@@ -6,7 +6,7 @@
  * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
  * released under GNU GPL v2 licence
  *
- * $Id: AddrClient.cpp,v 1.18 2008-11-11 22:01:27 thomson Exp $
+ * $Id: AddrClient.cpp,v 1.19 2009-03-24 22:41:07 thomson Exp $
  *
  */
 
@@ -16,25 +16,53 @@
 #include "AddrClient.h"
 #include "Logger.h"
 
-TAddrClient::TAddrClient(SmartPtr<TDUID> duid) {
+/**
+ * @brief constructor for creating client
+ *
+ * constructor used for creating client container. Client
+ * contains list of IAs, TAs and PDs.
+ *
+ * @param duid Client DUID
+ *
+ */
+TAddrClient::TAddrClient(SPtr<TDUID> duid) {
     this->DUID=duid;
     this->SPI = 0;
     this->ReplayDetectionRcvd = 0;
     this->ReplayDetectionSent = 1;
 }
 
-SmartPtr<TDUID> TAddrClient::getDUID() {
+SPtr<TDUID> TAddrClient::getDUID() {
     return this->DUID;
 }
 
 // --- IA ------------------------------------------------------------
 
-SmartPtr<TAddrIA> TAddrClient::getIA() {
+
+/**
+ * @brief rewinds IA list to the beginning
+ *
+ * rewinds IA list to the beginning
+ */
+void TAddrClient::firstIA() {
+  IAsLst.first();
+}
+
+/**
+ * @brief returns next IA
+ *
+ * returns next IA. Make sure to all firstIA() method before calling
+ * getIA() for the first time.
+ *
+ *
+ * @return next IA
+ */
+SPtr<TAddrIA> TAddrClient::getIA() {
     return IAsLst.get();
 }
 
-SmartPtr<TAddrIA> TAddrClient::getIA(unsigned long IAID) {
-    SmartPtr<TAddrIA> ptr;
+SPtr<TAddrIA> TAddrClient::getIA(unsigned long IAID) {
+    SPtr<TAddrIA> ptr;
     IAsLst.first();
 
     while ( ptr = IAsLst.get() ) {
@@ -42,28 +70,31 @@ SmartPtr<TAddrIA> TAddrClient::getIA(unsigned long IAID) {
             return ptr;
         }
     }
-    return SmartPtr<TAddrIA>();
+    return SPtr<TAddrIA>();
 }
 
-void TAddrClient::firstIA() {
-    IAsLst.first();
-}
-
-void TAddrClient::addIA(SmartPtr<TAddrIA> ia) {
+void TAddrClient::addIA(SPtr<TAddrIA> ia) {
     if (getIA(ia->getIAID()))
     {
-	Log(Debug) << "Unable to add IA (iaid=" << ia->getIAID() << "), such IA already exists." << LogEnd;
-	return;
+        Log(Debug) << "Unable to add IA (iaid=" << ia->getIAID() << "), such IA already exists." << LogEnd;
+	      return;
     }
     IAsLst.append(ia);
 }
 
+/**
+ * @brief returns number of IAs in this client
+ *
+ * returns number of IAs in this client
+ *
+ * @return number of IAs
+ */
 int TAddrClient::countIA() {
     return IAsLst.count();
 }
 
 bool TAddrClient::delIA(unsigned long IAID) {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     IAsLst.first();
 
     while ( ptr = IAsLst.get() ) {
@@ -77,12 +108,12 @@ bool TAddrClient::delIA(unsigned long IAID) {
 
 // --- PD ------------------------------------------------------------
 
-SmartPtr<TAddrIA> TAddrClient::getPD() {
+SPtr<TAddrIA> TAddrClient::getPD() {
     return PDLst.get();
 }
 
-SmartPtr<TAddrIA> TAddrClient::getPD(unsigned long IAID) {
-    SmartPtr<TAddrIA> ptr;
+SPtr<TAddrIA> TAddrClient::getPD(unsigned long IAID) {
+    SPtr<TAddrIA> ptr;
     PDLst.first();
 
     while ( ptr = PDLst.get() ) {
@@ -97,7 +128,7 @@ void TAddrClient::firstPD() {
     PDLst.first();
 }
 
-void TAddrClient::addPD(SmartPtr<TAddrIA> pd) {
+void TAddrClient::addPD(SPtr<TAddrIA> pd) {
     PDLst.append(pd);
 }
 
@@ -106,7 +137,7 @@ int TAddrClient::countPD() {
 }
 
 bool TAddrClient::delPD(unsigned long IAID) {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     PDLst.first();
 
     while ( ptr = PDLst.get() ) {
@@ -120,12 +151,12 @@ bool TAddrClient::delPD(unsigned long IAID) {
 
 // --- TA ------------------------------------------------------------
 
-SmartPtr<TAddrIA> TAddrClient::getTA() {
+SPtr<TAddrIA> TAddrClient::getTA() {
     return TALst.get();
 }
 
-SmartPtr<TAddrIA> TAddrClient::getTA(unsigned long IAID) {
-    SmartPtr<TAddrIA> ptr;
+SPtr<TAddrIA> TAddrClient::getTA(unsigned long IAID) {
+    SPtr<TAddrIA> ptr;
     TALst.first();
 
     while ( ptr = TALst.get() ) {
@@ -140,7 +171,7 @@ void TAddrClient::firstTA() {
     TALst.first();
 }
 
-void TAddrClient::addTA(SmartPtr<TAddrIA> ia) {
+void TAddrClient::addTA(SPtr<TAddrIA> ia) {
     TALst.append(ia);
 }
 
@@ -149,7 +180,7 @@ int TAddrClient::countTA() {
 }
 
 bool TAddrClient::delTA(unsigned long iaid) {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     TALst.first();
     while ( ptr = TALst.get() ) {
         if (ptr->getIAID() == iaid) {
@@ -165,14 +196,14 @@ bool TAddrClient::delTA(unsigned long iaid) {
 // --------------------------------------------------------------------
 
 unsigned long TAddrClient::getT1Timeout() {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     unsigned long ts = ULONG_MAX;
 
     IAsLst.first();
     while ( ptr = IAsLst.get() ) {
         if (ptr->getState()==STATE_CONFIGURED) {
 	    if (ts > ptr->getT1Timeout())
-            ts = ptr->getT1Timeout();
+		ts = ptr->getT1Timeout();
 	}else if (ptr->getState()==STATE_NOTCONFIGURED){
 	    ts = 0;
 	}
@@ -189,7 +220,7 @@ unsigned long TAddrClient::getT1Timeout() {
 }
 
 unsigned long TAddrClient::getT2Timeout() {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     unsigned long ts = ULONG_MAX;
     IAsLst.first();
 
@@ -212,7 +243,7 @@ unsigned long TAddrClient::getT2Timeout() {
 }
 
 unsigned long TAddrClient::getPrefTimeout() {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     unsigned long ts = ULONG_MAX;
 
     IAsLst.first();
@@ -235,7 +266,7 @@ unsigned long TAddrClient::getPrefTimeout() {
 }
 
 unsigned long TAddrClient::getValidTimeout() {
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     unsigned long ts = ULONG_MAX;
 
     IAsLst.first();
@@ -256,7 +287,7 @@ unsigned long TAddrClient::getValidTimeout() {
 unsigned long TAddrClient::getLastTimestamp() {
 
     unsigned long ts = 0;
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
 
     IAsLst.first();
     while ( ptr = IAsLst.get() ) {
@@ -317,7 +348,7 @@ ostream & operator<<(ostream & strum,TAddrClient &x)
 	strum << "    " << *x.DUID;
 
     strum << "    <!-- " << x.IAsLst.count() << " IA(s) -->" << endl;
-    SmartPtr<TAddrIA> ptr;
+    SPtr<TAddrIA> ptr;
     x.IAsLst.first();
     while (ptr = x.IAsLst.get() ) {
         strum << *ptr;
