@@ -3,6 +3,7 @@
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
  *          Marek Senderski  <msend@o2.pl>
+ * changes: Grzegorz Pluto <g.pluto(at)u-r-b-a-n(dot)pl>
  *
  * released under GNU GPL v2 only licence
  *
@@ -23,18 +24,27 @@
 #include <windows.h>
 #endif
 
-TAddrIA::TAddrIA(int iface, SmartPtr<TIPv6Addr> addr, SmartPtr<TDUID> duid, 
-		 unsigned long T1, unsigned long T2,unsigned long ID) 
+/**
+ * @brief constructor for new IA
+ *
+ * used for creation of IA, a container for addresses
+ *
+ * @param iface interface index (ifindex)
+ * @param type specifies container type (IA, PD or TA)
+ * @param addr address
+ * @param duid DUID (client DUID in server's database and server DUID in client's database)
+ * @param t1 T1 timer
+ * @param t2 T2 timer
+ * @param id IAID (if this is really IA) or PDID (if this is PD, not IA)
+ *
+ */
+TAddrIA::TAddrIA(int iface, TIAType type, SPtr<TIPv6Addr> addr, SPtr<TDUID> duid, 
+		 unsigned long t1, unsigned long t2,unsigned long id)
+    :IAID(id),T1(t1),T2(t2), State(STATE_NOTCONFIGURED), 
+     Tentative(TENTATIVE_UNKNOWN), Timestamp(now()), 
+     Unicast(false), Iface(iface), Type(type)
 {
-    this->T1 = T1;
-    this->T2 = T2;
-    this->IAID = ID;
-    this->Tentative = TENTATIVE_UNKNOWN;
-    this->State     = STATE_NOTCONFIGURED;//	STATE_CONFIRMME;
-    this->Timestamp = now();
-    this->Unicast = false;
     this->setDUID(duid);
-    this->Iface = iface;
     if (addr)
         this->setUnicast(addr);
     else
@@ -46,6 +56,10 @@ unsigned long TAddrIA::getIAID()
     return this->IAID;
 }
 
+/**
+ * resets IA to unconfigured state
+ *
+ */
 void TAddrIA::reset()
 {
     setState(STATE_NOTCONFIGURED);
@@ -76,22 +90,22 @@ void TAddrIA::setT2(unsigned long T2)
     this->T2 = T2;
 }
 
-void TAddrIA::addAddr(SmartPtr<TAddrAddr> x)
+void TAddrIA::addAddr(SPtr<TAddrAddr> x)
 {
     AddrLst.append(x);
     Tentative = TENTATIVE_UNKNOWN;
 }
 
-void TAddrIA::addAddr(SmartPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid)
+void TAddrIA::addAddr(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid)
 {
-    SmartPtr<TAddrAddr> ptr = new TAddrAddr(addr, pref, valid);
+    SPtr<TAddrAddr> ptr = new TAddrAddr(addr, pref, valid);
     AddrLst.append(ptr);
     Tentative = TENTATIVE_UNKNOWN;
 }
 
-void TAddrIA::addAddr(SmartPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid, int prefix)
+void TAddrIA::addAddr(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid, int prefix)
 {
-    SmartPtr<TAddrAddr> ptr = new TAddrAddr(addr, pref, valid, prefix);
+    SPtr<TAddrAddr> ptr = new TAddrAddr(addr, pref, valid, prefix);
     AddrLst.append(ptr);
     Tentative = TENTATIVE_UNKNOWN;
 }
@@ -114,7 +128,7 @@ TAddrIA::~TAddrIA()
 // --- contact with server using Unicast/Multicast --------------------
 // --------------------------------------------------------------------
 
-void TAddrIA::setUnicast(SmartPtr<TIPv6Addr> addr)
+void TAddrIA::setUnicast(SPtr<TIPv6Addr> addr)
 {
     this->Unicast = true;
     this->SrvAddr=addr;
@@ -125,7 +139,7 @@ void TAddrIA::setMulticast()
     this->Unicast = false;
 }
 
-SmartPtr<TIPv6Addr> TAddrIA::getSrvAddr()
+SPtr<TIPv6Addr> TAddrIA::getSrvAddr()
 {
     if (!this->Unicast) 
         return 0;
@@ -136,12 +150,12 @@ SmartPtr<TIPv6Addr> TAddrIA::getSrvAddr()
 // --- server's DUID --------------------------------------------------
 // --------------------------------------------------------------------
 
-void TAddrIA::setDUID(SmartPtr<TDUID> duid)
+void TAddrIA::setDUID(SPtr<TDUID> duid)
 {
     this->DUID = duid;
 }
 
-SmartPtr<TDUID> TAddrIA::getDUID()
+SPtr<TDUID> TAddrIA::getDUID()
 {
     return DUID;
 }
@@ -155,7 +169,7 @@ void TAddrIA::firstAddr()
 }
 
 // returns next address
-SmartPtr<TAddrAddr> TAddrIA::getAddr()
+SPtr<TAddrAddr> TAddrIA::getAddr()
 {
     return AddrLst.get();
 }
@@ -167,12 +181,12 @@ SmartPtr<TAddrAddr> TAddrIA::getAddr()
  * 
  * @return 
  */
-SmartPtr<TAddrAddr> TAddrIA::getAddr(SmartPtr<TIPv6Addr> addr)
+SPtr<TAddrAddr> TAddrIA::getAddr(SPtr<TIPv6Addr> addr)
 {
     if (!addr)
 	return 0;
     AddrLst.first();
-    SmartPtr <TAddrAddr> ptrAddr;
+    SPtr <TAddrAddr> ptrAddr;
     while (ptrAddr = AddrLst.get() ) {
         if ( (*addr)==(*(ptrAddr->get())) )
             return ptrAddr;
@@ -185,11 +199,10 @@ int TAddrIA::countAddr()
     return AddrLst.count();
 }
 
-int TAddrIA::delAddr(SmartPtr<TIPv6Addr> addr)
+int TAddrIA::delAddr(SPtr<TIPv6Addr> addr)
 {
-    SmartPtr< TAddrAddr> ptr;
+    SPtr< TAddrAddr> ptr;
     AddrLst.first();
-
     while (ptr = AddrLst.get())
     {
         if (*(ptr->get())==(*addr)) {
@@ -222,10 +235,9 @@ void TAddrIA::addPrefix(SPtr<TAddrPrefix> x)
     this->PrefixLst.append(x);
 }
 
-void TAddrIA::addPrefix(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid,
-	       int length)
+void TAddrIA::addPrefix(SPtr<TIPv6Addr> addr, unsigned long pref, unsigned long valid, int length)
 {
-    SmartPtr<TAddrPrefix> ptr = new TAddrPrefix(addr, pref, valid, length);
+    SPtr<TAddrPrefix> ptr = new TAddrPrefix(addr, pref, valid, length);
     PrefixLst.append(ptr);
 }
 
@@ -236,12 +248,12 @@ int TAddrIA::getPrefixCount()
 
 bool TAddrIA::delPrefix(SPtr<TAddrPrefix> x)
 {
-    SmartPtr<TAddrPrefix> ptr;
+    SPtr<TAddrPrefix> ptr;
     PrefixLst.first();
 
     while (ptr = PrefixLst.get())
     {
-	// FIXME: should we compare prefix length, too?
+	/// @todo: should we compare prefix length, too?
         if (*(ptr->get())==(*x->get())) {
             PrefixLst.del();
             return true;
@@ -252,12 +264,12 @@ bool TAddrIA::delPrefix(SPtr<TAddrPrefix> x)
 
 bool TAddrIA::delPrefix(SPtr<TIPv6Addr> x)
 {
-    SmartPtr<TAddrPrefix> ptr;
+    SPtr<TAddrPrefix> ptr;
     PrefixLst.first();
 
     while (ptr = PrefixLst.get())
     {
-	// FIXME: should we compare prefix length, too?
+	/// @todo: should we compare prefix length, too?
         if (*(ptr->get())==(*x)) {
             PrefixLst.del();
             return true;
@@ -300,7 +312,7 @@ unsigned long TAddrIA::getT2Timeout() {
 unsigned long TAddrIA::getPrefTimeout() {
     unsigned long ts = ULONG_MAX;
 
-    SmartPtr<TAddrAddr> ptr;
+    SPtr<TAddrAddr> ptr;
     this->AddrLst.first();
 
     while (ptr = this->AddrLst.get() ) {
@@ -313,7 +325,7 @@ unsigned long TAddrIA::getPrefTimeout() {
 unsigned long TAddrIA::getMaxValidTimeout() {
     unsigned long ts = 0; // should be 0
 
-    SmartPtr<TAddrAddr> ptr;
+    SPtr<TAddrAddr> ptr;
     this->AddrLst.first();
     while (ptr = this->AddrLst.get() ) {
         if (ts < ptr->getValidTimeout()) 
@@ -333,26 +345,21 @@ unsigned long TAddrIA::getMaxValidTimeout() {
 unsigned long TAddrIA::getValidTimeout() {
     unsigned long ts = ULONG_MAX;
 
-    SmartPtr<TAddrAddr> ptr;
+    SPtr<TAddrAddr> ptr;
     this->AddrLst.first();
 
     while (ptr = this->AddrLst.get() ) {
         if (ts > ptr->getValidTimeout()) 
             ts = ptr->getValidTimeout();
     }
-    return ts;
-}
 
-unsigned long TAddrIA::getMaxValid() {
-    unsigned long ts = 0;
-
-    SmartPtr<TAddrAddr> ptr;
-    this->AddrLst.first();
-
-    while (ptr = this->AddrLst.get() ) {
-        if (ts < ptr->getValidTimeout()) 
-            ts = ptr->getValidTimeout();
+    SPtr<TAddrPrefix> prefix;
+    firstPrefix();
+    while (prefix = getPrefix()) {
+      if (ts > prefix->getValidTimeout())
+          ts = prefix->getValidTimeout();
     }
+
     return ts;
 }
 
@@ -360,7 +367,7 @@ unsigned long TAddrIA::getMaxValid() {
 void TAddrIA::setTimestamp(unsigned long ts)
 {
     this->Timestamp = ts;
-    SmartPtr<TAddrAddr> ptr;
+    SPtr<TAddrAddr> ptr;
     AddrLst.first();
     while (ptr = AddrLst.get() )
     {
@@ -377,6 +384,13 @@ unsigned long TAddrIA::getTimestamp()
     return Timestamp;
 }
 
+/**
+ * @brief returns time till DAD procedure finishes
+ *
+ * returns how much time left until DAD procedure is finished
+ *
+ * @return timeout in seconds
+ */
 unsigned long TAddrIA::getTentativeTimeout()
 {
     unsigned long min = DHCPV6_INFINITY;
@@ -387,7 +401,7 @@ unsigned long TAddrIA::getTentativeTimeout()
     case TENTATIVE_NO:
         return DHCPV6_INFINITY;
     case TENTATIVE_UNKNOWN:
-        SmartPtr <TAddrAddr> ptrAddr;
+        SPtr <TAddrAddr> ptrAddr;
         AddrLst.first();
         while ( ptrAddr = AddrLst.get() )
         {
@@ -401,15 +415,19 @@ unsigned long TAddrIA::getTentativeTimeout()
     return min;
 }
 
-// returns Tentative status (TENTATIVE_YES/TENTATIVE_NO/TENTATIVE_UNKNOWN)
+/**
+ * @brief checks and returns tentative status
+ *
+ * checks if DAD procedure is finished and returns tentative status
+ *
+ * @return Tentative status (TENTATIVE_YES/TENTATIVE_NO/TENTATIVE_UNKNOWN)
+ */
 enum ETentative TAddrIA::getTentative()
 {
     if (Tentative != TENTATIVE_UNKNOWN)
     	return Tentative;
-    //if (Timestamp+DADTIMEOUT > now() )
-	//    return TENTATIVE_UNKNOWN;
 
-    SmartPtr<TAddrAddr> ptrAddr;
+    SPtr<TAddrAddr> ptrAddr;
     AddrLst.first();
 
     bool allChecked = true;
@@ -426,23 +444,23 @@ enum ETentative TAddrIA::getTentative()
 	case TENTATIVE_UNKNOWN:
         if ( ptrAddr->getTimestamp()+DADTIMEOUT < now() ) 
         {
-
+	    
             switch (is_addr_tentative(NULL, this->Iface, ptrAddr->get()->getPlain()) ) 
             {
-                case    LOWLEVEL_TENTATIVE_YES:  
-                    ptrAddr->setTentative(TENTATIVE_YES);
-                    this->Tentative=TENTATIVE_YES;
-                    return TENTATIVE_YES;
-                case    LOWLEVEL_TENTATIVE_NO:
-                    ptrAddr->setTentative(TENTATIVE_NO);
-                    Log(Debug) << "DAD finished successfully. Address " << ptrAddr->get()->getPlain()
-			       << " is not tentative." << LogEnd;
-                    break;
-                default:
-                    Log(Error) << "DAD inconclusive. Unable to dermine " << ptrAddr->get()->getPlain() 
-                               << " address state. Assuming NOT TENTATIVE." << LogEnd;
-                    ptrAddr->setTentative(TENTATIVE_NO);
-                    break;
+	    case LOWLEVEL_TENTATIVE_YES:  
+		ptrAddr->setTentative(TENTATIVE_YES);
+		this->Tentative=TENTATIVE_YES;
+		return TENTATIVE_YES;
+	    case LOWLEVEL_TENTATIVE_NO:
+		ptrAddr->setTentative(TENTATIVE_NO);
+		Log(Debug) << "DAD finished successfully. Address " << ptrAddr->get()->getPlain()
+			   << " is not tentative." << LogEnd;
+		break;
+	    default:
+		Log(Error) << "DAD inconclusive. Unable to dermine " << ptrAddr->get()->getPlain() 
+			   << " address state. Assuming NOT TENTATIVE." << LogEnd;
+		ptrAddr->setTentative(TENTATIVE_NO);
+		break;
             }
         } 
         else 
@@ -457,9 +475,16 @@ enum ETentative TAddrIA::getTentative()
     }
 }
 
+/**
+ * @brief sets tentative state, according to states of addresses
+ *
+ * sets tentative state, based on stats of addresses defined within
+ * this IA
+ *
+ */
 void TAddrIA::setTentative()
 {
-    SmartPtr<TAddrAddr> ptrAddr;
+    SPtr<TAddrAddr> ptrAddr;
     AddrLst.first();
     Tentative = TENTATIVE_NO;
 
@@ -482,7 +507,7 @@ void TAddrIA::setTentative()
 /** 
  * stores DNS server address, at which DNSUpdate was performed
  * 
- * @param srvAddr 
+ * @param srvAddr DNS Server address to be stored
  */
 void TAddrIA::setFQDNDnsServer(SPtr<TIPv6Addr> srvAddr)
 {
@@ -492,8 +517,7 @@ void TAddrIA::setFQDNDnsServer(SPtr<TIPv6Addr> srvAddr)
 /** 
  * return DNS server address, where the DNSUpdate was performed
  * 
- * 
- * @return 
+ * @return DNS server that DNS Update was performed at
  */
 SPtr<TIPv6Addr> TAddrIA::getFQDNDnsServer()
 {
@@ -526,17 +550,41 @@ SPtr<TFQDN> TAddrIA::getFQDN()
 
 ostream & operator<<(ostream & strum,TAddrIA &x) {
 
-    SmartPtr<TAddrAddr> ptr;
+    SPtr<TAddrAddr> ptr;
     SPtr<TAddrPrefix> prefix;
-
-	strum << "    <AddrIA unicast=\"";
+    string name;
+    
+    switch (x.Type)
+    {
+    case TAddrIA::TYPE_IA:
+	name="AddrIA";
+	break;
+    case TAddrIA::TYPE_TA:
+	name="AddrTA";
+	break;
+    case TAddrIA::TYPE_PD:
+	name="AddrPD";
+	break;
+    }
+    strum << "    <" << name << " unicast=\"";
     if (x.Unicast)
 	strum << x.SrvAddr->getPlain();
     strum << "\" T1=\"" << x.T1 << "\""
-	   << " T2=\"" << x.T2 << "\""
-	   << " IAID=\"" << x.IAID << "\""
-	   << " state=\"" << StateToString(x.State) 
-	   << "\" iface=\"" << x.Iface << "\"" << ">" << endl;
+	  << " T2=\"" << x.T2 << "\"";
+
+    switch (x.Type)
+    {
+    case TAddrIA::TYPE_IA:
+    case TAddrIA::TYPE_TA:
+	strum << " IAID=\"";
+	break;
+    case TAddrIA::TYPE_PD:
+	strum << " PDID=\"";
+	break;
+    }
+    strum << x.IAID << "\""
+	  << " state=\"" << StateToString(x.State) 
+	  << "\" iface=\"" << x.Iface << "\"" << ">" << endl;
     if (x.getDUID() && x.getDUID()->getLen())
         strum << "      " << *x.DUID;
 
@@ -554,17 +602,20 @@ ostream & operator<<(ostream & strum,TAddrIA &x) {
     }
 
     // FQDN
-    if (x.fqdnDnsServer) {
-	strum << "      <fqdnDnsServer>" << x.fqdnDnsServer->getPlain() << "</fqdnDnsServer>" << endl;
-    } else {
-	strum << "      <!--<fqdnDnsServer>-->" << endl;
-    }
-    if (x.fqdn) {
-	strum << "      " << *x.fqdn << endl;
-    } else {
-	strum << "      <!-- <fqdn>-->" << endl;
+    if (x.Type!=TAddrIA::TYPE_PD) {
+        // it does not make sense to mention FQDN in PD
+        if (x.fqdnDnsServer) {
+            strum << "      <fqdnDnsServer>" << x.fqdnDnsServer->getPlain() << "</fqdnDnsServer>" << endl;
+        } else {
+            strum << "      <!--<fqdnDnsServer>-->" << endl;
+        }
+        if (x.fqdn) {
+            strum << "      " << *x.fqdn << endl;
+        } else {
+            strum << "      <!-- <fqdn>-->" << endl;
+        }
     }
 
-    strum << "    </AddrIA>" << dec << endl;
+    strum << "    </" << name << ">" << dec << endl;
     return strum;
 }
