@@ -3,10 +3,7 @@
  *
  * author: Krzysztof Wnuk <keczi@poczta.onet.pl>
  *
- * $Log: AddrPrefix.h,v $
- * Revision 1.1  2006-10-06 00:30:17  thomson
- * Initial PD support.
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.5  2006-08-03 00:43:15  thomson
  * FQDN support added.
  *
@@ -31,7 +28,7 @@ class TAddrPrefix: public TAddrAddr
     friend ostream & operator<<(ostream & strum,TAddrPrefix &x);
   public:
 
-    TAddrPrefix(SmartPtr<TIPv6Addr> addr, long pref, long valid, int length);
+    TAddrPrefix(SPtr<TIPv6Addr> addr, long pref, long valid, int length);
 
     // return address in packed format (char[16])
     int getLength();
