@@ -8,17 +8,6 @@
  *
  * $Id: ClntCfgAddr.cpp,v 1.5 2008-08-29 00:07:27 thomson Exp $
  *
- * $Log: ClntCfgAddr.cpp,v $
- * Revision 1.5  2008-08-29 00:07:27  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
- * Revision 1.4  2005-11-03 21:23:43  thomson
- * Fixed possible segfault, when user did not specify IA parameters.
- *
- * Revision 1.3  2004/10/25 20:45:52  thomson
- * Option support, parsers rewritten. ClntIfaceMgr now handles options.
- *
- *
  */
 
 #include <iostream>
@@ -28,7 +17,7 @@
 #include "ClntCfgAddr.h"
 #include "Logger.h"
 
-SmartPtr<TIPv6Addr> TClntCfgAddr::get() {
+SPtr<TIPv6Addr> TClntCfgAddr::get() {
     return Addr;
 }
 
@@ -41,7 +30,7 @@ unsigned long TClntCfgAddr::getPref() {
 }
 
 
-TClntCfgAddr::TClntCfgAddr(SmartPtr<TIPv6Addr> addr,long valid,long pref)
+TClntCfgAddr::TClntCfgAddr(SPtr<TIPv6Addr> addr,long valid,long pref)
 {
     Addr=addr;
     Valid = valid;
@@ -52,7 +41,7 @@ TClntCfgAddr::~TClntCfgAddr() {
 
 }
 
-void TClntCfgAddr::setOptions(SmartPtr<TClntParsGlobalOpt> opt) {
+void TClntCfgAddr::setOptions(SPtr<TClntParsGlobalOpt> opt) {
     this->Valid=opt->getValid();
     this->Pref=opt->getPref();
 }
@@ -63,7 +52,7 @@ TClntCfgAddr::TClntCfgAddr() {
     Addr= new TIPv6Addr();
 }
 
-TClntCfgAddr::TClntCfgAddr(SmartPtr<TIPv6Addr> addr) {
+TClntCfgAddr::TClntCfgAddr(SPtr<TIPv6Addr> addr) {
     Addr=addr;
     Valid = ULONG_MAX;
     Pref = ULONG_MAX;
