@@ -1,69 +1,64 @@
-/*                                                                           
- * Dibbler - a portable DHCPv6                                               
- *                                                                           
- * authors: Tomasz Mrugalski <thomson@klub.com.pl>                           
- *          Marek Senderski <msend@o2.pl>                                    
- * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>                                                                         
- *          Michal Kowalczuk <michal@kowalczuk.eu>
+/*
+ * Dibbler - a portable DHCPv6
  *
- * released under GNU GPL v2 only licence                                
- *                                                                           
- * $Id: ClntCfgIface.cpp,v 1.28 2008-08-29 00:07:27 thomson Exp $
+ * authors: Tomasz Mrugalski <thomson@klub.com.pl>
+ *          Marek Senderski <msend@o2.pl>
+ * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ *          Michal Kowalczuk <michal@kowalczuk.eu>
+ *          Mateusz Ozga <matozga@gmail.com>
+ *
+ * released under GNU GPL v2 only licence
  *
  */
 
 #include <iostream>
 #include <iomanip>
+#include <sstream>
 #include "ClntCfgIface.h"
 #include "Logger.h"
 #include "Portable.h"
-#include "ClntOptVendorSpec.h"
+#include "OptVendorSpecInfo.h"
 using namespace std;
 
 TClntCfgIface::TClntCfgIface(string ifaceName) {
+    setDefaults();
+
     NoConfig=false;
     IfaceName=ifaceName;
     ID=-1;
-    this->DNSServerState  = STATE_DISABLED;
-    this->DomainState     = STATE_DISABLED;
-    this->NTPServerState  = STATE_DISABLED;
-    this->TimezoneState   = STATE_DISABLED;
-    this->SIPServerState  = STATE_DISABLED;
-    this->SIPDomainState  = STATE_DISABLED;
-    this->FQDNState       = STATE_DISABLED;
-    this->NISServerState  = STATE_DISABLED;
-    this->NISPServerState = STATE_DISABLED;
-    this->NISDomainState  = STATE_DISABLED;
-    this->NISPDomainState = STATE_DISABLED;
-    this->LifetimeState   = STATE_DISABLED;
-    this->PrefixDelegationState = STATE_DISABLED;
-    this->VendorSpecState = STATE_DISABLED;
 }
 
 TClntCfgIface::TClntCfgIface(int ifaceNr) {
+    setDefaults();
     NoConfig=false;
     ID=ifaceNr;
     IfaceName="[unknown]";
-    this->DNSServerState  = STATE_DISABLED;
-    this->DomainState     = STATE_DISABLED;
-    this->NTPServerState  = STATE_DISABLED;
-    this->TimezoneState   = STATE_DISABLED;
-    this->SIPServerState  = STATE_DISABLED;
-    this->SIPDomainState  = STATE_DISABLED;
-    this->FQDNState       = STATE_DISABLED;
-    this->NISServerState  = STATE_DISABLED;
-    this->NISPServerState = STATE_DISABLED;
-    this->NISDomainState  = STATE_DISABLED;
-    this->NISPDomainState = STATE_DISABLED;
-    this->LifetimeState   = STATE_DISABLED;
-    this->PrefixDelegationState = STATE_DISABLED;
-    this->VendorSpecState = STATE_DISABLED;
 }
 
-void TClntCfgIface::setOptions(SmartPtr<TClntParsGlobalOpt> opt) {
-    this->isIA        = opt->getIsIAs();
-    this->Unicast     = opt->getUnicast();
-    this->RapidCommit = opt->getRapidCommit();
+void TClntCfgIface::setDefaults() {
+    DNSServerState  = STATE_DISABLED;
+    DomainState     = STATE_DISABLED;
+    NTPServerState  = STATE_DISABLED;
+    TimezoneState   = STATE_DISABLED;
+    SIPServerState  = STATE_DISABLED;
+    SIPDomainState  = STATE_DISABLED;
+    FQDNState       = STATE_DISABLED;
+    NISServerState  = STATE_DISABLED;
+    NISPServerState = STATE_DISABLED;
+    NISDomainState  = STATE_DISABLED;
+    NISPDomainState = STATE_DISABLED;
+    LifetimeState   = STATE_DISABLED;
+    PrefixDelegationState = STATE_DISABLED;
+    VendorSpecState = STATE_DISABLED;
+    RoutingEnabledState = STATE_DISABLED;
+
+    ExtraOpts.clear();
+}
+
+void TClntCfgIface::setOptions(SPtr<TClntParsGlobalOpt> opt) {
+    isIA        = opt->getIsIAs();
+    Unicast     = opt->getUnicast();
+    RapidCommit = opt->getRapidCommit();
 
     // copy YES/NO information
     ReqDNSServer = opt->getReqDNSServer();
@@ -82,66 +77,67 @@ void TClntCfgIface::setOptions(SmartPtr<TClntParsGlobalOpt> opt) {
     ReqVendorSpec= opt->getReqVendorSpec();
 
     // copy parameters
-    this->DNSServerLst = *opt->getDNSServerLst();
-    this->DomainLst    = *opt->getDomainLst();
-    this->Timezone     = opt->getTimezone();
-    this->NTPServerLst = *opt->getNTPServerLst();
-    this->SIPServerLst = *opt->getSIPServerLst();
-    this->SIPDomainLst = *opt->getSIPDomainLst();
-    this->FQDN         = opt->getFQDN();
-    this->NISServerLst = *opt->getNISServerLst();
-    this->NISDomain    = opt->getNISDomain();
-    this->NISPServerLst= *opt->getNISPServerLst();
-    this->NISPDomain   = opt->getNISPDomain();
-    this->VendorSpec   = opt->getVendorSpec();
+    DNSServerLst = *opt->getDNSServerLst();
+    DomainLst    = *opt->getDomainLst();
+    Timezone     = opt->getTimezone();
+    NTPServerLst = *opt->getNTPServerLst();
+    SIPServerLst = *opt->getSIPServerLst();
+    SIPDomainLst = *opt->getSIPDomainLst();
+    FQDN         = opt->getFQDN();
+    NISServerLst = *opt->getNISServerLst();
+    NISDomain    = opt->getNISDomain();
+    NISPServerLst= *opt->getNISPServerLst();
+    NISPDomain   = opt->getNISPDomain();
+    VendorSpecLst= opt->getVendorSpec();
+
+    if (ReqDNSServer)  setDNSServerState(STATE_NOTCONFIGURED);
+    if (ReqDomain)     setDomainState(STATE_NOTCONFIGURED);
+    if (ReqNTPServer)  setNTPServerState(STATE_NOTCONFIGURED);
+    if (ReqTimezone)   setTimezoneState(STATE_NOTCONFIGURED);
+    if (ReqSIPServer)  setSIPServerState(STATE_NOTCONFIGURED);
+    if (ReqSIPDomain)  setSIPDomainState(STATE_NOTCONFIGURED);
+    if (ReqFQDN)       setFQDNState(STATE_NOTCONFIGURED);
+    if (ReqNISServer)  setNISServerState(STATE_NOTCONFIGURED);
+    if (ReqNISDomain)  setNISDomainState(STATE_NOTCONFIGURED);
+    if (ReqNISPServer) setNISPServerState(STATE_NOTCONFIGURED);
+    if (ReqNISPDomain) setNISPDomainState(STATE_NOTCONFIGURED);
+    if (ReqLifetime)   setLifetimeState(STATE_NOTCONFIGURED);
+    if (ReqVendorSpec) setVendorSpecState(STATE_NOTCONFIGURED);
 
-    if (ReqDNSServer)  this->setDNSServerState(STATE_NOTCONFIGURED);
-    if (ReqDomain)     this->setDomainState(STATE_NOTCONFIGURED);
-    if (ReqNTPServer)  this->setNTPServerState(STATE_NOTCONFIGURED);
-    if (ReqTimezone)   this->setTimezoneState(STATE_NOTCONFIGURED);
-    if (ReqSIPServer)  this->setSIPServerState(STATE_NOTCONFIGURED);
-    if (ReqSIPDomain)  this->setSIPDomainState(STATE_NOTCONFIGURED);
-    if (ReqFQDN)       this->setFQDNState(STATE_NOTCONFIGURED);
-    if (ReqNISServer)  this->setNISServerState(STATE_NOTCONFIGURED);
-    if (ReqNISDomain)  this->setNISDomainState(STATE_NOTCONFIGURED);
-    if (ReqNISPServer) this->setNISPServerState(STATE_NOTCONFIGURED);
-    if (ReqNISPDomain) this->setNISPDomainState(STATE_NOTCONFIGURED);
-    if (ReqLifetime)   this->setLifetimeState(STATE_NOTCONFIGURED);
-    if (ReqVendorSpec) this->setVendorSpecState(STATE_NOTCONFIGURED);
     // copy preferred-server list
-    SmartPtr<TStationID> station;
+    SPtr<TStationID> station;
     opt->firstPrefSrv();
     while (station = opt->getPrefSrv())
-	this->PrefSrvLst.append(station);
+	PrefSrvLst.append(station);
 
     // copy rejected-server list
     opt->firstRejedSrv();
     while (station = opt->getRejedSrv())
-	this->RejectedSrvLst.append(station);
+	RejectedSrvLst.append(station);
 }
 
-bool TClntCfgIface::isServerRejected(SmartPtr<TIPv6Addr> addr,SmartPtr<TDUID> duid)
+bool TClntCfgIface::isServerRejected(SPtr<TIPv6Addr> addr,SPtr<TDUID> duid)
 {
-    this->RejectedSrvLst.first();
-    SmartPtr<TStationID> RejectedSrv;
+    RejectedSrvLst.first();
+    SPtr<TStationID> RejectedSrv;
     while(RejectedSrv=RejectedSrvLst.get())
     {
-        if (((*RejectedSrv)==addr)||((*RejectedSrv)==duid))
-            return true;
+	if (((*RejectedSrv)==addr)||((*RejectedSrv)==duid))
+	    return true;
     }
     return false;
 }
 
 void TClntCfgIface::firstTA() {
-    this->ClntCfgTALst.first();
+    ClntCfgTALst.first();
 }
 
-SmartPtr<TClntCfgTA> TClntCfgIface::getTA() {
-    return this->ClntCfgTALst.get();
+SPtr<TClntCfgTA> TClntCfgIface::getTA() {
+    return ClntCfgTALst.get();
 }
 
-void  TClntCfgIface::addTA(SmartPtr<TClntCfgTA> ta) {
-    this->ClntCfgTALst.append(ta);
+void  TClntCfgIface::addTA(SPtr<TClntCfgTA> ta) {
+    ClntCfgTALst.append(ta);
 }
 
 int TClntCfgIface::countTA()
@@ -159,7 +155,7 @@ int TClntCfgIface::countIA()
     return IALst.count();
 }
 
- SmartPtr<TClntCfgIA> TClntCfgIface::getIA()
+ SPtr<TClntCfgIA> TClntCfgIface::getIA()
 {
     return IALst.get();
 }
@@ -175,8 +171,7 @@ SPtr<TClntCfgIA> TClntCfgIface::getIA(int iaid)
     return 0;
 }
 
-
- void TClntCfgIface::addIA(SmartPtr<TClntCfgIA> ptr)
+void TClntCfgIface::addIA(SPtr<TClntCfgIA> ptr)
 {
     IALst.append(ptr);
 }
@@ -191,7 +186,7 @@ int TClntCfgIface::countPD()
     return PDLst.count();
 }
 
- SmartPtr<TClntCfgPD> TClntCfgIface::getPD()
+ SPtr<TClntCfgPD> TClntCfgIface::getPD()
 {
     return PDLst.get();
 }
@@ -207,28 +202,20 @@ SPtr<TClntCfgPD> TClntCfgIface::getPD(int iaid)
     return 0;
 }
 
-void TClntCfgIface::addPD(SmartPtr<TClntCfgPD> ptr)
+void TClntCfgIface::addPD(SPtr<TClntCfgPD> ptr)
 {
     PDLst.append(ptr);
 }
 
-
-#if 0
-SmartPtr<TClntCfgIA> TClntCfgIface::getLastIA()
-{
-    return IALst.getLast();
-}
-#endif
-
  string TClntCfgIface::getName(void)
 {
-    return IfaceName;    
+    return IfaceName;
 }
 
 string TClntCfgIface::getFullName() {
     ostringstream oss;
-    oss << this->ID;
-    return string(this->IfaceName)
+    oss << ID;
+    return string(IfaceName)
 	+"/"
 	+oss.str();
 }
@@ -322,6 +309,9 @@ bool TClntCfgIface::isReqLifetime() {
 bool TClntCfgIface::isReqVendorSpec() {
     return this->ReqVendorSpec;
 }
+bool TClntCfgIface::isRoutingEnabled() {
+    return this->RoutingEnabled;
+}
 
 // --------------------------------------------------------------------------------
 // --- options: state -------------------------------------------------------------
@@ -372,6 +362,9 @@ EState TClntCfgIface::getKeyGenerationState() {
 EState TClntCfgIface::getAuthenticationState() {
     return AuthenticationState;
 }
+EState TClntCfgIface::getRoutingEnabledState() {
+    return RoutingEnabledState;
+}
 // --------------------------------------------------------------------
 // --- options: get option --------------------------------------------
 // --------------------------------------------------------------------
@@ -410,11 +403,11 @@ string TClntCfgIface::getProposedNISPDomain() {
 }
 
 void TClntCfgIface::firstVendorSpec() {
-    VendorSpec.first();
+    VendorSpecLst.first();
 }
 
-SPtr<TClntOptVendorSpec> TClntCfgIface::getVendorSpec() {
-    return this->VendorSpec.get();
+SPtr<TOptVendorSpecInfo> TClntCfgIface::getVendorSpec() {
+    return this->VendorSpecLst.get();
 }
 
 // --------------------------------------------------------------------
@@ -461,6 +454,11 @@ void TClntCfgIface::setVendorSpecState(EState state) {
     this->VendorSpecState = state;
 }
 
+void TClntCfgIface::setVendorSpec(List(TOptVendorSpecInfo) vendorSpecList)
+{
+    VendorSpecLst = vendorSpecList;
+}
+
 void TClntCfgIface::setKeyGenerationState(EState state) {
     this->KeyGenerationState = state;
 }
@@ -477,6 +475,55 @@ int  TClntCfgIface::getPrefixLength() {
     return this->PrefixLength;
 }
 
+void TClntCfgIface::setRoutingEnabledState(EState state) {
+    this->RoutingEnabledState = state;
+}
+
+/**
+ * add extra option to the list of supported extra options
+ *
+ * @param extra smart pointer to the supported option (to be sent)
+ * @param sendAlways should this option be always sent? Even when already configured?
+ */
+void TClntCfgIface::addExtraOption(SPtr<TOpt> extra, TOpt::EOptionLayout layout, bool sendAlways) {
+    SPtr<TOptionStatus> optStatus = new TOptionStatus();
+    optStatus->OptionType = extra->getOptType();
+    optStatus->Option = extra;
+    optStatus->Always = sendAlways;
+    optStatus->Layout = layout;
+    ExtraOpts.push_back(optStatus);
+}
+
+/**
+ * add extra option to the list of supported extra options
+ *
+ * @param opttype code of the supported option
+ * @param layout defines layout (see TOpt::EOptionLayout)
+ * @param sendAlways should this option be always sent? Even when already configured?
+ */
+void TClntCfgIface::addExtraOption(int opttype, TOpt::EOptionLayout layout, bool sendAlways) {
+    SPtr<TOptionStatus> optStatus = new TOptionStatus();
+    optStatus->OptionType = opttype;
+    optStatus->Always = sendAlways;
+    optStatus->Layout = layout;
+    ExtraOpts.push_back(optStatus);
+}
+
+TClntCfgIface::TOptionStatusLst& TClntCfgIface::getExtraOptions() {
+    return ExtraOpts;
+}
+
+void TClntCfgIface::setRouting(bool enabled) {
+    RoutingEnabled = enabled;
+}
+
+SPtr<TClntCfgIface::TOptionStatus> TClntCfgIface::getExtaOptionState(int type) {
+    for (TOptionStatusLst::iterator opt=ExtraOpts.begin(); opt!=ExtraOpts.end(); ++opt)
+	if ((*opt)->OptionType == type)
+	    return (*opt); // these are the droids you are looking for
+
+    return 0; // not found
+}
 
 
 // --------------------------------------------------------------------
@@ -485,19 +532,19 @@ int  TClntCfgIface::getPrefixLength() {
 
 ostream& operator<<(ostream& out,TClntCfgIface& iface)
 {
-    SmartPtr<TIPv6Addr> addr;
-    SmartPtr<string> str;
+    SPtr<TIPv6Addr> addr;
+    SPtr<string> str;
 
     out << dec;
     out<<"  <ClntCfgIface ";
     if (iface.NoConfig) {
-        out << "no-config=\"true\" />" << endl;
-        return out;
+	out << "no-config=\"true\" />" << endl;
+	return out;
     }
 
     out << "name=\"" << iface.IfaceName << "\""
-        << " ifindex=\"" << iface.ID << "\">" << endl;
-    
+	<< " ifindex=\"" << iface.ID << "\">" << endl;
+
     if (iface.RapidCommit) {
 	out << "    <RapidCommit/>" << endl;
     } else {
@@ -506,16 +553,16 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 
     out << "    <!-- addresses -->" << endl;
     out << "    <iaLst count=\"" << iface.IALst.count() << "\">" << endl;
-    SmartPtr<TClntCfgIA> ia;
+    SPtr<TClntCfgIA> ia;
     iface.IALst.first();
     while(ia=iface.IALst.get())
-    {	
-        out << *ia;
+    {
+	out << *ia;
     }
     out << "    </iaLst>" << endl;
 
     out << "    <!-- temporary addresses -->" << endl;
-    SmartPtr<TClntCfgTA> ta;
+    SPtr<TClntCfgTA> ta;
     iface.firstTA();
     while (ta = iface.getTA() ) {
 	out << *ta;
@@ -525,7 +572,7 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 
     out << "    <!-- prefix delegation -->" << endl;
     out << "    <pdLst count=\"" << iface.countPD() << "\">" << endl;
-    SmartPtr<TClntCfgPD> pd;
+    SPtr<TClntCfgPD> pd;
     iface.firstPD();
     while (pd = iface.getPD()) {
 	out << *pd;
@@ -539,14 +586,14 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 
 	iface.DNSServerLst.first();
 	while(addr=iface.DNSServerLst.get())
-	    out << "      <dns-server>" << *addr << "</dns-server>" << endl;  
+	    out << "      <dns-server>" << *addr << "</dns-server>" << endl;
     } else {
 	out << "    <!-- <dns-servers/> -->" << endl;
     }
 
     // --- option: DOMAIN ---
     if (iface.isReqDomain()) {
-	out << "    <domains state=\"" << StateToString(iface.getDomainState()) 
+	out << "    <domains state=\"" << StateToString(iface.getDomainState())
 	    << "\" hints=\"" << iface.DomainLst.count() << "\" />" << endl;
 
 	iface.DomainLst.first();
@@ -555,18 +602,18 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
     } else {
 	out << "    <!-- <domains/> -->" << endl;
     }
-	
+
     // --- option: NTP servers ---
     if (iface.isReqNTPServer()) {
-	out << "    <ntp-servers state=\"" << StateToString(iface.getNTPServerState()) 
+	out << "    <ntp-servers state=\"" << StateToString(iface.getNTPServerState())
 	    << "\" hints=\"" << iface.NTPServerLst.count() << "\" />" << endl;
 	iface.NTPServerLst.first();
 	while(addr=iface.NTPServerLst.get())
-	    out << "      <ntp-server>" << *addr << "</ntp-server>" << endl;  
+	    out << "      <ntp-server>" << *addr << "</ntp-server>" << endl;
     } else {
 	out << "    <!-- <ntp-servers/> -->" << endl;
     }
-    
+
     // --- option: Timezone ---
     if (iface.isReqTimezone()) {
 	out << "    <timezone state=\"" << StateToString(iface.getTimezoneState())
@@ -581,7 +628,7 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 	    << "\" hints=\"" << iface.NTPServerLst.count() << "\"/>" << endl;
 	iface.NTPServerLst.first();
 	while(addr=iface.NTPServerLst.get())
-	    out << "      <sip-server>" << *addr << "</sip-server>" << endl;  
+	    out << "      <sip-server>" << *addr << "</sip-server>" << endl;
     } else {
 	out << "    <!-- <sip-servers/> -->" << endl;
     }
@@ -599,7 +646,7 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 
     // --- option: FQDN ---
     if (iface.isReqFQDN()) {
-	out << "    <fqdn state=\"" << StateToString(iface.getFQDNState()) 
+	out << "    <fqdn state=\"" << StateToString(iface.getFQDNState())
 	    << "\">" << iface.FQDN << "</fqdn>" << endl;
     } else {
 	out << "    <!-- <fqdn/> -->" << endl;
@@ -611,7 +658,7 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 	    << "\" hints=\"" << iface.NISServerLst.count() << "\"/>" << endl;
 	iface.NISServerLst.first();
 	while(addr=iface.NISServerLst.get())
-	    out << "      <nis-server>" << *addr << "</nis-server>" << endl;  
+	    out << "      <nis-server>" << *addr << "</nis-server>" << endl;
     } else {
 	out << "    <!-- <nis-servers/> -->" << endl;
     }
@@ -630,7 +677,7 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 	    << "\" hints=\"" << iface.NISPServerLst.count() << "\"/>" << endl;
 	iface.NISPServerLst.first();
 	while(addr=iface.NISPServerLst.get())
-	    out << "      <nisplus-server>" << *addr << "</nisplus-server>" << endl;  
+	    out << "      <nisplus-server>" << *addr << "</nisplus-server>" << endl;
     } else {
 	out << "    <!-- <nisplus-servers/> -->" << endl;
     }
@@ -652,12 +699,12 @@ ostream& operator<<(ostream& out,TClntCfgIface& iface)
 
     // --- option: Vendor-spec ---
     if (iface.isReqVendorSpec()) {
-	SPtr<TClntOptVendorSpec> opt;
-	out << "    <vendorSpecLst count=\"" << iface.VendorSpec.count() << "\">" << endl;
-	iface.VendorSpec.first();
-	while (opt = iface.VendorSpec.get()) {
-	    out << "      <vendor enterprise=\"" << opt->getVendor() << "\" length=\"" << opt->getVendorDataLen() << "\">"
-		<< opt->getVendorDataPlain() << "</vendor>" << endl;
+	SPtr<TOptVendorSpecInfo> opt;
+	out << "    <vendorSpecLst count=\"" << iface.VendorSpecLst.count() << "\">" << endl;
+	iface.VendorSpecLst.first();
+	while (opt = iface.VendorSpecLst.get()) {
+	    out << "      <vendorSpec vendor=\"" << opt->getVendor() << "\">"
+		<< opt->getPlain() << "</vendorSpec>" << endl;
 	}
 	out << "    <vendorSpecLst/>" << endl;
     } else {
