@@ -1,23 +1,20 @@
-/*                                                                           
- * Dibbler - a portable DHCPv6                                               
- *                                                                           
- * authors: Tomasz Mrugalski <thomson@klub.com.pl>                           
- *          Marek Senderski <msend@o2.pl>                                    
- * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>                                                                         
+/*
+ * Dibbler - a portable DHCPv6
+ *
+ * authors: Tomasz Mrugalski <thomson@klub.com.pl>
+ *          Marek Senderski <msend@o2.pl>
+ * changes: Krzysztof Wnuk <keczi@poczta.onet.pl>
  *          Michal Kowalczuk <michal@kowalczuk.eu>
- * 
- * released under GNU GPL v2 only licence                                
- *                                                                           
+ *          Mateusz Ozga <matozga@gmail.com>
+ *
+ * released under GNU GPL v2 only licence
+ *
  * $Id: ClntCfgIface.h,v 1.20 2008-08-29 00:07:27 thomson Exp $
  */
 
-class TClntCfgIface;
 #ifndef CLNTCFGIFACE_H
 #define CLNTCFGIFACE_H
-
-#include <iostream>
-#include <iomanip>
-#include <sstream>
+#include <list>
 
 #include "Container.h"
 #include "StationID.h"
@@ -30,40 +27,59 @@ class TClntCfgIface;
 #include "DUID.h"
 #include "ClntCfgIA.h"
 #include "ClntCfgPD.h"
-#include "ClntOptVendorSpec.h"
+#include "OptVendorSpecInfo.h"
+#include "Opt.h"
 
 class TClntCfgIface
 {
-	friend std::ostream& operator<<(std::ostream&,TClntCfgIface&);
+    friend std::ostream& operator<<(std::ostream&,TClntCfgIface&);
 public:
+
+    class TOptionStatus
+    {
+    public:
+	TOptionStatus(): OptionType(0), State(STATE_NOTCONFIGURED), Option(0), Always(true) {};
+	unsigned short OptionType;
+	EState State;
+	SPtr<TOpt> Option;
+	TOpt::EOptionLayout Layout;
+	bool Always; // should this option be sent always? (even when already configured?)
+    };
+    typedef std::list< SPtr<TOptionStatus> > TOptionStatusLst;
+
     TClntCfgIface(string ifaceName);
     TClntCfgIface(int ifaceNr);
 
-    bool isServerRejected(SmartPtr<TIPv6Addr> addr,SmartPtr<TDUID> duid);
+    void setRouting(bool enabled);
+    bool isRoutingEnabled();
+    EState getRoutingEnabledState();
+    void setRoutingEnabledState(EState state);
+
+    bool isServerRejected(SPtr<TIPv6Addr> addr,SPtr<TDUID> duid);
 
     // IA
     void firstIA();
     int countIA();
     SPtr<TClntCfgIA> getIA();
     SPtr<TClntCfgIA> getIA(int iaid);
-    void addIA(SmartPtr<TClntCfgIA> ptr);
+    void addIA(SPtr<TClntCfgIA> ptr);
 
     // PD
     void firstPD();
     int countPD();
     SPtr<TClntCfgPD> getPD();
     SPtr<TClntCfgPD> getPD(int iaid);
-    void addPD(SmartPtr<TClntCfgPD> ptr);
-    
+    void addPD(SPtr<TClntCfgPD> ptr);
+
     // TA
     void firstTA();
-    void addTA(SmartPtr<TClntCfgTA> ta);
-    SmartPtr<TClntCfgTA> getTA();
+    void addTA(SPtr<TClntCfgTA> ta);
+    SPtr<TClntCfgTA> getTA();
     int countTA();
 
     string getName(void);
     string getFullName(void);
-    void setOptions(SmartPtr<TClntParsGlobalOpt> opt);
+    void setOptions(SPtr<TClntParsGlobalOpt> opt);
     int	getID(void);
     void setNoConfig();
     void setIfaceID(int ifaceID);
@@ -169,8 +185,15 @@ public:
     EState getVendorSpecState();
     void setVendorSpecState(EState state);
     void firstVendorSpec();
-    SPtr<TClntOptVendorSpec> getVendorSpec();
+    SPtr<TOptVendorSpecInfo> getVendorSpec();
     int getVendorSpecCount();
+    void setVendorSpec(List(TOptVendorSpecInfo) vendorSpecList);
+
+    // --- custom/extra options ---
+    void addExtraOption(SPtr<TOpt> extra, TOpt::EOptionLayout layout, bool sendAlways);
+    void addExtraOption(int optType, TOpt::EOptionLayout layout, bool sendAlways);
+    TOptionStatusLst& getExtraOptions();
+    SPtr<TOptionStatus> getExtaOptionState(int type);
 
     // --- option: KeyGeneration ---
     EState getKeyGenerationState();
@@ -181,6 +204,7 @@ public:
     void setAuthenticationState(EState state);
 
 private:
+    void setDefaults();
     string IfaceName;
     int ID;
     bool NoConfig;
@@ -195,7 +219,7 @@ private:
     List(TStationID) RejectedSrvLst;
 
     List(TClntCfgTA) ClntCfgTALst;
-    
+
     List(TIPv6Addr) DNSServerLst;
     List(string) DomainLst;
     List(TIPv6Addr) NTPServerLst;
@@ -207,8 +231,8 @@ private:
     List(TIPv6Addr) NISPServerLst;
     string NISDomain;
     string NISPDomain;
-    List(TClntOptVendorSpec) VendorSpec;
-    
+    List(TOptVendorSpecInfo) VendorSpecLst;
+
     EState DNSServerState;
     EState DomainState;
     EState NTPServerState;
@@ -225,6 +249,7 @@ private:
     EState VendorSpecState;
     EState KeyGenerationState;
     EState AuthenticationState;
+    EState RoutingEnabledState;
 
     bool ReqDNSServer;
     bool ReqDomain;
@@ -240,6 +265,9 @@ private:
     bool ReqLifetime;
     bool ReqPrefixDelegation;
     bool ReqVendorSpec;
+    bool RoutingEnabled;
+
+    TOptionStatusLst ExtraOpts; // extra options to be sent to server
 };
 
-#endif 
+#endif
