@@ -27,35 +27,40 @@ class TClntIfaceIface;
 #include "IPv6Addr.h"
 #include "ClntMsg.h"
 
-typedef enum {
-    PREFIX_MODIFY_ADD,
-    PREFIX_MODIFY_UPDATE,
-    PREFIX_MODIFY_DEL
-} PrefixModifyMode;
+#define ClntIfaceMgr() (TClntIfaceMgr::instance())
 
 class TClntIfaceMgr : public TIfaceMgr
 {
+public:
+	typedef enum {
+		PREFIX_MODIFY_ADD,
+		PREFIX_MODIFY_UPDATE,
+		PREFIX_MODIFY_DEL
+	} PrefixModifyMode;
+
+ private:
+    TClntIfaceMgr(string xmlFile); // this is singleton
+    
  public:
-    TClntIfaceMgr(string xmlFile);
+    static void instanceCreate(const std::string xmlFile);
+    static TClntIfaceMgr& instance();
+
     ~TClntIfaceMgr();
     friend ostream & operator <<(ostream & strum, TClntIfaceMgr &x);
     void dump();
     
-    bool sendUnicast(int iface, char *msg, int size, SmartPtr<TIPv6Addr> addr);
+    bool sendUnicast(int iface, char *msg, int size, SPtr<TIPv6Addr> addr);
     
     bool sendMulticast(int iface, char *msg, int msgsize);
     
-    SmartPtr<TClntMsg> select(unsigned int timeout);
+    SPtr<TClntMsg> select(unsigned int timeout);
 
-    void setContext(SmartPtr<TClntIfaceMgr> clntIfaceMgr,
-		    SmartPtr<TClntTransMgr> clntTransMgr,
-		    SmartPtr<TClntCfgMgr>   clntCfgMgr,
-		    SmartPtr<TClntAddrMgr>  clntAddrMgr);
+#ifdef MOD_REMOTE_AUTOCONF
+    bool notifyRemoteScripts(SPtr<TIPv6Addr> receivedAddr, SPtr<TIPv6Addr> serverAddr, int ifindex);
+#endif    
 
-    void notifyScripts(int msgType, int ifindex);
-
-    bool fqdnAdd(SmartPtr<TClntIfaceIface> iface, string domainname);
-    bool fqdnDel(SmartPtr<TClntIfaceIface> iface, SmartPtr<TAddrIA> ia, string domainname);
+    bool fqdnAdd(SPtr<TClntIfaceIface> iface, string domainname);
+    bool fqdnDel(SPtr<TClntIfaceIface> iface, SPtr<TAddrIA> ia, string domainname);
 
     bool addPrefix   (int iface, SPtr<TIPv6Addr> prefix, int prefixLen, unsigned int pref, unsigned int valid);
     bool updatePrefix(int iface, SPtr<TIPv6Addr> prefix, int prefixLen, unsigned int pref, unsigned int valid);
@@ -71,13 +76,12 @@ class TClntIfaceMgr : public TIfaceMgr
     void redetectIfaces();
 
   private:
-    bool modifyPrefix(int iface, SPtr<TIPv6Addr> prefix, int prefixLen, unsigned int pref, unsigned int valid, PrefixModifyMode mode);
+    bool modifyPrefix(int iface, SPtr<TIPv6Addr> prefix, int prefixLen, unsigned int pref, 
+		      unsigned int valid, PrefixModifyMode mode);
 
     string XmlFile;
-    SmartPtr<TClntCfgMgr> ClntCfgMgr;
-    SmartPtr<TClntAddrMgr> ClntAddrMgr;
-    SmartPtr<TClntTransMgr> ClntTransMgr;
-    SmartPtr<TClntIfaceMgr> That;
+
+    static TClntIfaceMgr * Instance;
 };
 
 #endif 
