@@ -23,36 +23,26 @@
 class TClntMsg : public TMsg
 {
 public:
-    TClntMsg(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-	     SmartPtr<TClntTransMgr> TransMgr, 
-	     SmartPtr<TClntCfgMgr> CfgMgr,
-	     SmartPtr<TClntAddrMgr> AddrMgr,
-	     int iface, SmartPtr<TIPv6Addr> addr, char* buf, int bufSize);
+    TClntMsg(int iface, SPtr<TIPv6Addr> addr, char* buf, int bufSize);
     
-    TClntMsg(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-	     SmartPtr<TClntTransMgr> TransMgr, 
-	     SmartPtr<TClntCfgMgr> CfgMgr,
-	     SmartPtr<TClntAddrMgr> AddrMgr,
-	     int iface, SmartPtr<TIPv6Addr> addr, int msgType);
+    TClntMsg(int iface, SPtr<TIPv6Addr> addr, int msgType);
+    ~TClntMsg();
     unsigned long getTimeout();
     void send();
+    SPtr<TOpt> parseExtraOption(const char *buf, unsigned int code, unsigned int length);
 
     //answer for a specific message
     virtual void doDuties() = 0;
     virtual bool check() = 0;
     void setIface(int iface); // used to override when we have received msg via loopback interface.
 
-    void copyAAASPI(SmartPtr<TClntMsg> q);
+    void copyAAASPI(SPtr<TClntMsg> q);
     void appendTAOptions(bool switchToInProcess); // append all TAs, which are currently in the NOTCONFIGURED state
 //    void appendPDOptions(bool switchToInProcess); // append all PDs, which are currently in the NOTCONFIGURED state
 
-    void appendAuthenticationOption(SmartPtr<TClntAddrMgr> AddrMgr);
+    void appendAuthenticationOption();
     void appendElapsedOption();
     void appendRequestedOptions();
-    SmartPtr<TClntTransMgr>  getClntTransMgr();
-    SmartPtr<TClntAddrMgr>   getClntAddrMgr();
-    SmartPtr<TClntCfgMgr>    getClntCfgMgr();
-    SmartPtr<TClntIfaceMgr>  getClntIfaceMgr();
 
     bool validateReplayDetection();
 
@@ -71,16 +61,9 @@ public:
     int RT;             // Retransmission timeout (in seconds)
     int FirstTimeStamp; // timestamp of the first transmission
     int LastTimeStamp;  // timestamp of the last transmission
-    SmartPtr<TClntTransMgr>  ClntTransMgr;
-    SmartPtr<TClntAddrMgr>   ClntAddrMgr;
-    SmartPtr<TClntCfgMgr>    ClntCfgMgr;
-    SmartPtr<TClntIfaceMgr>  ClntIfaceMgr;
 
  private:
-    void setAttribs(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-		    SmartPtr<TClntTransMgr> TransMgr, 
-		    SmartPtr<TClntCfgMgr>   CfgMgr,
-		    SmartPtr<TClntAddrMgr>  AddrMgr);
+    void setDefaults();
     void invalidAllowOptInMsg(int msg, int opt);
     void invalidAllowOptInOpt(int msg, int parentOpt, int childOpt);
 };
