@@ -18,23 +18,15 @@
 class TClntMsgAdvertise : public TClntMsg
 {
   public:
-    TClntMsgAdvertise(SmartPtr<TClntIfaceMgr> IfaceMgr,
-		      SmartPtr<TClntTransMgr> TransMgr,
-		      SmartPtr<TClntCfgMgr>   CfgMgr,
-		      SmartPtr<TClntAddrMgr>  AddrMgr,
-		      int iface, SmartPtr<TIPv6Addr> addr);
+    /* TClntMsgAdvertise(int iface, SPtr<TIPv6Addr> addr); */
     
-    TClntMsgAdvertise(SmartPtr<TClntIfaceMgr> IfaceMgr,
-		      SmartPtr<TClntTransMgr> TransMgr,
-		      SmartPtr<TClntCfgMgr> CfgMgr,
-		      SmartPtr<TClntAddrMgr> AddrMgr,
-		      int iface, SmartPtr<TIPv6Addr> addr, 
-		      char* buf, int bufSize);
+    TClntMsgAdvertise(int iface, SPtr<TIPv6Addr> addr, 
+                      char* buf, int bufSize);
     
     // returns preference value (default value is 0)
     int getPreference();
     bool check();
-    void answer(SmartPtr<TClntMsg> Rep);
+    void answer(SPtr<TClntMsg> Rep);
     void doDuties();
     string getName();
     string getInfo();
