@@ -16,28 +16,23 @@ class TClntMsgRebind;
 
 #include "ClntMsg.h"
 #include "ClntOptIA_NA.h"
-#include "ClntOptServerIdentifier.h"
-#include "ClntOptClientIdentifier.h"
-#include "ClntOptServerUnicast.h"
+#include "OptDUID.h"
+#include "OptAddr.h"
 
 class TClntMsgRebind : public TClntMsg
 {
   public:
-    TClntMsgRebind(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-		   SmartPtr<TClntTransMgr> TransMgr, 
-		   SmartPtr<TClntCfgMgr> CfgMgr, 
-		   SmartPtr<TClntAddrMgr> AddrMgr,
-		   TContainer<SmartPtr<TOpt> > ptrOpts, int iface);
+    TClntMsgRebind(TOptList ptrOpts, int iface);
     
-    void answer(SmartPtr<TClntMsg> Rep);
+    void answer(SPtr<TClntMsg> Rep);
     void doDuties();
     bool check();
     string getName();
     ~TClntMsgRebind();
  private:
-    void updateIA(SmartPtr <TClntOptIA_NA> ptrOptIA,
-		  SmartPtr<TClntOptServerIdentifier> optSrvDUID, 
-		  SmartPtr<TClntOptServerUnicast> optUnicast);
+    void updateIA(SPtr<TClntOptIA_NA> ptrOptIA,
+		  SPtr<TOptDUID> optSrvDUID, 
+		  SPtr<TOptAddr> optUnicast);
     void releaseIA(int IAID);
     void releasePD(int IAID);
 
