@@ -8,7 +8,7 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: ClntMsgRenew.cpp,v 1.22 2008-08-29 00:07:28 thomson Exp $
+ * $Id: ClntMsgRenew.cpp,v 1.23 2009-03-24 23:17:17 thomson Exp $
  *
  */
 
@@ -16,22 +16,17 @@
 #include "DHCPConst.h"
 #include "ClntOptIA_NA.h"
 #include "ClntOptIA_PD.h"
-#include "ClntOptClientIdentifier.h"
-#include "ClntOptServerIdentifier.h"
+#include "OptDUID.h"
 #include "ClntOptOptionRequest.h"
 #include "ClntOptStatusCode.h"
 #include "Logger.h"
-#include "SmartPtr.h"
-
+#include "ClntTransMgr.h"
+#include "ClntIfaceMgr.h"
 #include <cmath>
 
-TClntMsgRenew::TClntMsgRenew(SmartPtr<TClntIfaceMgr> IfaceMgr,
-			     SmartPtr<TClntTransMgr> TransMgr,
-			     SmartPtr<TClntCfgMgr> CfgMgr,
-			     SmartPtr<TClntAddrMgr> AddrMgr,
-			     List(TAddrIA) IALst,
-			     List(TAddrIA) PDLst)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr,AddrMgr, 0, 0, RENEW_MSG)
+TClntMsgRenew::TClntMsgRenew(List(TAddrIA) IALst,
+                             List(TAddrIA) PDLst)
+    :TClntMsg(0, 0, RENEW_MSG)
 {
    // set transmission parameters
     IRT=REN_TIMEOUT;
@@ -72,46 +67,46 @@ TClntMsgRenew::TClntMsgRenew(SmartPtr<TClntIfaceMgr> IfaceMgr,
         RT=MRD;
 
     // store our DUID
-    Options.append(new TClntOptClientIdentifier(CfgMgr->getDUID(),this));
+    Options.push_back(new TOptDUID(OPTION_CLIENTID, ClntCfgMgr().getDUID(), this));
 
     // and say who's this message is for
     if (IALst.count())
-	Options.append( new TClntOptServerIdentifier(IALst.getFirst()->getDUID(),this));
+      	Options.push_back( new TOptDUID(OPTION_SERVERID,IALst.getFirst()->getDUID(),this));
     else
-	Options.append( new TClntOptServerIdentifier(PDLst.getFirst()->getDUID(),this));
+	Options.push_back( new TOptDUID(OPTION_SERVERID,PDLst.getFirst()->getDUID(),this));
     
     //Store all IAs to renew
     IALst.first();
     while(ia=IALst.get()) {
-	if (timeout > ia->getT2Timeout())
-	    timeout = ia->getT2Timeout();
-	Options.append(new TClntOptIA_NA(ia,this));
+	      if (timeout > ia->getT2Timeout())
+	          timeout = ia->getT2Timeout();
+	      Options.push_back(new TClntOptIA_NA(ia,this));
     }
 
     PDLst.first();
     while (ia=PDLst.get()) {
-	if (timeout > ia->getT2Timeout())
-	    timeout = ia->getT2Timeout();
-	Options.append(new TClntOptIA_PD(ia, this));
+	      if (timeout > ia->getT2Timeout())
+	          timeout = ia->getT2Timeout();
+	      Options.push_back(new TClntOptIA_PD(ia, this));
     }
 
     appendRequestedOptions();
-    appendAuthenticationOption(AddrMgr);
+    appendAuthenticationOption();
 
-    pkt = new char[getSize()];
-    this->IsDone = false;
-    this->send();
+    IsDone = false;
+    send();
 }
 
-void TClntMsgRenew::answer(SmartPtr<TClntMsg> Reply)
+
+void TClntMsgRenew::answer(SPtr<TClntMsg> Reply)
 {
-    SmartPtr<TOpt> opt;
-    
+    SPtr<TOpt> opt;
+    unsigned int iaCnt = 0; 
     // get DUID
-    SmartPtr<TClntOptServerIdentifier> ptrDUID;
-    ptrDUID = (Ptr*) this->getOption(OPTION_SERVERID);
+    SPtr<TOptDUID> srvDUID;
+    srvDUID = (Ptr*) this->getOption(OPTION_SERVERID);
     
-    SmartPtr<TClntOptOptionRequest> ptrOptionReqOpt=(Ptr*)getOption(OPTION_ORO);
+    SPtr<TClntOptOptionRequest> ptrOptionReqOpt=(Ptr*)getOption(OPTION_ORO);
 
     Reply->firstOption();
     // for each option in message... (there should be only one IA option, as we send 
@@ -119,30 +114,44 @@ void TClntMsgRenew::answer(SmartPtr<TClntMsg> Reply)
     while ( opt = Reply->getOption() ) {
         switch (opt->getOptType()) {
 	case OPTION_IA_NA: {
-	    SmartPtr<TClntOptIA_NA> ptrOptIA = (Ptr*)opt;
+	    iaCnt++;
+	    SPtr<TClntOptIA_NA> ptrOptIA = (Ptr*)opt;
 	    if (ptrOptIA->getStatusCode()!=STATUSCODE_SUCCESS) {
-		SmartPtr<TClntOptStatusCode> status = (Ptr*) ptrOptIA->getOption(OPTION_STATUS_CODE);
-		Log(Warning) << "Received IA (iaid=" << ptrOptIA->getIAID() << ") with status code " << 
-		    StatusCodeToString(status->getCode()) << ": " 
-			     << status->getText() << LogEnd;
-		break;
+		if(ptrOptIA->getStatusCode() == STATUSCODE_NOBINDING){
+		    ClntTransMgr().sendRequest(Options, Iface);
+		    IsDone = true;
+		    return;
+		}else{
+		    SPtr<TClntOptStatusCode> status = (Ptr*) ptrOptIA->getOption(OPTION_STATUS_CODE);
+  		    Log(Warning) << "Received IA (iaid=" << ptrOptIA->getIAID() << ") with status code " << 
+		        StatusCodeToString(status->getCode()) << ": " 
+			         << status->getText() << LogEnd;
+	  	    break;
+		}
 	    }
-	    ptrOptIA->setContext(ClntIfaceMgr, ClntTransMgr, ClntCfgMgr, ClntAddrMgr,
-			         ptrDUID->getDUID(), SmartPtr<TIPv6Addr>() /*NULL*/, Reply->getIface());
+	    ptrOptIA->setContext(srvDUID->getDUID(), 0, Reply->getIface());
 
 	    ptrOptIA->doDuties();
 	    break;
 	}
 	case OPTION_IA_PD: {
+	    iaCnt++;
 	    SPtr<TClntOptIA_PD> pd = (Ptr*) opt;
 	    if (pd->getStatusCode() != STATUSCODE_SUCCESS) {
-		SmartPtr<TClntOptStatusCode> status = (Ptr*) pd->getOption(OPTION_STATUS_CODE);
-		Log(Warning) << "Received PD (iaid=" << pd->getIAID() << ") with status code " << 
-		    StatusCodeToString(status->getCode()) << ": " 
-			     << status->getText() << LogEnd;
-		break;
+		if(pd->getStatusCode() == STATUSCODE_NOBINDING){
+		    ClntTransMgr().sendRequest(Options,Iface);
+		    IsDone = true;
+		    return;
+		}
+		else{
+	            SPtr<TClntOptStatusCode> status = (Ptr*) pd->getOption(OPTION_STATUS_CODE);
+		    Log(Warning) << "Received PD (iaid=" << pd->getIAID() << ") with status code " << 
+		        StatusCodeToString(status->getCode()) << ": " 
+			         << status->getText() << LogEnd;
+		    break;
+		}
 	    }
-	    pd->setContext(ClntIfaceMgr, ClntTransMgr, ClntCfgMgr, ClntAddrMgr, ptrDUID->getDUID(), 0, (TMsg*)this);
+	    pd->setContext(srvDUID->getDUID(), 0, (TMsg*)this);
 	    pd->doDuties();
 	    break;
 	}
@@ -165,18 +174,16 @@ void TClntMsgRenew::answer(SmartPtr<TClntMsg> Reply)
     //There is no use to send Rebind even if server realesed some addresses/IAs
     //in such a case new Solicit message should be sent
     IsDone = true;
-
-    ClntIfaceMgr->notifyScripts(RENEW_MSG, Iface);
 }
 
 /** 
  * @brief changes IA state to not cofigured.
  * 
- * @param IAID 
+ * @param iaid
  */
-void TClntMsgRenew::releaseIA(long IAID)
+void TClntMsgRenew::releaseIA(long iaid)
 {
-    SPtr<TAddrIA> ia = getClntAddrMgr()->getIA(IAID);
+    SPtr<TAddrIA> ia = ClntAddrMgr().getIA(iaid);
     if(ia){
         ia->setState(STATE_NOTCONFIGURED);
     }  
@@ -184,13 +191,13 @@ void TClntMsgRenew::releaseIA(long IAID)
 
 void TClntMsgRenew::doDuties()
 {
-    // FIXME: increase RT from REN_TIMEOUT to REN_MAX_RT
+    /// @todo: increase RT from REN_TIMEOUT to REN_MAX_RT
 
     // should we send RENEW once more or start sending REBIND
     if (!MRD) 
     {
-	Log(Notice) << "RENEW remains unanswered and timeout T2 reached. " << LogEnd;
-        ClntTransMgr->sendRebind(this->Options,this->getIface());
+	Log(Notice) << "RENEW remains unanswered and timeout T2 reached, so REBIND will be sent." << LogEnd;
+        ClntTransMgr().sendRebind(Options,getIface());
         IsDone = true;
         return;
     }
@@ -208,8 +215,5 @@ string TClntMsgRenew::getName() {
     return "RENEW";
 }
 
-TClntMsgRenew::~TClntMsgRenew()
-{
-    delete [] pkt;
-    pkt = NULL;
+TClntMsgRenew::~TClntMsgRenew() {
 }
