@@ -1,4 +1,4 @@
-	/*
+/*
  * Dibbler - a portable DHCPv6
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
@@ -12,27 +12,14 @@
 
 #include "SmartPtr.h"
 #include "ClntMsgReply.h"
-#include "ClntMsg.h"
+#include "ClntOptIAAddress.h"
 
-TClntMsgReply::TClntMsgReply(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-			     SmartPtr<TClntTransMgr> TransMgr, 
-			     SmartPtr<TClntCfgMgr> CfgMgr, 
-			     SmartPtr<TClntAddrMgr> AddrMgr,
-			     int iface, SmartPtr<TIPv6Addr> addr)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr, AddrMgr, iface, addr,REPLY_MSG)
+TClntMsgReply::TClntMsgReply(int iface, SPtr<TIPv6Addr> addr, char* buf, int bufSize)
+    :TClntMsg(iface, addr,buf,bufSize)
 {
 }
 
-TClntMsgReply::TClntMsgReply(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-			     SmartPtr<TClntTransMgr> TransMgr, 
-			     SmartPtr<TClntCfgMgr> CfgMgr, 
-			     SmartPtr<TClntAddrMgr> AddrMgr,
-			     int iface, SmartPtr<TIPv6Addr> addr, char* buf, int bufSize)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr, AddrMgr, iface, addr,buf,bufSize)
-{
-}
-
-void TClntMsgReply::answer(SmartPtr<TClntMsg> Reply) {
+void TClntMsgReply::answer(SPtr<TClntMsg> Reply) {
     // this should never happen. After receiving REPLY for e.g. REQUEST,
     // request->answer(reply) is called. Client nevers sends reply msg, so
     // this method will never be called.
@@ -41,16 +28,32 @@ void TClntMsgReply::answer(SmartPtr<TClntMsg> Reply) {
 void TClntMsgReply::doDuties() {
 }
 
-
 bool TClntMsgReply::check() {
-    bool anonInfReq = ClntCfgMgr->anonInfRequest();
+    bool anonInfReq = ClntCfgMgr().anonInfRequest();
     return TClntMsg::check(!anonInfReq /* clientID mandatory */, true /* serverID mandatory */ );
 }
 
-
 string TClntMsgReply::getName() {
     return "REPLY";
 }
 
+SPtr<TIPv6Addr> TClntMsgReply::getFirstAddr() {
+    firstOption();
+    SPtr<TOpt> opt, subopt;
+    while (opt=getOption()) {
+	if (opt->getOptType() != OPTION_IA_NA)
+	    continue;
+	opt->firstOption();
+	while (subopt=opt->getOption()) {
+	    if (subopt->getOptType() != OPTION_IAADDR)
+		continue;
+	    SPtr<TOptIAAddress> optAddr = (Ptr*) subopt;
+	    return optAddr->getAddr();
+	}
+    }
+
+    return 0;
+}
+
 TClntMsgReply::~TClntMsgReply() {
 }
