@@ -8,37 +8,32 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: ClntMsgRequest.cpp,v 1.28 2008-08-29 00:07:28 thomson Exp $
+ * $Id: ClntMsgRequest.cpp,v 1.29 2009-03-24 23:17:17 thomson Exp $
  *
  */
 
 #include "ClntMsgRequest.h"
 #include "SmartPtr.h"
 #include "DHCPConst.h"
+#include "OptDUID.h"
+#include "OptAddr.h"
 #include "ClntIfaceMgr.h"
 #include "ClntMsgAdvertise.h"
-#include "ClntOptServerIdentifier.h"
-#include "ClntOptServerUnicast.h"
 #include "ClntOptIA_NA.h"
 #include "ClntOptTA.h"
 #include "ClntOptIA_PD.h"
 #include "ClntOptElapsed.h"
-#include "ClntOptClientIdentifier.h"
 #include "ClntOptOptionRequest.h"
+#include "ClntOptStatusCode.h"
+#include "ClntTransMgr.h"
 #include <cmath>
 #include "Logger.h"
 
 /*
  * opts - options list WITHOUT serverDUID
  */
-TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-				 SmartPtr<TClntTransMgr> TransMgr,
-				 SmartPtr<TClntCfgMgr>   CfgMgr, 
-				 SmartPtr<TClntAddrMgr> AddrMgr, 
-				 List(TOpt) opts, 
-				 
-				 int iface)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr,AddrMgr,iface, SmartPtr<TIPv6Addr>() /*NULL*/, REQUEST_MSG) {
+TClntMsgRequest::TClntMsgRequest(TOptList opts, int iface)
+    :TClntMsg(iface, 0, REQUEST_MSG) {
     IRT = REQ_TIMEOUT;
     MRT = REQ_MAX_RT;
     MRC = REQ_MAX_RC;
@@ -48,7 +43,7 @@ TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
     Iface=iface;
     IsDone=false;
 
-    int backupCount = TransMgr->getAdvertiseLstCount();
+    int backupCount = ClntTransMgr().getAdvertiseLstCount();
     if (!backupCount) 
     {
 	Log(Error) << "Unable to send REQUEST. There are no backup servers left." << LogEnd;
@@ -59,39 +54,41 @@ TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
     }
     Log(Info) << "Creating REQUEST. Backup server list contains " 
 	      << backupCount << " server(s)." << LogEnd;
-    TransMgr->printAdvertiseLst();
+    ClntTransMgr().printAdvertiseLst();
 
     // get server DUID from the first advertise
-    SPtr<TOpt> srvDUID = TransMgr->getAdvertiseDUID();
+    SPtr<TOpt> srvDUID = ClntTransMgr().getAdvertiseDUID();
 
-    TransMgr->firstAdvertise();
-    SPtr<TClntMsgAdvertise> advertise = (Ptr*) TransMgr->getAdvertise();
-    this->copyAAASPI((SmartPtr<TClntMsg>)advertise);
+    ClntTransMgr().firstAdvertise();
+    SPtr<TClntMsgAdvertise> advertise = (Ptr*) ClntTransMgr().getAdvertise();
+    this->copyAAASPI((SPtr<TClntMsg>)advertise);
 
     // remove just used server
-    TransMgr->delFirstAdvertise();
+    ClntTransMgr().delFirstAdvertise();
 
     // copy whole list from SOLICIT ...
     Options = opts;
+
     // set proper Parent in copied options
-    Options.first();
-    SmartPtr<TOpt> opt;
-    while (opt = Options.get()) {
-        // delete OPTION_AAAAUTH (needed only in SOLICIT)
-        if (opt->getOptType() == OPTION_AAAAUTH)
-            Options.del();
-        else
-            opt->setParent(this);
+    TOptList::iterator opt=Options.begin();
+    while (opt!=Options.end())
+    {
+        if ( (*opt)->getOptType() == OPTION_AAAAUTH || (*opt)->getOptType() == OPTION_ELAPSED_TIME)
+	          opt = Options.erase(opt);
+        else {
+	          (*opt)->setParent(this);
+            ++opt;
+        }
     }
 
     // delete OPTION_KEYGEN from OPTION_ORO (needed only once)
-    // FIXME: shouldn't it be done when receiving OPTION_KEYGEN in ADVERTISE?
-    SmartPtr<TClntOptOptionRequest> optORO = (Ptr*) this->getOption(OPTION_ORO);
+    /// @todo: shouldn't it be done when receiving OPTION_KEYGEN in ADVERTISE?
+    SPtr<TClntOptOptionRequest> optORO = (Ptr*) this->getOption(OPTION_ORO);
     if (optORO) {
         if (advertise->getOption(OPTION_KEYGEN))
             optORO->delOption(OPTION_KEYGEN);
         // delete also OPTION_AUTH from OPTION_ORO
-        // FIXME: shouldn't it be done when receiving OPTION_AUTH in ADVERTISE?
+        /// @todo: shouldn't it be done when receiving OPTION_AUTH in ADVERTISE?
         if (advertise->getOption(OPTION_AUTH))
             optORO->delOption(OPTION_AUTH);
     }
@@ -99,29 +96,32 @@ TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
     // copy addresses offered in ADVERTISE
     copyAddrsFromAdvertise((Ptr*) advertise);
 
+    copyPrefixesFromAdvertise((Ptr*) advertise);
+
     // does this server support unicast?
-    SmartPtr<TClntCfgIface> cfgIface = CfgMgr->getIface(iface);
+    SPtr<TClntCfgIface> cfgIface = ClntCfgMgr().getIface(iface);
     if (!cfgIface) {
 	Log(Error) << "Unable to find interface with ifindex " << iface << "." << LogEnd;    
 	IsDone = true;
 	return;
     }
-    SmartPtr<TClntOptServerUnicast> unicast = (Ptr*) advertise->getOption(OPTION_UNICAST);
+    SPtr<TOptAddr> unicast = (Ptr*) advertise->getOption(OPTION_UNICAST);
     if (unicast && !cfgIface->getUnicast()) {
 	Log(Info) << "Server offers unicast (" << *unicast->getAddr() 
 		  << ") communication, but this client is not configured to so." << LogEnd;
     }
     if (unicast && cfgIface->getUnicast()) {
 	Log(Debug) << "Server supports unicast on address " << *unicast->getAddr() << "." << LogEnd;
+
 	//this->PeerAddr = unicast->getAddr();
-	Options.first();
-	SmartPtr<TOpt> opt;
+	firstOption();
+	SPtr<TOpt> opt;
 	// set this unicast address in each IA in AddrMgr
-	while (opt = Options.get()) {
+	while ( opt = getOption() ) {
 	    if (opt->getOptType()!=OPTION_IA_NA)
 		continue;
-	    SmartPtr<TClntOptIA_NA> ptrOptIA = (Ptr*) opt;
-	    SmartPtr<TAddrIA> ptrAddrIA = AddrMgr->getIA(ptrOptIA->getIAID());
+	    SPtr<TClntOptIA_NA> ptrOptIA = (Ptr*) opt;
+	    SPtr<TAddrIA> ptrAddrIA = ClntAddrMgr().getIA(ptrOptIA->getIAID());
 	  
 	    if (!ptrAddrIA) {
 		Log(Crit) << "IA with IAID=" << ptrOptIA->getIAID() << " not found." << LogEnd;
@@ -133,22 +133,17 @@ TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
     }
     
     // ... and append server's DUID from ADVERTISE
-    Options.append( srvDUID );
+    Options.push_back( srvDUID );
     
-    appendAuthenticationOption(AddrMgr);
-
-    pkt = new char[getSize()];
-
+    appendElapsedOption();
+    appendAuthenticationOption();
+    IsDone = false;
+    send();
 }
 
-TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr, 
-				 SmartPtr<TClntTransMgr> TransMgr,
-				 SmartPtr<TClntCfgMgr>   CfgMgr, 
-				 SmartPtr<TClntAddrMgr> AddrMgr, 
-				 TContainer<SmartPtr<TAddrIA> > IAs,
-				 SmartPtr<TDUID> srvDUID,
-				 int iface)
-    :TClntMsg(IfaceMgr,TransMgr,CfgMgr,AddrMgr,iface,SmartPtr<TIPv6Addr>()/*NULL*/,REQUEST_MSG) {
+TClntMsgRequest::TClntMsgRequest(List(TAddrIA) IAs,
+				 SPtr<TDUID> srvDUID, int iface)
+    :TClntMsg(iface, 0, REQUEST_MSG) {
     IRT = REQ_TIMEOUT;
     MRT = REQ_MAX_RT;
     MRC = REQ_MAX_RC;
@@ -157,9 +152,9 @@ TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
 
     Iface=iface;
     IsDone=false;
-    SmartPtr<TOpt> ptr;
-    ptr = new TClntOptClientIdentifier( CfgMgr->getDUID(), this );
-    Options.append( ptr );
+    SPtr<TOpt> ptr;
+    ptr = new TOptDUID(OPTION_CLIENTID, ClntCfgMgr().getDUID(), this );
+    Options.push_back( ptr );
 
     if (!srvDUID) {
 	Log(Error) << "Unable to send REQUEST: ServerId not specified.\n" << LogEnd;
@@ -167,36 +162,61 @@ TClntMsgRequest::TClntMsgRequest(SmartPtr<TClntIfaceMgr> IfaceMgr,
 	return;
     }
     
-    ptr = (Ptr*) SmartPtr<TClntOptServerIdentifier> (new TClntOptServerIdentifier(srvDUID,this));
+    ptr = (Ptr*) new TOptDUID(OPTION_SERVERID, srvDUID,this);
     // all IAs provided by checkSolicit
-    SmartPtr<TAddrIA> ClntAddrIA;
-    Options.append( ptr );
+    SPtr<TAddrIA> ClntAddrIA;
+    Options.push_back( ptr );
 	
     IAs.first();
     while (ClntAddrIA = IAs.get()) 
     {
-        SmartPtr<TClntCfgIA> ClntCfgIA = 
-            ClntCfgMgr->getIA(ClntAddrIA->getIAID());
-	SmartPtr<TClntOptIA_NA> IA_NA =
-	    new TClntOptIA_NA(ClntCfgIA, ClntAddrIA, this);
-	Options.append((Ptr*)IA_NA);
+        SPtr<TClntCfgIA> ClntCfgIA = ClntCfgMgr().getIA(ClntAddrIA->getIAID());
+        SPtr<TClntOptIA_NA> IA_NA = new TClntOptIA_NA(ClntCfgIA, ClntAddrIA, this);
+        Options.push_back((Ptr*)IA_NA);
     }
 
     appendElapsedOption();
-    appendAuthenticationOption(AddrMgr);
+    appendAuthenticationOption();
 
     pkt = new char[getSize()];
+    this->IsDone = false;
+    this->send();
 }
 
 /*
  * analyse REPLY received for this REQUEST
  */
-void TClntMsgRequest::answer(SmartPtr<TClntMsg> msg)
+void TClntMsgRequest::answer(SPtr<TClntMsg> msg)
 {
     this->copyAAASPI(msg);
-    TClntMsg::answer(msg);
 
-    ClntIfaceMgr->notifyScripts(REQUEST_MSG, Iface);
+#ifdef MOD_CLNT_CONFIRM    
+    /* CHANGED here: When the client receives a NotOnLink status from the server in
+     * response to a Request, the client can either re-issue the Request
+     * without specifying any addresses or restart the DHCP server discovery
+     * process.
+     */  
+    SPtr<TOptStatusCode> optStateCode = (Ptr*)msg->getOption(OPTION_STATUS_CODE);
+    if( optStateCode && STATUSCODE_NOTONLINK == optStateCode->getCode()){
+	SPtr<TOpt> opt;
+	firstOption();
+	while(opt = getOption()){
+	    if(opt->getOptType() != OPTION_IA_NA){
+		continue;
+	    }
+	    SPtr<TClntOptIA_NA> IA_NA = (Ptr*)opt;
+	    IA_NA->firstOption();
+	    SPtr<TOpt> subOpt;
+	    while( subOpt = IA_NA->getOption()){
+		if(subOpt->getOptType() == OPTION_IAADDR)
+		    IA_NA->delOption();
+	    }
+	} 
+	return;   
+    }
+#endif
+     
+    TClntMsg::answer(msg);
 }
 
 void TClntMsgRequest::doDuties()
@@ -204,10 +224,10 @@ void TClntMsgRequest::doDuties()
     // timeout is reached and we still don't have answer, retransmit
     if (RC>MRC) 
     {
-	ClntTransMgr->sendRequest(Options, Iface);
+        ClntTransMgr().sendRequest(Options, Iface);
 
-	IsDone = true;
-	return;
+        IsDone = true;
+        return;
     }
     send();
     return;
@@ -227,9 +247,10 @@ string TClntMsgRequest::getName() {
  * on the backup list. When this method is called, it is sure that some IAs, TA or PDs will
  * remain not configured (as there are no servers available, which could configure it)
  * 
- * @param List 
+ * @param options list of still unconfigured options 
+ * @param state state to be set in CfgMgr
  */
-void TClntMsgRequest::setState(List(TOpt) opts, EState state)
+void TClntMsgRequest::setState(TOptList options, EState state)
 {
     SPtr<TOpt>          opt;
     SPtr<TClntOptIA_NA> ia;
@@ -240,18 +261,18 @@ void TClntMsgRequest::setState(List(TOpt) opts, EState state)
     SPtr<TClntCfgTA> cfgTa;
     SPtr<TClntCfgPD> cfgPd;
 
-    SPtr<TClntCfgIface> iface = ClntCfgMgr->getIface(Iface);
+    SPtr<TClntCfgIface> iface = ClntCfgMgr().getIface(Iface);
     if (!iface) {
-	Log(Error) << "Unable to find interface with ifindex=" << Iface << LogEnd;
-	return;
+	      Log(Error) << "Unable to find interface with ifindex=" << Iface << LogEnd;
+	      return;
     }
 
-    opts.first();
-    while ( opt = opts.get() ) {
-	switch (opt->getOptType()) {
+    for (TOptList::iterator opt = options.begin(); opt!=options.end(); ++opt)
+    {
+	switch ( (*opt)->getOptType()) {
 	case OPTION_IA_NA:
 	{
-	    ia = (Ptr*) opt;
+	    ia = (Ptr*) (*opt);
 	    cfgIa = iface->getIA(ia->getIAID());
 	    if (cfgIa)
 		cfgIa->setState(state);
@@ -259,7 +280,7 @@ void TClntMsgRequest::setState(List(TOpt) opts, EState state)
 	}
 	case OPTION_IA_TA:
 	{
-	    ia = (Ptr*) opt;
+	    ia = (Ptr*) (*opt);
 	    iface->firstTA();
 	    cfgTa = iface->getTA();
 	    if (cfgTa)
@@ -268,13 +289,13 @@ void TClntMsgRequest::setState(List(TOpt) opts, EState state)
 	}
 	case OPTION_IA_PD:
 	{
-	    pd = (Ptr*) opt;
+	    pd = (Ptr*) (*opt);
 	    cfgPd = iface->getPD(pd->getIAID());
 	    if (cfgPd)
 		cfgPd->setState(state);
 	    break;
 	}
-	default:
+      	default:
 	    continue;
 	}
     }
@@ -282,13 +303,16 @@ void TClntMsgRequest::setState(List(TOpt) opts, EState state)
 
 void TClntMsgRequest::copyAddrsFromAdvertise(SPtr<TClntMsg> adv)
 {
+    if (ClntCfgMgr().insistMode())
+        return; // insist-mode on, so ask for the address user specified again
+
     SPtr<TOpt> opt1, opt2, opt3;
     SPtr<TClntOptIA_NA> ia1, ia2;
 
     this->copyAAASPI(adv);
 
-    Options.first();
-    while (opt1 = Options.get()) {
+    firstOption();
+    while (opt1 = getOption()) {
 	if (opt1->getOptType()!=OPTION_IA_NA)
 	    continue; // ignore all options except IA_NA
 	adv->firstOption();
@@ -308,6 +332,40 @@ void TClntMsgRequest::copyAddrsFromAdvertise(SPtr<TClntMsg> adv)
 		if (opt3->getOptType() == OPTION_IAADDR)
 		    ia1->addOption(opt3);
 	    }
+	}
+    }
+}
+
+void TClntMsgRequest::copyPrefixesFromAdvertise(SPtr<TClntMsg> adv)
+{
+    if (ClntCfgMgr().insistMode())
+        return; // insist-mode on, so ask for the address user specified again
+
+    SPtr<TOpt> opt1, opt2, opt3;
+    SPtr<TClntOptIA_PD> ia1, ia2;
+
+    this->copyAAASPI(adv);
+
+    firstOption();
+    while (opt1 = getOption()) {
+	if (opt1->getOptType()!=OPTION_IA_PD)
+	    continue; // ignore all options except IA_NA
+	adv->firstOption();
+	while (opt2 = adv->getOption()) {
+	    if (opt2->getOptType() != OPTION_IA_PD)
+		continue;
+	    ia1 = (Ptr*) opt1;
+	    ia2 = (Ptr*) opt2;
+	    if (ia1->getIAID() != ia2->getIAID())
+		continue;
+
+	    // found IA_PD in ADVERTISE, now copy all addrs
+	    ia1->delAllOptions();
+	    ia2->firstOption();
+	    while (opt3 = ia2->getOption()) {
+		if (opt3->getOptType() == OPTION_IAPREFIX)
+		    ia1->addOption(opt3);
+	    }
 
 	}
     }
@@ -315,8 +373,5 @@ void TClntMsgRequest::copyAddrsFromAdvertise(SPtr<TClntMsg> adv)
 
 }
 
-TClntMsgRequest::~TClntMsgRequest()
-{
-    delete [] pkt;
-    pkt=NULL;
+TClntMsgRequest::~TClntMsgRequest() {
 }
