@@ -7,10 +7,7 @@
  *
  * $Id: ClntOptAAAAuthentication.cpp,v 1.2 2008-08-29 00:07:28 thomson Exp $
  *
- * $Log: ClntOptAAAAuthentication.cpp,v $
- * Revision 1.2  2008-08-29 00:07:28  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2008-02-25 20:42:45  thomson
  * Missing new AUTH files added.
  *
@@ -26,7 +23,7 @@ TClntOptAAAAuthentication::TClntOptAAAAuthentication( char * buf,  int n, TMsg*
 TClntOptAAAAuthentication::TClntOptAAAAuthentication(TClntMsg* parent)
     :TOptAAAAuthentication(parent)
 {
-    this->setAAASPI(parent->getClntCfgMgr()->getAAASPI());
+    this->setAAASPI(ClntCfgMgr().getAAASPI());
 }
 
 bool TClntOptAAAAuthentication::doDuties()
