@@ -5,10 +5,7 @@
  *
  * $Id: ClntOptFQDN.h,v 1.3 2006-10-06 00:42:13 thomson Exp $
  *
- * $Log: ClntOptFQDN.h,v $
- * Revision 1.3  2006-10-06 00:42:13  thomson
- * Initial PD support.
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.2  2006-03-02 00:59:22  thomson
  * ClntOptFQDN implemented for real.
  *
@@ -35,9 +32,9 @@ class TClntOptFQDN : public TOptFQDN
     TClntOptFQDN(string fqdn, TMsg* parent);
     TClntOptFQDN(char *buf, int bufsize, TMsg* parent);
     bool doDuties();
-    void setSrvDuid(SmartPtr<TDUID> duid);
+    void setSrvDuid(SPtr<TDUID> duid);
 private:
-    SmartPtr<TDUID> SrvDUID;
+    SPtr<TDUID> SrvDUID;
 };
 
 
