@@ -2,6 +2,7 @@
  * Dibbler - a portable DHCPv6
  *
  * author: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ * changes: Tomasz Mrugalski <thomson(at)klub.com.pl>
  *
  * released under GNU GPL v2 only licence
  *
@@ -18,7 +19,7 @@ class TClntOptIAPrefix : public TOptIAPrefix
 {
  public:
     TClntOptIAPrefix(char *addr,int n, TMsg* parent);
-    TClntOptIAPrefix(SmartPtr<TIPv6Addr> addr, long pref, long valid, char prefix_length, TMsg* parent);
+    TClntOptIAPrefix(SPtr<TIPv6Addr> addr, long pref, long valid, char prefix_length, TMsg* parent);
     bool doDuties();
     bool isValid();
 };
