@@ -6,8 +6,6 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: ClntOptIA_NA.cpp,v 1.24 2008-08-29 00:07:29 thomson Exp $
- *
  */
 
 #include "AddrIA.h"
@@ -17,6 +15,9 @@
 #include "ClntOptStatusCode.h"
 #include "ClntOptAddrParams.h"
 #include "Logger.h"
+#include "Msg.h"
+#include "ClntAddrMgr.h"
+#include "ClntIfaceMgr.h"
 
 /** 
  * Used in CONFIRM constructor
@@ -25,11 +26,11 @@
  * @param zeroTimes 
  * @param parent 
  */
-TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TAddrIA> clntAddrIA, bool zeroTimes, TMsg* parent)
+TClntOptIA_NA::TClntOptIA_NA(SPtr<TAddrIA> clntAddrIA, bool zeroTimes, TMsg* parent)
     :TOptIA_NA(clntAddrIA->getIAID(), zeroTimes?0:clntAddrIA->getT1(),
 	       zeroTimes?0:clntAddrIA->getT2(), parent) 
 {
-    SmartPtr <TAddrAddr> addr;
+    SPtr <TAddrAddr> addr;
     clntAddrIA->firstAddr();
     while ( addr = clntAddrIA->getAddr() ) {
 	SubOptions.append( new TClntOptIAAddress(addr->get(),
@@ -46,7 +47,7 @@ TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TAddrIA> clntAddrIA, bool zeroTimes, TMsg*
  * @param addrIA 
  * @param parent 
  */
-TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TAddrIA> addrIA, TMsg* parent)
+TClntOptIA_NA::TClntOptIA_NA(SPtr<TAddrIA> addrIA, TMsg* parent)
     :TOptIA_NA(addrIA->getIAID(),addrIA->getT1(),addrIA->getT2(), parent)
 {
     // should we include all addrs or tentative ones only?
@@ -63,7 +64,7 @@ TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TAddrIA> addrIA, TMsg* parent)
 	zeroTimes = true;
     }
 
-    SmartPtr<TAddrAddr> ptrAddr;
+    SPtr<TAddrAddr> ptrAddr;
     addrIA->firstAddr();
     while ( ptrAddr = addrIA->getAddr() )
     {
@@ -71,7 +72,7 @@ TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TAddrIA> addrIA, TMsg* parent)
 	    SubOptions.append(new TClntOptIAAddress(ptrAddr->get(), zeroTimes?0:ptrAddr->getPref(), 
 						    zeroTimes?0:ptrAddr->getValid(),this->Parent) );
     }
-    DUID = SmartPtr<TDUID>(); // NULL
+    DUID = SPtr<TDUID>(); // NULL
 }
 
 /** 
@@ -81,16 +82,16 @@ TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TAddrIA> addrIA, TMsg* parent)
  * @param ClntaddrIA 
  * @param parent 
  */
-TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TClntCfgIA> ClntCfgIA, SmartPtr<TAddrIA> ClntaddrIA, TMsg* parent)
+TClntOptIA_NA::TClntOptIA_NA(SPtr<TClntCfgIA> ClntCfgIA, SPtr<TAddrIA> ClntaddrIA, TMsg* parent)
     :TOptIA_NA(ClntaddrIA->getIAID(),ClntaddrIA->getT1(),ClntaddrIA->getT2(), parent)
 {
     //checkRequestConstructor
     ClntCfgIA->firstAddr();
-    SmartPtr<TClntCfgAddr> ClntCfgAddr;
+    SPtr<TClntCfgAddr> ClntCfgAddr;
     while ((ClntCfgAddr = ClntCfgIA->getAddr())&&
         ((ClntCfgIA->countAddr()-ClntaddrIA->getAddrCount())>this->countAddr() ))
     {
-        SmartPtr<TAddrAddr> ptrAddr=ClntaddrIA->getAddr(ClntCfgAddr->get());
+        SPtr<TAddrAddr> ptrAddr=ClntaddrIA->getAddr(ClntCfgAddr->get());
         if(!ptrAddr)
             SubOptions.append(new TClntOptIAAddress(
             ClntCfgAddr->get(),
@@ -98,7 +99,7 @@ TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TClntCfgIA> ClntCfgIA, SmartPtr<TAddrIA> C
             ClntCfgAddr->getValid(),
             this->Parent));
     }
-    DUID = SmartPtr<TDUID>(); // NULL
+    DUID = SPtr<TDUID>(); // NULL
 }
 
 /** 
@@ -107,17 +108,17 @@ TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TClntCfgIA> ClntCfgIA, SmartPtr<TAddrIA> C
  * @param ClntCfgIA 
  * @param parent 
  */
-TClntOptIA_NA::TClntOptIA_NA(SmartPtr<TClntCfgIA> ClntCfgIA, TMsg* parent)
+TClntOptIA_NA::TClntOptIA_NA(SPtr<TClntCfgIA> ClntCfgIA, TMsg* parent)
     :TOptIA_NA(ClntCfgIA->getIAID(),ClntCfgIA->getT1(),ClntCfgIA->getT2(), parent)
 {
     ClntCfgIA->firstAddr();
-    SmartPtr<TClntCfgAddr> ClntCfgAddr;
+    SPtr<TClntCfgAddr> ClntCfgAddr;
     // just copy all addresses defined in the CfgMgr
     while (ClntCfgAddr = ClntCfgIA->getAddr())
         SubOptions.append(new TClntOptIAAddress(ClntCfgAddr->get(),
         ClntCfgAddr->getPref(),
         ClntCfgAddr->getValid(),this->Parent) ); 
-    DUID = SmartPtr<TDUID>(); // NULL
+    DUID = SPtr<TDUID>(); // NULL
 }
 
 /** 
@@ -148,7 +149,6 @@ TClntOptIA_NA::TClntOptIA_NA(char * buf,int bufsize, TMsg* parent)
                 switch (code)
                 {
                 case OPTION_IAADDR:
-                    //  SmartPtr<TOptIAAddress> ptr;
                     SubOptions.append( new TClntOptIAAddress(buf+pos,length,this->Parent));
                     break;
                 case OPTION_STATUS_CODE:
@@ -179,21 +179,21 @@ void TClntOptIA_NA::firstAddr()
     SubOptions.first();
 }
 
-SmartPtr<TClntOptIAAddress> TClntOptIA_NA::getAddr()
+SPtr<TClntOptIAAddress> TClntOptIA_NA::getAddr()
 {
-    SmartPtr<TClntOptIAAddress> ptr;
+    SPtr<TClntOptIAAddress> ptr;
     do {
         ptr = (Ptr*) SubOptions.get();
         if (ptr)
             if (ptr->getOptType()==OPTION_IAADDR)
                 return ptr;
     } while (ptr);
-    return SmartPtr<TClntOptIAAddress>();
+    return SPtr<TClntOptIAAddress>();
 }
 
 int TClntOptIA_NA::countAddr()
 {
-    SmartPtr< TOpt> ptr;
+    SPtr< TOpt> ptr;
     SubOptions.first();
     int count = 0;
     while ( ptr = SubOptions.get() ) {
@@ -205,59 +205,46 @@ int TClntOptIA_NA::countAddr()
 
 int TClntOptIA_NA::getStatusCode()
 {
-    SmartPtr<TOpt> option;
+    SPtr<TOpt> option;
     if (option=getOption(OPTION_STATUS_CODE))
     {
-        SmartPtr<TClntOptStatusCode> statOpt=(Ptr*) option;
+        SPtr<TClntOptStatusCode> statOpt=(Ptr*) option;
         return statOpt->getCode();
     }
     return STATUSCODE_SUCCESS;
 }
 
-void TClntOptIA_NA::setContext(SmartPtr<TClntIfaceMgr> ifaceMgr, 
-                               SmartPtr<TClntTransMgr> transMgr, 
-                               SmartPtr<TClntCfgMgr> cfgMgr, 
-                               SmartPtr<TClntAddrMgr> addrMgr,
-                               SmartPtr<TDUID> srvDuid, SmartPtr<TIPv6Addr> srvAddr, int iface)
+void TClntOptIA_NA::setContext(SPtr<TDUID> srvDuid, SPtr<TIPv6Addr> srvAddr, int iface)
 {
-    this->AddrMgr=addrMgr;
-    this->IfaceMgr=ifaceMgr;
-    this->TransMgr=transMgr;
-    this->CfgMgr=cfgMgr;
-    this->DUID=srvDuid;
+    DUID=srvDuid;
     if (srvAddr) {
-        this->Unicast = true;
+        Unicast = true;
     } else {
-        this->Unicast = false;
+        Unicast = false;
     }
-    this->Addr=srvAddr;
-    this->Iface = iface;
+    Addr = srvAddr;
+    Iface = iface;
 }
 
-TClntOptIA_NA::~TClntOptIA_NA()
-{
+TClntOptIA_NA::~TClntOptIA_NA() {
 
 }
 
-//I don't know whether this method should be invoked everywhere
-//i.e. from Verify\Renew\Rebind
-//it's worth to check whether futher reactions in every message will 
-//be the same e.g. detection of duplicate address, lack of enough
-//addresses
-bool TClntOptIA_NA::doDuties()
-{
+
+bool TClntOptIA_NA::doDuties() {
+
     // find this IA in addrMgr...
-    SmartPtr<TAddrIA> ptrIA=AddrMgr->getIA(this->getIAID());
+    SPtr<TAddrIA> ptrIA=ClntAddrMgr().getIA(this->getIAID());
     if (!ptrIA) {
         // unknown IAID, ignore it
-	Log(Warning) << "Received message contains unknown IA (IAID="
-            << this->getIAID() << "). We didn't order it. Weird... ignoring it." << LogEnd;
+        Log(Warning) << "Received message contains unknown IA (IAID="
+                     << this->getIAID() << "). We didn't order it. Weird... ignoring it." << LogEnd;
         return true;
     }
 
     // IAID found, set up new received options.
-    SmartPtr<TAddrAddr> ptrAddrAddr;
-    SmartPtr<TClntOptIAAddress> ptrOptAddr;
+    SPtr<TAddrAddr> ptrAddrAddr;
+    SPtr<TClntOptIAAddress> ptrOptAddr;
 
 #if 0
     //if not we don't like this server, cause
@@ -273,9 +260,9 @@ bool TClntOptIA_NA::doDuties()
         //or the server doesn't want to prolong lease.
 
         ptrIA->firstAddr();
-        while(SmartPtr<TAddrAddr> addrToRel=ptrIA->getAddr()) {
-	    SmartPtr<TIPv6Addr> addr2(addrToRel->get());
-            IfaceMgr->getIfaceByID(ptrIA->getIface())->delAddr(addr2);
+        while(SPtr<TAddrAddr> addrToRel=ptrIA->getAddr()) {
+	    SPtr<TIPv6Addr> addr2(addrToRel->get());
+            ClntIfaceMgr().getIfaceByID(ptrIA->getIface())->delAddr(addr2);
 	}
 
         this->firstAddr();
@@ -305,8 +292,8 @@ bool TClntOptIA_NA::doDuties()
         List(TAddrIA) list;
         list.append(ptrIA);
 
-        AddrMgr->delIA(ptrIA->getIAID() );
-        AddrMgr->addIA(new TAddrIA(ptrIA->getIface(), SmartPtr<TIPv6Addr>(), SmartPtr<TDUID>(),
+        ClntAddrMgr().delIA(ptrIA->getIAID() );
+        ClntAddrMgr().addIA(new TAddrIA(ptrIA->getIface(), SPtr<TIPv6Addr>(), SPtr<TDUID>(),
 				   0x7fffffff,0x7fffffff,ptrIA->getIAID()));
 
 	List(TAddrIA) pdLst;
@@ -317,8 +304,8 @@ bool TClntOptIA_NA::doDuties()
     }
 #endif /* if 0 */
 
-    SmartPtr<TIfaceIface> ptrIface;
-    ptrIface = IfaceMgr->getIfaceByID(this->Iface);
+    SPtr<TIfaceIface> ptrIface;
+    ptrIface = ClntIfaceMgr().getIfaceByID(this->Iface);
     if (!ptrIface) 
     {
 	Log(Error) << "Interface with ifindex=" << this->Iface << " not found." << LogEnd;
@@ -363,7 +350,7 @@ bool TClntOptIA_NA::doDuties()
             }
 
             // set up new options in IfaceMgr
-            SmartPtr<TIfaceIface> ptrIface = IfaceMgr->getIfaceByID(this->Iface);
+            SPtr<TIfaceIface> ptrIface = ClntIfaceMgr().getIfaceByID(this->Iface);
             if (ptrIface)
                 ptrIface->updateAddr(ptrOptAddr->getAddr(), 
                         ptrOptAddr->getPref(), 
@@ -374,8 +361,8 @@ bool TClntOptIA_NA::doDuties()
             ptrAddrAddr->setTimestamp();
         }
     }
-    SmartPtr<TClntCfgIA> ptrCfgIA;
-    ptrCfgIA=CfgMgr->getIA(ptrIA->getIAID());
+    SPtr<TClntCfgIA> ptrCfgIA;
+    ptrCfgIA=ClntCfgMgr().getIA(ptrIA->getIAID());
 
     if (getT1() && getT2()) {
       ptrIA->setT1( this->getT1() );
@@ -401,13 +388,13 @@ bool TClntOptIA_NA::doDuties()
 //Counts all valid and diffrent addresses in sum of
 //addresses received in IA from server and addresses contained
 //in its counterpart IA in address manager
-int TClntOptIA_NA::countValidAddrs(SmartPtr<TAddrIA> ptrIA)
+int TClntOptIA_NA::countValidAddrs(SPtr<TAddrIA> ptrIA)
 {
     int count=0;
 
     //Counts addresses not received in Reply message
     //but which are in addrDB, and are still valid (valid>0)
-    SmartPtr<TAddrAddr> ptrAddr;
+    SPtr<TAddrAddr> ptrAddr;
     ptrIA->firstAddr();
     //For each addr in DB for this IA
     while(ptrAddr = ptrIA->getAddr())
@@ -422,7 +409,7 @@ int TClntOptIA_NA::countValidAddrs(SmartPtr<TAddrIA> ptrIA)
     }
     
     //count all valid (valid>0) addresses received from server
-    //FIXME: A) check if they repeats (possible with maliciious server)
+    /// @todo: A) check if they repeats (possible with maliciious server)
     //       B) and not already assigned in addrDB (in others IAs)
     //       It's easy and worth checking
     //       A) Create list of valid addrs and add new valid addr 
@@ -430,7 +417,7 @@ int TClntOptIA_NA::countValidAddrs(SmartPtr<TAddrIA> ptrIA)
     //       B) Address can be assigned only in this IA, not in other
     //          This could be ommited if VerifyIA worked prooperly
     this->firstAddr();
-    SmartPtr<TClntOptIAAddress> ptrOptIAAddr;
+    SPtr<TClntOptIAAddress> ptrOptIAAddr;
     while(ptrOptIAAddr=this->getAddr())
     {
         if (!ptrOptIAAddr->getValid())
@@ -441,9 +428,9 @@ int TClntOptIA_NA::countValidAddrs(SmartPtr<TAddrIA> ptrIA)
     return count;
 }
 
-SmartPtr<TClntOptIAAddress> TClntOptIA_NA::getAddr(SmartPtr<TIPv6Addr> addr)
+SPtr<TClntOptIAAddress> TClntOptIA_NA::getAddr(SPtr<TIPv6Addr> addr)
 {
-    SmartPtr<TClntOptIAAddress> optAddr;
+    SPtr<TClntOptIAAddress> optAddr;
     this->firstAddr();
     while(optAddr=this->getAddr())
     {   
@@ -451,12 +438,12 @@ SmartPtr<TClntOptIAAddress> TClntOptIA_NA::getAddr(SmartPtr<TIPv6Addr> addr)
         if ((*addr)==(*optAddr->getAddr()))
             return optAddr;
     };
-    return SmartPtr<TClntOptIAAddress>();
+    return SPtr<TClntOptIAAddress>();
 }
 
-void TClntOptIA_NA::releaseAddr(long IAID, SmartPtr<TIPv6Addr> addr )
+void TClntOptIA_NA::releaseAddr(long IAID, SPtr<TIPv6Addr> addr )
 {
-    SmartPtr<TAddrIA> ptrIA = AddrMgr->getIA(IAID);
+    SPtr<TAddrIA> ptrIA = ClntAddrMgr().getIA(IAID);
     if (ptrIA)
         ptrIA->delAddr(addr);
     else
@@ -471,7 +458,7 @@ void TClntOptIA_NA::setIface(int iface) {
 
 bool TClntOptIA_NA::isValid()
 {
-    SmartPtr<TClntOptIAAddress> addr;
+    SPtr<TClntOptIAAddress> addr;
     this->firstAddr();
     while (addr = this->getAddr()) {
 	if (addr->getAddr()->linkLocal()) {
