@@ -7,10 +7,7 @@
  *
  * $Id: ClntOptKeyGeneration.cpp,v 1.2 2008-08-29 00:07:29 thomson Exp $
  *
- * $Log: ClntOptKeyGeneration.cpp,v $
- * Revision 1.2  2008-08-29 00:07:29  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2008-02-25 20:42:45  thomson
  * Missing new AUTH files added.
  *
@@ -23,15 +20,13 @@
 TClntOptKeyGeneration::TClntOptKeyGeneration( char * buf,  int n, TClntMsg* parent)
 	:TOptKeyGeneration(buf, n, parent)
 {
-    parent->getClntCfgMgr()->setDigest((DigestTypes)this->getAlgorithmId());
+    ClntCfgMgr().setDigest((DigestTypes)this->getAlgorithmId());
 }
 
 bool TClntOptKeyGeneration::doDuties()
 {
-    int ifindex = this->Parent->getIface();
-    TClntMsg * msg = (TClntMsg*)(this->Parent);
-    SmartPtr<TClntCfgMgr> cfgMgr = msg->getClntCfgMgr();
-    SmartPtr<TClntCfgIface> cfgIface = cfgMgr->getIface(ifindex);
+    int ifindex = Parent->getIface();
+    SPtr<TClntCfgIface> cfgIface = ClntCfgMgr().getIface(ifindex);
     cfgIface->setKeyGenerationState(STATE_CONFIGURED);
 
     return true;
