@@ -8,10 +8,7 @@
  *
  * $Id: ClntOptTimeZone.h,v 1.4 2008-08-29 00:07:29 thomson Exp $
  *
- * $Log: ClntOptTimeZone.h,v $
- * Revision 1.4  2008-08-29 00:07:29  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.3  2004-10-25 20:45:53  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
@@ -30,9 +27,9 @@ class TClntOptTimeZone : public TOptString
     TClntOptTimeZone(string domain, TMsg* parent);
     TClntOptTimeZone(char *buf, int bufsize, TMsg* parent);
     bool doDuties();
-    void setSrvDuid(SmartPtr<TDUID> duid);
+    void setSrvDuid(SPtr<TDUID> duid);
     bool isValid();
  private:
-    SmartPtr<TDUID> SrvDUID;
+    SPtr<TDUID> SrvDUID;
 };
 #endif
