@@ -17,25 +17,44 @@
 #include "Portable.h"
 #include "Logger.h"
 #include <stdio.h>
+#include "sha256.h"
 
-DNSUpdate::DNSUpdate(string dns_address, string zonename,string hostname,string hostip,
-		     DnsUpdateMode updateMode) { 
+DNSUpdate::DNSUpdate(string dns_address, string zonename, string hostname,
+		     string hostip, DnsUpdateMode updateMode,
+		     DnsUpdateProtocol proto /* = DNSUPDATE_TCP */)
+    :_hostname(NULL) { 
     message= NULL;
+    memset(&server, 0, sizeof(server));
+
+#ifndef WIN32	
+	// LINUX, BSD
+	server.ss_family = AF_INET6;
+#else
+	// WINDOWS
+	server.sa_family = AF_INET6;
+#endif
     
     if (updateMode==DNSUPDATE_AAAA || updateMode==DNSUPDATE_AAAA_CLEANUP) {
-	this->splitHostDomain(hostname);
+	splitHostDomain(hostname);
     } else {
-	this->hostname=new char[hostname.length()+1];
-	strcpy(this->hostname,hostname.c_str());
+        int len = hostname.length()+1;
+        _hostname=new char[len];
+        strncpy(_hostname,hostname.c_str(), len-1);
 	zoneroot = new domainname(zonename.c_str());
     }
     
     txt_to_addr(&server,dns_address.c_str());
-    this->hostip = new char[hostip.length()+1];
-    strcpy(this->hostip,hostip.c_str());
-    this->ttl=new char[strlen(DNSUPDATE_DEFAULT_TTL)+1];
-    strcpy(this->ttl,DNSUPDATE_DEFAULT_TTL);
+    int len = hostip.length()+1;
+    this->hostip = new char[len];
+    strncpy(this->hostip,hostip.c_str(), len-1);
+    hostip[len-1] = 0;
+    
+    len = strlen(DNSUPDATE_DEFAULT_TTL)+1;
+    this->ttl=new char[len];
+    strncpy(this->ttl,DNSUPDATE_DEFAULT_TTL, len-1);
+    ttl[len-1]=0;
     this->updateMode = updateMode;
+    _proto = proto;
 }
  
 DNSUpdate::~DNSUpdate() {
@@ -43,7 +62,7 @@ DNSUpdate::~DNSUpdate() {
 	delete message;
     delete zoneroot;
     delete [] hostip;
-    delete [] hostname;
+    delete [] _hostname;
     delete [] ttl;
 }
 
@@ -56,45 +75,51 @@ void DNSUpdate::splitHostDomain(string fqdnName) {
     std::string::size_type dotpos = fqdnName.find(".");
     string hostname = "";
     string domain = "";
+    if (_hostname) {
+	delete [] _hostname;
+	_hostname = 0;
+    }
+
     if (dotpos == string::npos) {
 	Log(Warning) << "Name provided for DNS update is not a FQDN. [" << fqdnName
 		     << "]." << LogEnd;
-	this->hostname = new char[fqdnName.length()+1];
-	strcpy(this->hostname, fqdnName.c_str());
+	int len = fqdnName.length()+1;
+	_hostname = new char[len];
+	strncpy(_hostname, fqdnName.c_str(), len -1);
     }
     else {
 	string hostname = fqdnName.substr(0, dotpos);
 	string domain = fqdnName.substr(dotpos + 1, fqdnName.length() - dotpos - 1);
-	this->hostname = new char[hostname.length()];
-	strcpy(this->hostname, hostname.c_str());
+	_hostname = new char[hostname.length()+1];
+	strncpy(_hostname, hostname.c_str(), hostname.length());
+	_hostname[hostname.length()] = 0; // make sure it is null terminated
 	this->zoneroot = new domainname(domain.c_str());
     }
 }
 
-
-DnsUpdateResult DNSUpdate::run(){
+DnsUpdateResult DNSUpdate::run(int timeout){
 
     switch (this->updateMode) {
     case DNSUPDATE_PTR:
-	Log(Debug) << "FQDN: Performing DNS Update: Only PTR record." << LogEnd;   
+	Log(Debug) << "DDNS: Performing DNS Update: Only PTR record." << LogEnd;   
 	this->createSOAMsg();
 	this->addinMsg_delOldRR();   
 	this->addinMsg_newPTR();
 	break;
     case DNSUPDATE_PTR_CLEANUP:
-	Log(Debug) << "FQDN: Performing DNS Cleanup: Only PTR record." << LogEnd;   
+	Log(Debug) << "DDNS: Performing DNS Cleanup: Only PTR record." << LogEnd;   
 	this->createSOAMsg();
 	this->addinMsg_delOldRR();   
 	this->deletePTRRecordFromRRSet();
 	break;
     case DNSUPDATE_AAAA:
-	Log(Debug) << "FQDN: Performing DNS Update: Only AAAA record." << LogEnd;   
+	Log(Debug) << "DDNS: Performing DNS Update: Only AAAA record." << LogEnd;   
 	this->createSOAMsg();
 	this->addinMsg_delOldRR();   
 	this->addinMsg_newAAAA();
 	break;
     case DNSUPDATE_AAAA_CLEANUP:
-	Log(Debug) << "FQDN: Performing DNS Cleanup: Only AAAA record." << LogEnd;   
+	Log(Debug) << "DDNS: Performing DNS Cleanup: Only AAAA record." << LogEnd;   
 	this->createSOAMsg();
 	this->addinMsg_delOldRR();   
 	this->deleteAAAARecordFromRRSet();
@@ -102,20 +127,20 @@ DnsUpdateResult DNSUpdate::run(){
     }
     
     try {
-	this->sendMsg();
+	sendMsg(timeout);
     } 
     catch (PException p) {
-	if (!strcmp(p.message,"Could not connect TCP socket") ){
-	    Log(Error) << "FQDN: Unable to establish connection to the DNS server:" << p.message << LogEnd;
-	    return DNSUPDATE_CONNFAIL;
-	}
+	DnsUpdateResult result = DNSUPDATE_ERROR;
+	if (strstr(p.message,"Could not connect TCP socket") ){
+	    result = DNSUPDATE_CONNFAIL;
+	} 
 	if (!strcmp(p.message,"NOTAUTH")){
-	    Log(Error) << "FQDN: Nameserver is not authoritative for this zone (" << p.message << ")" << LogEnd;	
-	    return DNSUPDATE_SRVNOTAUTH;
+	    Log(Error) << "DDNS: Nameserver returned NOTAUTH error." << LogEnd;	
+	    result = DNSUPDATE_SRVNOTAUTH;
 	}
 
-	Log(Error) << "FQDN: Error not specified (" << p.message << ")" << LogEnd;
-	return DNSUPDATE_ERROR;
+	Log(Error) << "DDNS error: " << p.message << "." << LogEnd;
+	return result;
      }// exeption catch
 
     return DNSUPDATE_SUCCESS;
@@ -137,7 +162,7 @@ void DNSUpdate::createSOAMsg(){
  */
 void DNSUpdate::addinMsg_newAAAA(){
     DnsRR rr;
-    rr.NAME = domainname(hostname, *zoneroot);
+    rr.NAME = domainname(_hostname, *zoneroot);
     rr.TYPE = qtype_getcode("AAAA", false);
     rr.TTL = txt_to_int(ttl);
     string data = rr_fromstring(rr.TYPE, hostip, *zoneroot);
@@ -145,7 +170,38 @@ void DNSUpdate::addinMsg_newAAAA(){
     rr.RDATA = (unsigned char*)memdup(data.c_str(), rr.RDLENGTH);
     
     message->authority.push_back(rr);
-    Log(Debug) << "FQDN: AAAA record created:" << rr.NAME.tostring() << " -> " << hostip << LogEnd;
+    Log(Debug) << "DDNS: AAAA record created:" << rr.NAME.tostring() << " -> " << hostip << LogEnd;
+}
+
+void DNSUpdate::addDHCID(const char* duid, int duidlen) {
+    DnsRR rr;
+    rr.NAME = domainname(_hostname, *zoneroot);
+    rr.TYPE = qtype_getcode("DHCID", false);
+    rr.TTL = txt_to_int(ttl);
+    
+
+    char input_buf[512];
+    char output_buf[35]; // identifier-type code (2) + digest type code (1) + digest (SHA-256 = 32 bytes)
+
+    memcpy(input_buf, duid, duidlen); // 
+    memcpy(input_buf+duidlen, rr.NAME.c_str(), strlen((const char*)rr.NAME.c_str()) );
+
+    sha256_buffer(input_buf, duidlen + strlen((const char*)rr.NAME.c_str() ),
+                  output_buf+3);
+   
+    output_buf[0] = 0;
+    output_buf[1] = 2; // identifier-type code: 0x0002 - DUID used as client identifier
+    output_buf[2] = 1; // digest type = 1 (SHA-256)
+
+    message->authority.push_back(rr);
+
+}
+
+void DNSUpdate::addTSIG(const char* key, int keylen) {
+    DnsRR rr;
+    // TODO
+
+    // message->additional.push_back(rr);
 }
 
 /** 
@@ -155,7 +211,7 @@ void DNSUpdate::addinMsg_newAAAA(){
  */
 void DNSUpdate::deleteAAAARecordFromRRSet(){
   DnsRR rr;
-  rr.NAME = domainname(hostname, *zoneroot);
+  rr.NAME = domainname(_hostname, *zoneroot);
   rr.TYPE = qtype_getcode("AAAA", false);
   rr.CLASS = QCLASS_NONE; /* 254 */
   rr.TTL = 0;
@@ -164,7 +220,7 @@ void DNSUpdate::deleteAAAARecordFromRRSet(){
   rr.RDATA = (unsigned char*)memdup(data.c_str(), rr.RDLENGTH);
   message->authority.push_back(rr);
 
-  Log(Debug) << "FQDN: AAAA record created:" << rr.NAME.tostring() << " -> " << hostip << LogEnd;
+  Log(Debug) << "DDNS: AAAA record created:" << rr.NAME.tostring() << " -> " << hostip << LogEnd;
 }
 
 void DNSUpdate::deletePTRRecordFromRRSet(){
@@ -180,13 +236,13 @@ void DNSUpdate::deletePTRRecordFromRRSet(){
   rr.TYPE = qtype_getcode("PTR", false);
   rr.CLASS = QCLASS_NONE;
   rr.TTL = 0;
-  string tmp  = hostname;
+  string tmp  = string(_hostname);
   string data = rr_fromstring(rr.TYPE, tmp.c_str()); 
   rr.RDLENGTH = data.size();
   rr.RDATA = (unsigned char*)memdup(data.c_str(), rr.RDLENGTH);
   message->authority.push_back(rr);
 
-  Log(Debug) << "FQDN: PTR record created: " << result << " -> " << tmp << LogEnd;
+  Log(Debug) << "DDNS: PTR record created: " << result << " -> " << tmp << LogEnd;
 }
 		
 /** 
@@ -204,13 +260,13 @@ void DNSUpdate::addinMsg_newPTR(){
   rr.NAME = result;
   rr.TYPE = qtype_getcode("PTR", false);
   rr.TTL = txt_to_int(ttl);
-  string tmp  = hostname;
+  string tmp  = string(_hostname);
   string data = rr_fromstring(rr.TYPE, tmp.c_str()); 
   rr.RDLENGTH = data.size();
   rr.RDATA = (unsigned char*)memdup(data.c_str(), rr.RDLENGTH);
   message->authority.push_back(rr);
 
-  Log(Debug) << "FQDN: PTR record created: " << result << " -> " << tmp << LogEnd;
+  Log(Debug) << "DDNS: PTR record created: " << result << " -> " << tmp << LogEnd;
 }
 
 /** 
@@ -238,123 +294,169 @@ void DNSUpdate::addinMsg_delOldRR(){
  */
 bool DNSUpdate::DnsRR_avail(DnsMessage *msg, DnsRR& RemoteDnsRR){
   
-  //check axfr_message 
-  bool flagSOA = false;
-  
-  
-  if (msg->answers.empty()) { delete msg; return false; }
-  
-  stl_list(DnsRR)::iterator it = msg->answers.begin();
-  
-  it++;
-     
-  while (it != msg->answers.end()) {
-
-   if (it->TYPE == DNS_TYPE_SOA) {
-       flagSOA = !flagSOA;
-   } 
-   else {
-    if (!flagSOA) {
-     
-     if ( !strcmp( hostname,(it->NAME.label(0)).c_str()) ){
-      RemoteDnsRR=*it;
-      delete msg;
-      return true;      
-     }
+    //check axfr_message 
+    bool flagSOA = false;
+    
+    if (msg->answers.empty()) { 
+	delete msg; 
+	return false; 
     }
-   }
-   it++;
-  }
-  delete msg;
   
-  return false;
+    stl_list(DnsRR)::iterator it = msg->answers.begin();
+  
+    it++;
+     
+    while (it != msg->answers.end()) {
+	
+	if (it->TYPE == DNS_TYPE_SOA) {
+	    flagSOA = !flagSOA;
+	} 
+	else {
+	    if (!flagSOA) {
+		
+		if ( !strcmp(_hostname,(it->NAME.label(0)).c_str()) ){
+		    RemoteDnsRR=*it;
+		    delete msg;
+		    return true;      
+		}
+	    }
+	}
+	it++;
+    }
+    delete msg;
+    
+    return false;
 }
- 
- 
-/** get old RR entry from Dns Server*/
- 
+
+/** get old RR entry from Dns Server */ 
 DnsRR* DNSUpdate::get_oldDnsRR(){
  
-  DnsRR* RemoteDnsRR= NULL;
-  DnsMessage *q = NULL, *a = NULL;
-  int sockid = -1;
+    DnsRR* RemoteDnsRR= NULL;
+    DnsMessage *q = NULL, *a = NULL;
+    int sockid = -1;
     
-  try {
-   q = create_query(*zoneroot, QTYPE_AXFR);
-   
-   pos_cliresolver res;   
-   sockid = res.tcpconnect(&server);  
-   res.tcpsendmessage(q, sockid);
-   
-   res.tcpwaitanswer(a, sockid);
-   if (a->RCODE != RCODE_NOERROR){    
+    try {
+	q = create_query(*zoneroot, QTYPE_AXFR);
+	
+	pos_cliresolver res;   
+	sockid = res.tcpconnect(&server);  
+	res.tcpsendmessage(q, sockid);
+	
+	res.tcpwaitanswer(a, sockid);
+	if (a->RCODE != RCODE_NOERROR){    
+	    
+	    throw PException((char*)str_rcode(a->RCODE).c_str()); 
+	}
+	if (!a->answers.empty())
+	    {
+		RemoteDnsRR = new DnsRR();
+		if (this->DnsRR_avail(a,*RemoteDnsRR) == false) 
+		    {   
+			delete RemoteDnsRR;
+			RemoteDnsRR = NULL;
+		    }
+	    }
+	
+	if (a) {
+	    // delete a; // FIXME: Why is this commented out? Memory leak!
+	    a = 0;
+	}
+	if (q) {
+	    delete q;
+	    q = 0;
+	}
+	
+	if (sockid != -1) 
+	    tcpclose(sockid);
+	
+	return RemoteDnsRR;
+	
+    } catch (PException p) {
+	if (q) {
+	    delete q;
+	    q = NULL;
+	}
 
-    throw PException((char*)str_rcode(a->RCODE).c_str()); 
-   }
-   if (!a->answers.empty())
-   {
-    RemoteDnsRR = new DnsRR();
-    if (this->DnsRR_avail(a,*RemoteDnsRR) == false) 
-    {   
-     delete RemoteDnsRR;
-     RemoteDnsRR = NULL;
-    }
-   }
-
-   if (a) {
-       //delete a;
-       a = 0;
-   }
-   if (q) {
-       delete q;
-       q = 0;
-   }
-   
-   if (sockid != -1) tcpclose(sockid);
-   
-   return RemoteDnsRR;
-   
-  } catch (PException p) {
-      if (q) delete q;
-      if (a) delete a;     
-      if (sockid != -1) tcpclose(sockid);
-      if (RemoteDnsRR) delete RemoteDnsRR;
-      Log(Error) << "FQDN: Attempt to get old DNS record failed." << LogEnd;
-      return 0;
-  } 
+	if (a) {
+	    delete a;
+	    a = NULL;
+	}
+	if (sockid != -1) 
+	    tcpclose(sockid);
+	if (RemoteDnsRR) 
+	    delete RemoteDnsRR;
+	Log(Error) << "DDNS: Attempt to get old DNS record failed." << LogEnd;
+	return 0;
+    } 
 }
- 
+
+void DNSUpdate::sendMsg(unsigned int timeout) {
+    switch (_proto) {
+    case DNSUPDATE_TCP:
+	Log(Debug) << "DDNS: Updating over TCP." << LogEnd;
+	sendMsgTCP(timeout);
+	return;
+    case DNSUPDATE_UDP:
+	Log(Debug) << "DDNS: Updating over UDP." << LogEnd;
+	sendMsgUDP(timeout);
+	return;
+    default:
+	Log(Error) << "DDNS: Invalid protocol (non-TCP, non-UDP) specified." << LogEnd;
+    }
+
+    return;
+}
+
 /** send Update Message to server*/
-void DNSUpdate::sendMsg(){
+void DNSUpdate::sendMsgTCP(unsigned int timeout){
     DnsMessage *a = NULL;
     int sockid = -1;
     
     try {
-	
 	pos_cliresolver res;
+	res.tcp_timeout = timeout;
 	sockid = res.tcpconnect(&server);
 	res.tcpsendmessage(message, sockid);
 	res.tcpwaitanswer(a, sockid);
-	if (a->RCODE != RCODE_NOERROR){
-	 
+	if (a->RCODE != RCODE_NOERROR) {
 	    throw PException((char*)str_rcode(a->RCODE).c_str());
 	}
-	else{			
-	
-	}		
     } catch (PException p) {
 	
-
-	
-	if (a) delete a;
-	if (sockid != -1) tcpclose(sockid);
+	if (a) 
+	    delete a;
+	if (sockid != -1) 
+	    tcpclose(sockid);
 	
 	throw PException(p.message);
-	
     }
 	
-    if (a) delete a;
-    if (sockid != -1) tcpclose(sockid);
+    if (a) 
+	delete a;
+    if (sockid != -1) 
+	tcpclose(sockid);
+}
+
+void DNSUpdate::sendMsgUDP(unsigned int timeout) {
+    DnsMessage *a = NULL;
+    try {
+	
+	pos_cliresolver res;
+	res.udp_tries[0] = timeout;
+	res.n_udp_tries = 1; // just one timeout
+	res.query(message, a, &server, Q_NOTCP);
+	if (a->RCODE != RCODE_NOERROR) {
+	    throw PException((char*)str_rcode(a->RCODE).c_str());
+	}
+    } catch (PException p) {
+	
+	if (a) 
+	    delete a;
+	throw PException(p.message);
+    }
+	
+    if (a) 
+	delete a;
 }
 
 /** 
@@ -367,21 +469,21 @@ void DNSUpdate::showResult(int result)
     switch (result) {
     case DNSUPDATE_SUCCESS:
 	if (this->updateMode == DNSUPDATE_AAAA || this->updateMode == DNSUPDATE_PTR)
-	    Log(Notice) << "FQDN: DNS Update (add) successful." << LogEnd;
+	    Log(Notice) << "DDNS: DNS Update (add) successful." << LogEnd;
 	else
-	    Log(Notice) << "FQDN: DNS Update (delete) successful." << LogEnd;
+	    Log(Notice) << "DDNS: DNS Update (delete) successful." << LogEnd;
 	break;
     case DNSUPDATE_ERROR:
-	Log(Warning) << "FQDN: DNS Update failed." << LogEnd;
+	Log(Warning) << "DDNS: DNS Update failed." << LogEnd;
 	break;
     case DNSUPDATE_CONNFAIL:
-	Log(Warning) << "FQDN: Unable to establish connection to the DNS server." << LogEnd;
+	Log(Warning) << "DDNS: Unable to establish connection to the DNS server." << LogEnd;
 	break;
     case DNSUPDATE_SRVNOTAUTH:
-	Log(Warning) << "FQDN: DNS Update failed: server is not not authoritative." << LogEnd;
+	Log(Warning) << "DDNS: DNS Update failed: server returned NOTAUTH." << LogEnd;
 	break;
     case DNSUPDATE_SKIP:
-	Log(Notice) << "FQDN: DNS Update was skipped." << LogEnd;
+	Log(Notice) << "DDNS: DNS Update was skipped." << LogEnd;
 	break;
     }
 }
