@@ -14,23 +14,25 @@ class TMsg;
 
 #include <iostream>
 #include <string>
+#include <list>
 #include "SmartPtr.h"
 #include "Container.h"
 #include "DHCPConst.h"
 #include "IPv6Addr.h"
 #include "Opt.h"
 #include "KeyList.h"
+#include "ScriptParams.h"
 
 // Hey! It's grampa of all messages
 class TMsg
 {
   public:
     // Used to create TMsg object (normal way)
-    TMsg(int iface, SmartPtr<TIPv6Addr> addr, int msgType);
-    TMsg(int iface, SmartPtr<TIPv6Addr> addr, int msgType, long transID);
+    TMsg(int iface, SPtr<TIPv6Addr> addr, int msgType);
+    TMsg(int iface, SPtr<TIPv6Addr> addr, int msgType, long transID);
 
     // used to create TMsg object based on received char[] data
-    TMsg(int iface, SmartPtr<TIPv6Addr> addr, char* &buf, int &bufSize);
+    TMsg(int iface, SPtr<TIPv6Addr> addr, char* &buf, int &bufSize);
     
     virtual int getSize();
     
@@ -43,19 +45,20 @@ class TMsg
     virtual string getName() = 0;
 
     // returns requested option (or NULL, there is no such option)
-    SmartPtr<TOpt> getOption(int type);
+    SPtr<TOpt> getOption(int type);
     void firstOption();
     int countOption();
 
-    virtual SmartPtr<TOpt> getOption();
+    virtual SPtr<TOpt> getOption();
     
     long getType();
     long getTransID();
-    TContainer< SmartPtr<TOpt> > getOptLst();
-    SmartPtr<TIPv6Addr> getAddr();
+    TOptList & getOptLst();
+    SPtr<TIPv6Addr> getAddr();
     int getIface();
     virtual ~TMsg();
     bool isDone();
+    bool isDone(bool done);
 
     // auth stuff below
     void setAuthInfoPtr(char* ptr);
@@ -74,23 +77,27 @@ class TMsg
     char* getKeyGenNonce();
     unsigned getKeyGenNonceLen();
     enum DigestTypes DigestType;
-    SmartPtr<KeyList> AuthKeys;
+    SPtr<KeyList> AuthKeys;
+
+    // notify scripts stuff
+    void* getNotifyScriptParams() { return NotifyScripts; }
 
   protected:
     int MsgType;
-
     long TransID;
 
-    List(TOpt) Options;
-    
-    void setAttribs(int iface, SmartPtr<TIPv6Addr> addr, 
+    bool delOption(int code);
+
+    TOptList Options;
+    TOptList::iterator NextOpt; // to be removed together with firstOption() and getOption();
+    void setAttribs(int iface, SPtr<TIPv6Addr> addr, 
 		    int msgType, long transID);
     virtual bool check(bool clntIDmandatory, bool srvIDmandatory);
     
     bool IsDone; // Is this transaction done?
     char * pkt;  // buffer where this packet will be build
     int Iface;   // interface from/to which message was received/should be sent
-    SmartPtr<TIPv6Addr> PeerAddr; // server/client address from/to which message was received/should be sent
+    SPtr<TIPv6Addr> PeerAddr; // server/client address from/to which message was received/should be sent
 
     // auth stuff below
     char * AuthInfoPtr; // pointer to Authentication Information field of OPTION AUTH and OPTION AAAAUTH
@@ -100,6 +107,11 @@ class TMsg
     uint32_t AAASPI; // AAA-SPI sent by client in OPTION_AAAAUTH
     char *KeyGenNonce;
     unsigned KeyGenNonceLen;
+
+    // a pointer to NotifyScriptParams structure (if defined)
+    TNotifyScriptParams * NotifyScripts;
 };
 
+typedef std::list< SPtr<TMsg> > TMsgLst;
+
 #endif
