@@ -8,10 +8,7 @@
  *
  * $Id: DHCPRelay.h,v 1.2 2005-02-01 00:57:36 thomson Exp $
  *
- * $Log: DHCPRelay.h,v $
- * Revision 1.2  2005-02-01 00:57:36  thomson
- * no message
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2005/01/11 22:53:35  thomson
  * Relay skeleton implemented.
  *
@@ -22,7 +19,6 @@
 
 #include <iostream>
 #include <string>
-#include "RelCommon.h"
 
 using namespace std;
 
@@ -39,7 +35,6 @@ class TDHCPRelay
 
   private:
     bool IsDone;
-    TCtx Ctx;
 };
 
 #endif
