@@ -8,10 +8,7 @@
  *
  * $Id: OptAddr.h,v 1.1 2004-10-26 22:36:57 thomson Exp $
  *
- * $Log: OptAddr.h,v $
- * Revision 1.1  2004-10-26 22:36:57  thomson
- * *** empty log message ***
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.2  2004/09/05 15:27:49  thomson
  * Data receive switched from recvfrom to recvmsg, unicast partially supported.
  *
@@ -22,20 +19,21 @@
 #define OPTSERVERUNICAST_H
 
 #include "Opt.h"
-#include "DHCPConst.h"
 #include "SmartPtr.h"
 #include "IPv6Addr.h"
 
 class TOptAddr : public TOpt
 {
  public:
-    TOptAddr(int type, char * &buf,  int &n, TMsg* parent);
-    TOptAddr(int type, SmartPtr<TIPv6Addr> addr, TMsg * parent);
+    TOptAddr(int type, const char * buf, unsigned short len, TMsg* parent);
+    TOptAddr(int type, SPtr<TIPv6Addr> addr, TMsg * parent);
     int getSize();
     char * storeSelf( char* buf);
-    SmartPtr<TIPv6Addr> getAddr();
+    SPtr<TIPv6Addr> getAddr();
+    virtual bool doDuties() { return true; } // does nothing on its own
+    std::string getPlain();
  protected:
-    SmartPtr<TIPv6Addr> Addr;
+    SPtr<TIPv6Addr> Addr;
 };
 
 #endif
