@@ -6,34 +6,20 @@
  *
  * released under GNU GPL v2 licence
  *
- * $Id: OptAddrLst.cpp,v 1.1 2004-11-02 01:23:13 thomson Exp $
- *
- * $Log: OptAddrLst.cpp,v $
- * Revision 1.1  2004-11-02 01:23:13  thomson
- * Initial revision
- *
- * Revision 1.3  2004/03/29 18:53:08  thomson
- * Author/Licence/cvs log/cvs version headers added.
- *
  */
 
 
 #include <stdlib.h>
-#ifdef LINUX
-#include <netinet/in.h>
-#endif
-#ifdef WIN32
-#include <winsock2.h>
-#endif
+#include <sstream>
+#include "Portable.h"
 #include "OptAddrLst.h"
 #include "DHCPConst.h"
 
 TOptAddrLst::TOptAddrLst(int type, List(TIPv6Addr) lst, TMsg* parent)
     :TOpt(type, parent), AddrLst(lst) {
-    
 }
 
-TOptAddrLst::TOptAddrLst(int type, char* &buf,int &bufSize, TMsg* parent)
+TOptAddrLst::TOptAddrLst(int type, const char* buf, unsigned short bufSize, TMsg* parent)
     :TOpt(type, parent)
 {
     while(bufSize>0)
@@ -43,20 +29,18 @@ TOptAddrLst::TOptAddrLst(int type, char* &buf,int &bufSize, TMsg* parent)
 	    return;
 	}
         this->AddrLst.append(new TIPv6Addr(buf));
-        bufSize-=16;
-        buf+=16;
+	buf +=16;
+	bufSize -= 16;
     }
     Valid = true;
     return;
 }
 
 char * TOptAddrLst::storeSelf(char* buf) {
-    SmartPtr<TIPv6Addr> addr;
+    SPtr<TIPv6Addr> addr;
 
-    *(short*)buf = htons(OptType);
-    buf+=2;
-    *(short*)buf = htons(getSize()-4);
-    buf+=2;
+    buf = writeUint16(buf, OptType);
+    buf = writeUint16(buf, getSize()-4);
     AddrLst.first();
     while(addr=AddrLst.get())
 	buf=addr->storeSelf(buf);
@@ -72,7 +56,7 @@ void TOptAddrLst::firstAddr() {
     this->AddrLst.first();
 }
 
-SmartPtr<TIPv6Addr> TOptAddrLst::getAddr()
+SPtr<TIPv6Addr> TOptAddrLst::getAddr()
 {
     return this->AddrLst.get();
 }
@@ -82,3 +66,12 @@ bool TOptAddrLst::isValid()
     return this->Valid;
 }
 
+std::string TOptAddrLst::getPlain() {
+    stringstream tmp;
+    AddrLst.first();
+    SPtr<TIPv6Addr> addr;
+    while (addr = AddrLst.get()) {
+        tmp << addr->getPlain() << " ";
+    }
+    return tmp.str();
+}
