@@ -2,17 +2,9 @@
  * Dibbler - a portable DHCPv6
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
- *          Marek Senderski <msend@o2.pl>
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: OptAddrLst.h,v 1.2 2008-08-29 00:07:30 thomson Exp $
- *
- * $Log: not supported by cvs2svn $
- * Revision 1.1  2004-11-02 01:23:13  thomson
- * Initial revision
- *
- *
  */
 
 #ifndef OPTDNSSERVERS_H
@@ -31,6 +23,7 @@ public:
     int getSize();
     void firstAddr();
     SPtr<TIPv6Addr> getAddr();
+    const List(TIPv6Addr)& getAddrLst() { return AddrLst; }
     int countAddr();
     bool isValid();
     virtual bool doDuties() { return true; } // does nothing on its own
