@@ -6,33 +6,33 @@
  *
  * released under GNU GPL v2 licence
  *
- * $Id: OptIAAddress.cpp,v 1.7 2007-08-26 10:26:19 thomson Exp $
- *
  */
 
+//#include <netinet/in.h>
 #include <string.h>
 #include "Portable.h"
 #include "DHCPConst.h"
 #include "Opt.h"
 #include "OptIAAddress.h"
 
-TOptIAAddress::TOptIAAddress( char * &buf, int &n, TMsg* parent)
+TOptIAAddress::TOptIAAddress(char * &buf, int& n, TMsg* parent)
 	:TOpt(OPTION_IAADDR, parent)
 {
-    this->ValidOpt=false;
+    ValidOpt=false;
     if (n>=24)
     {
-        Addr=new TIPv6Addr(buf);
-        buf+= 16; n-=16;
-        this->Pref  = ntohl(*((long*)buf));
-        buf+= 4;  n-=4;
-        this->Valid = ntohl(*((long*)buf));
-        buf+= 4;  n-=4;    
-        this->ValidOpt=true;
+        Addr = new TIPv6Addr(buf);
+        buf += 16; n -= 16;
+        Pref = readUint32(buf);
+        buf += sizeof(uint32_t); n -= sizeof(uint32_t);
+        Valid = readUint32(buf);
+        buf += sizeof(uint32_t); n -= sizeof(uint32_t);
+
+        ValidOpt=true;
     }
 }
 
-TOptIAAddress::TOptIAAddress(SmartPtr<TIPv6Addr> addr, unsigned long pref, 
+TOptIAAddress::TOptIAAddress(SPtr<TIPv6Addr> addr, unsigned long pref, 
 			     unsigned long valid, TMsg* parent)
     :TOpt(OPTION_IAADDR, parent) {
     if(addr)
@@ -58,21 +58,23 @@ void TOptIAAddress::setValid(unsigned long valid) {
 
  char * TOptIAAddress::storeSelf( char* buf)
 {
-    *(uint16_t*)buf = htons(OptType);
-    buf+=2;
-    *(uint16_t*)buf = htons( getSize()-4 );
-    buf+=2;
+    buf = writeUint16(buf, OptType);
+
+    buf = writeUint16(buf, getSize() - 4 );
+
     memcpy(buf,Addr->getAddr(),16);
     buf+=16;
-    *(uint32_t*)buf = htonl(Pref);
-    buf+=4;
-    *(uint32_t*)buf = htonl(Valid);
-    buf+=4;
-	buf=storeSubOpt(buf);
+
+    buf = writeUint32(buf, Pref);
+
+    buf = writeUint32(buf, Valid);
+
+    buf=storeSubOpt(buf);
+
     return buf;
 }
 
- SmartPtr<TIPv6Addr> TOptIAAddress::getAddr()
+ SPtr<TIPv6Addr> TOptIAAddress::getAddr()
 {
 	return this->Addr;
 }
