@@ -2,10 +2,13 @@
  * Dibbler - a portable DHCPv6
  *
  * author: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ * changes: Tomasz Mrugalski <thomson(at)klub.com.pl>
  * 
  * released under GNU GPL v2 only licence
  *
  */
+
+#include <string.h>
 #include "Portable.h"
 #include "DHCPConst.h"
 #include "OptIAPrefix.h"
@@ -13,25 +16,22 @@
 TOptIAPrefix::TOptIAPrefix( char * &buf, int &n, TMsg* parent)
 	:TOpt(OPTION_IAPREFIX, parent)
 {
-    	
-	this->ValidOpt=false;
+    ValidOpt=false;
     if (n>=25) // was 24 for IA address
     {
-       
-	this->Pref  = ntohl(*((long*)buf));
-        buf+= 4;  n-=4;
-        this->Valid = ntohl(*((long*)buf));
-        buf+= 4;  n-=4;    
-	this->PrefixLength  = *buf;// was ntohl(*((char*)buf));
+        Pref = readUint32(buf);
+        buf += sizeof(uint32_t);  n -= sizeof(uint32_t);
+        Valid = readUint32(buf);
+        buf += sizeof(uint32_t);  n -= sizeof(uint32_t);
+        PrefixLength  = *buf;// was ntohl(*((char*)buf));
         buf+= 1;  n-=1;
-        this->Prefix=new TIPv6Addr(buf); // was buf
+        Prefix=new TIPv6Addr(buf); // was buf
         buf+= 16; n-=16;
-        this->ValidOpt=true;
-
-}
+        ValidOpt=true;
+    }
 }
 
-TOptIAPrefix::TOptIAPrefix(SmartPtr<TIPv6Addr> prefix, char prefixLength, unsigned long pref, unsigned long valid,
+TOptIAPrefix::TOptIAPrefix(SPtr<TIPv6Addr> prefix, char prefixLength, unsigned long pref, unsigned long valid,
 				 TMsg* parent)
     :TOpt(OPTION_IAPREFIX, parent) {
     /*if(prefix)
@@ -61,15 +61,12 @@ void TOptIAPrefix::setPrefixLenght(char prefix_length){
 
 char * TOptIAPrefix::storeSelf( char* buf)
 {
-	
-    *(uint16_t*)buf = htons(OptType);
-    buf+=2;
-    *(uint16_t*)buf = htons( getSize()-4 );
-    buf+=2;
-    *(uint32_t*)buf = htonl(Pref);
-    buf+=4;
-    *(uint32_t*)buf = htonl(Valid);
-    buf+=4;
+    buf = writeUint16(buf, OptType);
+    buf = writeUint16(buf, getSize()-4);
+
+    buf = writeUint32(buf, Pref);
+    buf = writeUint32(buf, Valid);
+
     *(char*)buf = PrefixLength;
     buf+=1;
     memcpy(buf,Prefix->getAddr(),16);
@@ -79,7 +76,7 @@ char * TOptIAPrefix::storeSelf( char* buf)
     return buf;
 }
 
- SmartPtr<TIPv6Addr> TOptIAPrefix::getPrefix()
+ SPtr<TIPv6Addr> TOptIAPrefix::getPrefix()
 {
 	return this->Prefix;
 }
