@@ -2,19 +2,14 @@
  * Dibbler - a portable DHCPv6
  *
  * author: Krzysztof Wnuk <keczi@poczta.onet.pl>
+ * changes: Tomasz Mrugalski <thomson@klub.com.pl>
  * 
  * released under GNU GPL v2 only licence
  *
  *
  */
 
-#ifdef WIN32
-#include <winsock2.h>
-#endif
-#ifdef LINUX
-#include <netinet/in.h>
-#endif 
-
+#include "Portable.h"
 #include "OptIA_PD.h"
 #include "OptIAPrefix.h"
 #include "OptStatusCode.h"
@@ -47,20 +42,22 @@ TOptIA_PD::TOptIA_PD( char * &buf, int &bufsize, TMsg* parent)
 	
     } else {
         Valid=true;
-        IAID = ntohl(*( long*)buf);
-        T1 = ntohl(*( long*)(buf+4));
-        T2 = ntohl(*( long*)(buf+8));
-        buf+=12; bufsize-=12;
+        IAID = readUint32(buf);
+        buf += sizeof(uint32_t); bufsize -= sizeof(uint32_t);
+        T1 = readUint32(buf);
+        buf += sizeof(uint32_t); bufsize -= sizeof(uint32_t);
+        T2 = readUint32(buf);
+        buf += sizeof(uint32_t); bufsize -= sizeof(uint32_t);
     }
 }
 
 
 int TOptIA_PD::getStatusCode() {
-    SmartPtr<TOpt> ptrOpt;
+    SPtr<TOpt> ptrOpt;
     SubOptions.first();
     while ( ptrOpt = SubOptions.get() ) {
 	if ( ptrOpt->getOptType() == OPTION_STATUS_CODE) {
-	    SmartPtr <TOptStatusCode> ptrStatus;
+	    SPtr <TOptStatusCode> ptrStatus;
 	    ptrStatus = (Ptr*) ptrOpt;
 	    return ptrStatus->getCode();
 	}
@@ -74,28 +71,25 @@ int TOptIA_PD::getSize() {
 }
 
 char * TOptIA_PD::storeSelf( char* buf) {
-    *(uint16_t*)buf = htons(OptType);
-    buf+=2;
-    *(uint16_t*)buf = htons( getSize()-4 );
-    buf+=2;
-    *(uint32_t*)buf = htonl(IAID);
-    buf+=4;
-    *(uint32_t*)buf = htonl(T1);
-    buf+=4;
-    *(uint32_t*)buf = htonl(T2);
-    buf+=4;
-    buf=this->storeSubOpt(buf);
+    buf = writeUint16(buf, OptType);
+    buf = writeUint16(buf, getSize() - 4 );
+
+    buf = writeUint32(buf, IAID);
+    buf = writeUint32(buf, T1);
+    buf = writeUint32(buf, T2);
+
+    buf = storeSubOpt(buf);
     return buf;
 }
 
 unsigned long TOptIA_PD::getMaxValid() {
     unsigned long maxValid=0;
-    SmartPtr<TOpt> ptrOpt;
+    SPtr<TOpt> ptrOpt;
     SubOptions.first();
     while (ptrOpt=SubOptions.get())
     {
         if (ptrOpt->getOptType()==OPTION_IAPREFIX) {
-            //SmartPtr<TOptIAAddress> ptrIAAddr=(Ptr*)ptrOpt;
+            //SPtr<TOptIAAddress> ptrIAAddr=(Ptr*)ptrOpt;
             //if (maxValid<ptrIAAddr->getValid())
             //    maxValid=ptrIAAddr->getValid();
         }
@@ -112,7 +106,7 @@ bool TOptIA_PD::isValid() {
  */
 int TOptIA_PD::countPrefixes() {
     int cnt = 0;
-    SmartPtr<TOpt> opt;
+    SPtr<TOpt> opt;
     this->firstOption();
     while (opt = this->getOption() ) {
 	if (opt->getOptType() == OPTION_IAPREFIX)
