@@ -8,11 +8,7 @@
  *
  * $Id: OptInteger.h,v 1.1 2006-10-29 13:11:46 thomson Exp $
  *
- * $Log: OptInteger.h,v $
- * Revision 1.1  2006-10-29 13:11:46  thomson
- * Size of the Elapsed time option has been corrected,
- * OptInteger4 class migrated to OptInteger.
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.1  2004-11-02 01:23:13  thomson
  * Initial revision
  *
@@ -30,12 +26,13 @@ using namespace std;
 class TOptInteger : public TOpt
 {
 public:
-    TOptInteger(int type, unsigned int len/*0-4*/, unsigned int value, TMsg* parent);
-    TOptInteger(int type, unsigned int len/*0-4*/, char *&buf, int &bufsize, TMsg* parent);
+    TOptInteger(int type, unsigned int len/* 1,2, or 4*/, unsigned int value, TMsg* parent);
+    TOptInteger(int type, unsigned int len/* 1,2, or 4*/, char *&buf, int &bufsize, TMsg* parent);
     char * storeSelf( char* buf);
     int getSize();
     unsigned int getValue();
     bool isValid();
+    std::string getPlain();
 protected:
     unsigned int Value;
     bool Valid;
