@@ -6,27 +6,9 @@
  *
  * released under GNU GPL v2 licence
  *
- * $Id: OptString.cpp,v 1.3 2007-08-26 10:26:19 thomson Exp $
- *
- * $Log: OptString.cpp,v $
- * Revision 1.3  2007-08-26 10:26:19  thomson
- * Possible segfault in REBIND processing,
- * gcc 4.3.0 conformance
- *
- * Revision 1.2  2005-07-17 21:09:52  thomson
- * Minor improvements for 0.4.1 release.
- *
- * Revision 1.1  2004/11/02 01:23:13  thomson
- * Initial revision
- *
- * Revision 1.3  2004/04/11 18:10:56  thomson
- * CRLF fixed.
- *
- * Revision 1.2  2004/03/29 18:53:08  thomson
- * Author/Licence/cvs log/cvs version headers added.
  */
 
-#include <stdlib.h>
+#include <string.h>
 #include <iostream>
 #include "Portable.h"
 #include "OptString.h"
@@ -34,12 +16,11 @@
 
 using namespace std;
 
-TOptString::TOptString(int type, string str, TMsg* parent)
-    :TOpt(type, parent) {
-    Str = str;
+TOptString::TOptString(int type, std::string str, TMsg* parent)
+    :TOpt(type, parent), Str(str) {
 }
 
-TOptString::TOptString(int type, char *&buf, int &bufsize, TMsg* parent)
+TOptString::TOptString(int type, const char *buf, unsigned short bufsize, TMsg* parent)
     :TOpt(type, parent)
 {
     char* str=new char[bufsize+1];
@@ -47,16 +28,12 @@ TOptString::TOptString(int type, char *&buf, int &bufsize, TMsg* parent)
     str[bufsize]=0;
     Str = string(str);
     delete [] str;
-    bufsize -= this->Str.length()+1;
-    buf += this->Str.length()+1;
 }
 
 char * TOptString::storeSelf(char* buf)
 {
-    *(short*)buf = htons(OptType);
-    buf+=2;
-    *(short*)buf = htons(getSize()-4);
-    buf+=2;    
+    buf = writeUint16(buf, OptType);
+    buf = writeUint16(buf, getSize()-4);
     memcpy(buf,Str.c_str(),Str.length());
     buf[Str.length()]=0;  // null-terminated
     return buf+this->Str.length()+1;
