@@ -6,12 +6,6 @@
  *
  * released under GNU GPL v2 licence
  *
- * $Id: OptString.h,v 1.1 2004-11-02 01:23:13 thomson Exp $
- *
- * $Log: OptString.h,v $
- * Revision 1.1  2004-11-02 01:23:13  thomson
- * Initial revision
- *
  */
 
 #ifndef OPTSTRING_H
@@ -21,18 +15,18 @@
 
 #include "Opt.h"
 
-using namespace std;
-
 class TOptString : public TOpt
 {
  public:
-    TOptString(int type, string str, TMsg* parent);
-    TOptString(int type, char *&buf, int &bufsize, TMsg* parent);
+    TOptString(int type, std::string str, TMsg* parent);
+    TOptString(int type, const char *buf, unsigned short len, TMsg* parent);
     char * storeSelf( char* buf);
     int getSize();
     string getString();
+    virtual bool doDuties() { return true; } // do nothing, actual code in ClntOpt* classes
+    std::string getPlain() { return Str; }
  protected:
-    string Str;
+    std::string Str;
 };
 
 #endif
