@@ -2,12 +2,9 @@
  * Dibbler - a portable DHCPv6
  *
  * authors: Tomasz Mrugalski <thomson@klub.com.pl>
- *          Marek Senderski <msend@o2.pl>
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: dibbler-client.cpp,v 1.25 2008-10-12 14:02:40 thomson Exp $
- *
  */
 
 #include <signal.h>
@@ -20,21 +17,32 @@
 #include "Logger.h"
 #include "daemon.h"
 #include "ClntCfgMgr.h"
+#include <map>
+#include <pthread.h>
+
+using std::map;
+
+#define IF_RECONNECTED_DETECTED -1
+
+extern pthread_mutex_t lock;
 
 TDHCPClient * ptr;
+//static const char *TOOL_NAME = "ifplugstatus";
+
 
 void signal_handler(int n) {
     Log(Crit) << "Signal received. Shutting down." << LogEnd;
     ptr->stop();
 }
 
-// when network linkstate change event is detected, this handler will be called.
-void signal_handler1(int n) {
-    Log(Notice) << "Network switch off event detected. do Confirmming." << LogEnd;
 
-    // get information regarding updated interfaces and call
-    // link_state_changed(int ifindex)
-}   
+#ifdef MOD_CLNT_CONFIRM
+void signal_handler_of_linkstate_change(int n) {
+    Log(Notice) << "Network switch off event detected. initiating CONFIRM." << LogEnd;
+    pthread_mutex_lock(&lock);
+    pthread_mutex_unlock(&lock);
+}
+#endif
 
 int status() {
 
@@ -65,11 +73,13 @@ int status() {
 
 int run() {
     if (!init(CLNTPID_FILE, WORKDIR)) {
+	die(CLNTPID_FILE);
 	return -1;
     }
 
     if (lowlevelInit()<0) {
 	cout << "Lowlevel init failed:" << error_message() << endl;
+	die(CLNTPID_FILE);
 	return -1;
     }
 
@@ -77,6 +87,7 @@ int run() {
     ptr = &client;
 
     if (ptr->isDone()) {
+	die(CLNTPID_FILE);
 	return -1;
     }
 
@@ -84,8 +95,15 @@ int run() {
     signal(SIGTERM, signal_handler);
     signal(SIGINT, signal_handler);
 
+#ifdef MOD_CLNT_CONFIRM
+    // CHANGED: add a signal handling function to handle SIGUSR1,
+    // which will be generated if network switch off.
     // SIGUSR1 = link state-change
-    signal(SIGUSR1,signal_handler1);
+    signal(SIGUSR1, signal_handler_of_linkstate_change);
+    Log(Notice) << "CONFIRM support compiled in." << LogEnd;
+#else
+    Log(Info) << "CONFIRM support not compiled in." << LogEnd;
+#endif
 
     ptr->run();
 
