@@ -7,57 +7,13 @@
  * released under GNU GPL v2 only licence
  *
  * $Id: dibbler-server.cpp,v 1.21 2008-10-10 20:39:12 thomson Exp $
- *
- * $Log: dibbler-server.cpp,v $
- * Revision 1.21  2008-10-10 20:39:12  thomson
- * pid_t is now used instead of int (bug #180)
- *
- * Revision 1.20  2008-08-29 00:07:31  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
- * Revision 1.19  2008-06-01 21:45:48  thomson
- * Return coded are now returned properly under Linux (bug #175)
- *
- * Revision 1.18  2005-10-11 20:52:47  thomson
- * Problem with command-line parsing fixed.
- *
- * Revision 1.17  2005/07/31 14:39:40  thomson
- * Minor changes related to 0.4.1 release.
- *
- * Revision 1.16  2005/07/21 21:40:19  thomson
- * PID checking process is improved.
- *
- * Revision 1.15  2005/04/29 00:08:20  thomson
- * *** empty log message ***
- *
- * Revision 1.14  2005/02/03 22:06:40  thomson
- * Linux startup/pid checking changed.
- *
- * Revision 1.13  2005/02/03 20:09:11  thomson
- * *** empty log message ***
- *
- * Revision 1.12  2005/01/30 23:12:28  thomson
- * *** empty log message ***
- *
- * Revision 1.11  2005/01/30 22:53:28  thomson
- * *** empty log message ***
- *
- * Revision 1.10  2004/12/07 00:45:42  thomson
- * Clnt managers creation unified and cleaned up.
- *
- * Revision 1.9  2004/12/02 00:51:06  thomson
- * Log files are now always created (bugs #34, #36)
- *
- * Revision 1.8  2004/06/04 16:55:27  thomson
- * *** empty log message ***
- *
- * Revision 1.7  2004/06/04 14:15:53  thomson
- * Command line parsing.
- *
  *                                                                           
  */
 
 #include <signal.h>
+#include <string.h>
+#include <stdlib.h>
+#include <stdio.h>
 #include "DHCPServer.h"
 #include "Portable.h"
 #include "Logger.h"
@@ -98,6 +54,7 @@ int status() {
 
 int run() {
     if (!init(SRVPID_FILE, WORKDIR)) {
+	die(SRVPID_FILE);
 	return -1;
     }
 
@@ -105,6 +62,7 @@ int run() {
     
     ptr = &srv;
     if (ptr->isDone()) {
+	die(SRVPID_FILE);
 	return -1;
     }
     
