@@ -12,30 +12,26 @@
 #include <iostream>
 #include <fstream>
 #include <string>
-#include "RelCommon.h"
-
-using namespace std;
-
 #include "IfaceMgr.h"
 #include "RelIfaceMgr.h"
 #include "RelCfgIface.h"
-
 #include "FlexLexer.h"
 #include "RelParser.h"
 #include "RelCfgMgr.h"
 
+using namespace std;
+
 int TRelCfgMgr::NextRelayID = RELAY_MIN_IFINDEX;
 
-TRelCfgMgr::TRelCfgMgr(TCtx ctx, string cfgFile, string xmlFile)
-    :TCfgMgr(ctx.IfaceMgr)
-{
-    this->Ctx = ctx;
-    this->XmlFile = xmlFile;
+TRelCfgMgr * TRelCfgMgr::Instance = 0;
 
+TRelCfgMgr::TRelCfgMgr(const std::string cfgFile, const std::string xmlFile)
+    :TCfgMgr(), XmlFile(xmlFile)
+{
     // load config file
     if (!this->parseConfigFile(cfgFile)) {
-	this->IsDone = true;
-	return;
+        this->IsDone = true;
+        return;
     }
 
     this->dump();
@@ -97,7 +93,7 @@ void TRelCfgMgr::dump() {
     xmlDump.close();
 }
 
-bool TRelCfgMgr::setupGlobalOpts(SmartPtr<TRelParsGlobalOpt> opt) {
+bool TRelCfgMgr::setupGlobalOpts(SPtr<TRelParsGlobalOpt> opt) {
     this->Workdir          = opt->getWorkDir();
     this->GuessMode        = opt->getGuessMode();
     this->InterfaceIDOrder = opt->getInterfaceIDOrder();
@@ -116,8 +112,8 @@ bool TRelCfgMgr::matchParsedSystemInterfaces(List(TRelCfgIface) * lst) {
     cfgIfaceCnt = lst->count();
     Log(Debug) << cfgIfaceCnt << " interface(s) specified in " << RELCONF_FILE << LogEnd;
 
-    SmartPtr<TRelCfgIface> cfgIface;
-    SmartPtr<TIfaceIface>  ifaceIface;
+    SPtr<TRelCfgIface> cfgIface;
+    SPtr<TIfaceIface>  ifaceIface;
     
     lst->first();
     while(cfgIface=lst->get()) {
@@ -125,9 +121,9 @@ bool TRelCfgMgr::matchParsedSystemInterfaces(List(TRelCfgIface) * lst) {
 	// physical interface
 	if (cfgIface->getID()==-1) {
 	    // ID==-1 means that user referenced to interface by name
-	    ifaceIface = IfaceMgr->getIfaceByName(cfgIface->getName());
+	    ifaceIface = RelIfaceMgr().getIfaceByName(cfgIface->getName());
 	} else {
-	    ifaceIface = IfaceMgr->getIfaceByID(cfgIface->getID());
+	    ifaceIface = RelIfaceMgr().getIfaceByID(cfgIface->getID());
 	}
 	if (!ifaceIface) {
 	    Log(Crit) << "Interface " << cfgIface->getName() << "/" << cfgIface->getID() 
@@ -151,11 +147,11 @@ bool TRelCfgMgr::matchParsedSystemInterfaces(List(TRelCfgIface) * lst) {
     return true;
 }
 
-SmartPtr<TRelCfgIface> TRelCfgMgr::getIface() {
+SPtr<TRelCfgIface> TRelCfgMgr::getIface() {
 	return this->IfaceLst.get();
 }
 
-void TRelCfgMgr::addIface(SmartPtr<TRelCfgIface> ptr) {
+void TRelCfgMgr::addIface(SPtr<TRelCfgIface> ptr) {
     IfaceLst.append(ptr);
 }
 
@@ -180,7 +176,7 @@ bool TRelCfgMgr::guessMode() {
 }
 
 bool TRelCfgMgr::validateConfig() {
-    SmartPtr<TRelCfgIface> ptrIface;
+    SPtr<TRelCfgIface> ptrIface;
 
     if (!this->countIface()) {
 	Log(Crit) << "Config problem: No interface defined." << LogEnd;
@@ -199,7 +195,7 @@ bool TRelCfgMgr::validateConfig() {
     return true;
 }
 
-bool TRelCfgMgr::validateIface(SmartPtr<TRelCfgIface> ptrIface)
+bool TRelCfgMgr::validateIface(SPtr<TRelCfgIface> ptrIface)
 {
     if ( (ptrIface->getInterfaceID() == (signed int)DHCPV6_INFINITY) &&
 	(ptrIface->getClientUnicast() || ptrIface->getClientMulticast()) ) {
@@ -220,9 +216,9 @@ bool TRelCfgMgr::validateIface(SmartPtr<TRelCfgIface> ptrIface)
     return true;
 }
 
-SmartPtr<TRelCfgIface> TRelCfgMgr::getIfaceByID(int iface) 
+SPtr<TRelCfgIface> TRelCfgMgr::getIfaceByID(int iface) 
 {
-    SmartPtr<TRelCfgIface> ptrIface;
+    SPtr<TRelCfgIface> ptrIface;
     this->firstIface();
     while ( ptrIface = this->getIface() ) {
 	if ( ptrIface->getID()==iface )
@@ -233,9 +229,9 @@ SmartPtr<TRelCfgIface> TRelCfgMgr::getIfaceByID(int iface)
 }
 
 
-SmartPtr<TRelCfgIface> TRelCfgMgr::getIfaceByInterfaceID(int iface) 
+SPtr<TRelCfgIface> TRelCfgMgr::getIfaceByInterfaceID(int iface) 
 {
-    SmartPtr<TRelCfgIface> ptrIface;
+    SPtr<TRelCfgIface> ptrIface;
     this->firstIface();
     while ( ptrIface = this->getIface() ) {
 	if ( ptrIface->getInterfaceID()==iface )
@@ -251,7 +247,7 @@ ERelIfaceIdOrder TRelCfgMgr::getInterfaceIDOrder()
     return InterfaceIDOrder;
 }
 
-SPtr<TRelOptRemoteID> TRelCfgMgr::getRemoteID()
+SPtr<TOptVendorData> TRelCfgMgr::getRemoteID()
 {
     return RemoteID;
 }
@@ -261,6 +257,20 @@ SPtr<TRelOptEcho> TRelCfgMgr::getEcho()
     return Echo;
 }
 
+void TRelCfgMgr::instanceCreate( const std::string cfgFile, const std::string xmlFile )
+{
+    if (Instance)
+        Log(Crit) << "RelCfgMgr instance already created. Application error!" << LogEnd;
+    Instance = new TRelCfgMgr(cfgFile, xmlFile);
+}
+
+TRelCfgMgr& TRelCfgMgr::instance()
+{
+    if (!Instance)
+        Log(Crit) << "RelCfgMgr instance not created yet. Application error. Crashing in 3... 2... 1..." << LogEnd;
+    return *Instance;
+}
+
 // --------------------------------------------------------------------
 // --- operators ------------------------------------------------------
 // --------------------------------------------------------------------
@@ -288,8 +298,7 @@ ostream & operator<<(ostream &out, TRelCfgMgr &x) {
     }
     out << "</InterfaceIDOrder>" << endl;
 
-    if (x.getRemoteID()) {
-	SPtr<TRelOptRemoteID> r = x.getRemoteID();
+    if (SPtr<TOptVendorData> r = x.getRemoteID()) {
 	out << "  <RemoteID enterprise=\"" << r->getVendor() << "\" length=\"" << r->getVendorDataLen() 
 	    << "\">" << r->getVendorDataPlain() << "</RemoteID>" << endl;
     } else {
@@ -307,7 +316,7 @@ ostream & operator<<(ostream &out, TRelCfgMgr &x) {
 	out << "  <!-- <EchoRequest/> -->" << endl;
     }
     
-    SmartPtr<TRelCfgIface> ptrIface;
+    SPtr<TRelCfgIface> ptrIface;
     x.firstIface();
     while (ptrIface = x.getIface()) {
 	out << *ptrIface;
