@@ -6,72 +6,74 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: RelCfgMgr.h,v 1.8 2008-08-29 00:07:32 thomson Exp $
- *
  */
 
-class TRelCfgMgr;
 #ifndef RELCFGMGR_H
 #define RELCFGMGR_H
 
-#include "RelCommon.h"
 #include "RelCfgIface.h"
 
 #include "CfgMgr.h"
 #include "DHCPConst.h"
-#include "RelOptRemoteID.h"
+#include "OptVendorData.h"
 #include "RelOptEcho.h"
 
+#define RelCfgMgr() (TRelCfgMgr::instance())
+
 class TRelCfgMgr : public TCfgMgr
 {
 public:  
-    friend ostream & operator<<(ostream &strum, TRelCfgMgr &x);
-    TRelCfgMgr(TCtx ctx, string cfgFile, string xmlFile);
+    friend ostream & operator<<(std::ostream &strum, TRelCfgMgr &x);
     virtual ~TRelCfgMgr();
 
-    bool parseConfigFile(string cfgFile);
+    static void instanceCreate(const std::string cfgFile, const std::string xmlFile);
+    static TRelCfgMgr& instance();
 
-    //Interfaces acccess methods
+    bool parseConfigFile(const std::string cfgFile);
+
+    //Interfaces access methods
     void firstIface();
-    SmartPtr<TRelCfgIface> getIface();
-    SmartPtr<TRelCfgIface> getIfaceByID(int iface);
-    SmartPtr<TRelCfgIface> getIfaceByInterfaceID(int iface);
+    SPtr<TRelCfgIface> getIface();
+    SPtr<TRelCfgIface> getIfaceByID(int iface);
+    SPtr<TRelCfgIface> getIfaceByInterfaceID(int iface);
     long countIface();
-    void addIface(SmartPtr<TRelCfgIface> iface);
+    void addIface(SPtr<TRelCfgIface> iface);
 
     void dump();
 
     bool isDone();
 
-    bool setupGlobalOpts(SmartPtr<TRelParsGlobalOpt> opt);
+    bool setupGlobalOpts(SPtr<TRelParsGlobalOpt> opt);
 
     // configuration parameters
     string getWorkdir();
     bool guessMode();
     ERelIfaceIdOrder getInterfaceIDOrder();
 
-    SPtr<TRelOptRemoteID> getRemoteID();
+    SPtr<TOptVendorData> getRemoteID();
     SPtr<TRelOptEcho>     getEcho();
 
-private:    
-    TCtx Ctx;
-    string XmlFile;
+private:
+    static TRelCfgMgr * Instance;
+    TRelCfgMgr(const std::string cfgFile, const std::string xmlFile);
+
+    std::string XmlFile;
 
     static int NextRelayID;
 
     bool IsDone;
     bool validateConfig();
-    bool validateIface(SmartPtr<TRelCfgIface> ptrIface);
+    bool validateIface(SPtr<TRelCfgIface> ptrIface);
     List(TRelCfgIface) IfaceLst;
 
     bool matchParsedSystemInterfaces(List(TRelCfgIface) * lst);
 
     // global options
-    string Workdir;
+    std::string Workdir;
     bool GuessMode;
     ERelIfaceIdOrder InterfaceIDOrder;
 
-    SPtr<TRelOptRemoteID> RemoteID;
+    SPtr<TOptVendorData> RemoteID;
     SPtr<TRelOptEcho> Echo;
 };
 
