@@ -13,6 +13,7 @@
 #define MAX_PACKET_LEN 1452
 #define RELAY_FORW_MSG_LEN 36
 
+#include <fstream>
 #include "RelTransMgr.h"
 #include "RelCfgMgr.h"
 #include "RelIfaceMgr.h"
@@ -20,18 +21,17 @@
 #include "RelOptEcho.h"
 #include "RelOptGeneric.h"
 #include "Logger.h"
+#include "Portable.h"
 
-TRelTransMgr::TRelTransMgr(TCtx * ctx, string xmlFile)
+TRelTransMgr * TRelTransMgr::Instance = 0; // singleton implementation
+
+TRelTransMgr::TRelTransMgr(const std::string xmlFile)
+    :XmlFile(xmlFile), IsDone(false)
 {
-    // remember context
-    this->Ctx = ctx;
-    this->IsDone = false; // TransMgr is certainly not done yet. We're just getting started
-    this->XmlFile = xmlFile;
-
     // for each interface in CfgMgr, create socket (in IfaceMgr)
-    SmartPtr<TRelCfgIface> confIface;
-    this->Ctx->CfgMgr->firstIface();
-    while (confIface=this->Ctx->CfgMgr->getIface()) {
+    SPtr<TRelCfgIface> confIface;
+    RelCfgMgr().firstIface();
+    while (confIface=RelCfgMgr().getIface()) {
 	if (!this->openSocket(confIface)) {
 	    this->IsDone = true;
 	    break;
@@ -40,20 +40,20 @@ TRelTransMgr::TRelTransMgr(TCtx * ctx, string xmlFile)
 }
 
 /*
- * opens proper (multicast or unicast) socket on interface 
+ * opens proper (multicast or unicast) socket on interface
  */
-bool TRelTransMgr::openSocket(SmartPtr<TRelCfgIface> cfgIface) {
+bool TRelTransMgr::openSocket(SPtr<TRelCfgIface> cfgIface) {
 
-    SmartPtr<TIfaceIface> iface = this->Ctx->IfaceMgr->getIfaceByID(cfgIface->getID());
+    SPtr<TIfaceIface> iface = RelIfaceMgr().getIfaceByID(cfgIface->getID());
     if (!iface) {
 	Log(Crit) << "Unable to find " << cfgIface->getName() << "/" << cfgIface->getID()
 		  << " interface in the IfaceMgr." << LogEnd;
 	return false;
     }
 
-    SmartPtr<TIPv6Addr> srvUnicast = cfgIface->getServerUnicast();
-    SmartPtr<TIPv6Addr> clntUnicast = cfgIface->getClientUnicast();
-    SmartPtr<TIPv6Addr> addr;
+    SPtr<TIPv6Addr> srvUnicast = cfgIface->getServerUnicast();
+    SPtr<TIPv6Addr> clntUnicast = cfgIface->getClientUnicast();
+    SPtr<TIPv6Addr> addr;
 
     if (cfgIface->getServerMulticast() || srvUnicast) {
 
@@ -100,17 +100,17 @@ bool TRelTransMgr::openSocket(SmartPtr<TRelCfgIface> cfgIface) {
 /**
  * relays normal (i.e. not server replies) messages to defined servers
  */
-void TRelTransMgr::relayMsg(SmartPtr<TRelMsg> msg)
-{	
+void TRelTransMgr::relayMsg(SPtr<TRelMsg> msg)
+{
     static char buf[MAX_PACKET_LEN];
     int offset = 0;
     int bufLen;
     int hopCount = 0;
     if (!msg->check()) {
 	Log(Warning) << "Invalid message received." << LogEnd;
-        return;
+	return;
     }
-    
+
     if (msg->getDestAddr()) {
 	this->relayMsgRepl(msg);
 	return;
@@ -121,14 +121,14 @@ void TRelTransMgr::relayMsg(SmartPtr<TRelMsg> msg)
     }
 
     // prepare message
-    SmartPtr<TIfaceIface> iface = this->Ctx->IfaceMgr->getIfaceByID(msg->getIface());
-    SmartPtr<TIPv6Addr> addr;
+    SPtr<TIfaceIface> iface = RelIfaceMgr().getIfaceByID(msg->getIface());
+    SPtr<TIPv6Addr> addr;
 
     // store header
     buf[offset++] = RELAY_FORW_MSG;
     buf[offset++] = hopCount;
 
-    // store link-addr 
+    // store link-addr
     iface->firstGlobalAddr();
     addr = iface->getGlobalAddr();
     if (!addr) {
@@ -143,11 +143,11 @@ void TRelTransMgr::relayMsg(SmartPtr<TRelMsg> msg)
     addr->storeSelf(buf+offset);
     offset += 16;
 
-    SmartPtr<TRelCfgIface> cfgIface;
-    cfgIface = this->Ctx->CfgMgr->getIfaceByID(msg->getIface());
+    SPtr<TRelCfgIface> cfgIface;
+    cfgIface = RelCfgMgr().getIfaceByID(msg->getIface());
     TRelOptInterfaceID ifaceID(cfgIface->getInterfaceID(), 0);
 
-    if (Ctx->CfgMgr->getInterfaceIDOrder()==REL_IFACE_ID_ORDER_BEFORE)
+    if (RelCfgMgr().getInterfaceIDOrder()==REL_IFACE_ID_ORDER_BEFORE)
     {
 	// store InterfaceID option
 	ifaceID.storeSelf(buf + offset);
@@ -156,14 +156,14 @@ void TRelTransMgr::relayMsg(SmartPtr<TRelMsg> msg)
     }
 
     // store relay msg option
-    *(short*)(buf+offset) = htons(OPTION_RELAY_MSG);
-    offset+=2;
-    *(short*)(buf+offset) = htons(msg->getSize());
-    offset+=2;
+    writeUint16((buf+offset), OPTION_RELAY_MSG);
+    offset += sizeof(uint16_t);
+    writeUint16((buf+offset), msg->getSize());
+    offset += sizeof(uint16_t);
     bufLen = msg->storeSelf(buf+offset);
     offset += bufLen;
 
-    if (Ctx->CfgMgr->getInterfaceIDOrder()==REL_IFACE_ID_ORDER_AFTER)
+    if (RelCfgMgr().getInterfaceIDOrder()==REL_IFACE_ID_ORDER_AFTER)
     {
 	// store InterfaceID option
 	ifaceID.storeSelf(buf + offset);
@@ -171,21 +171,22 @@ void TRelTransMgr::relayMsg(SmartPtr<TRelMsg> msg)
 	Log(Debug) << "Interface-id option added after relayed message." << LogEnd;
     }
 
-    if (Ctx->CfgMgr->getInterfaceIDOrder()==REL_IFACE_ID_ORDER_NONE)
+    if (RelCfgMgr().getInterfaceIDOrder()==REL_IFACE_ID_ORDER_NONE)
     {
 	Log(Warning) << "Interface-id option not added (interface-id-order omit used in relay.conf). "
 		     << "That is a debugging feature and violates RFC3315. Use with caution." << LogEnd;
     }
 
-    SPtr<TRelOptRemoteID> remoteID = Ctx->CfgMgr->getRemoteID();
+    SPtr<TOptVendorData> remoteID = RelCfgMgr().getRemoteID();
     if (remoteID) {
 	remoteID->storeSelf(buf+offset);
 	offset += remoteID->getSize();
-	Log(Debug) << "Appended RemoteID with " << remoteID->getVendorDataLen() << "-byte long data (option length=" 
+	Log(Debug) << "Appended RemoteID with " << remoteID->getVendorDataLen() 
+		   << "-byte long data (option length="
 		   << remoteID->getSize() << ")." << LogEnd;
     }
 
-    SPtr<TRelOptEcho> echo = Ctx->CfgMgr->getEcho();
+    SPtr<TRelOptEcho> echo = RelCfgMgr().getEcho();
     if (echo) {
 	echo->storeSelf(buf+offset);
 	offset += echo->getSize();
@@ -206,47 +207,47 @@ void TRelTransMgr::relayMsg(SmartPtr<TRelMsg> msg)
 	Log(Cont) << " opt(s)." << LogEnd;
     }
 
-    this->Ctx->CfgMgr->firstIface();
-    while (cfgIface = this->Ctx->CfgMgr->getIface()) {
+    RelCfgMgr().firstIface();
+    while (cfgIface = RelCfgMgr().getIface()) {
 	if (cfgIface->getServerUnicast()) {
 	    Log(Notice) << "Relaying encapsulated " << msg->getName() << " message on the " << cfgIface->getFullName()
-			<< " interface to unicast (" << cfgIface->getServerUnicast()->getPlain() << ") address, port " 
+			<< " interface to unicast (" << cfgIface->getServerUnicast()->getPlain() << ") address, port "
 			<< DHCPSERVER_PORT << "." << LogEnd;
 
-	    if (!this->Ctx->IfaceMgr->send(cfgIface->getID(), buf, offset, cfgIface->getServerUnicast(), DHCPSERVER_PORT)) {
+	    if (!RelIfaceMgr().send(cfgIface->getID(), buf, offset, cfgIface->getServerUnicast(), DHCPSERVER_PORT)) {
 		Log(Error) << "Failed to send data to server unicast address." << LogEnd;
 	    }
-					   
+
 	}
 	if (cfgIface->getServerMulticast()) {
 	    addr = new TIPv6Addr(ALL_DHCP_SERVERS, true);
 	    Log(Notice) << "Relaying encapsulated " << msg->getName() << " message on the " << cfgIface->getFullName()
-			<< " interface to multicast (" << addr->getPlain() << ") address, port " 
+			<< " interface to multicast (" << addr->getPlain() << ") address, port "
 			<< DHCPSERVER_PORT << "." << LogEnd;
-	    if (!this->Ctx->IfaceMgr->send(cfgIface->getID(), buf, offset, addr, DHCPSERVER_PORT)) {
+	    if (!RelIfaceMgr().send(cfgIface->getID(), buf, offset, addr, DHCPSERVER_PORT)) {
 		Log(Error) << "Failed to send data to server multicast address." << LogEnd;
 	    }
 	}
     }
 
     // save DB state regardless of action taken
-    this->Ctx->CfgMgr->dump();
-}	
+    RelCfgMgr().dump();
+}
 
-void TRelTransMgr::relayMsgRepl(SmartPtr<TRelMsg> msg) {
+void TRelTransMgr::relayMsgRepl(SPtr<TRelMsg> msg) {
     int port;
-    SmartPtr<TRelCfgIface> cfgIface = this->Ctx->CfgMgr->getIfaceByInterfaceID(msg->getDestIface());
+    SPtr<TRelCfgIface> cfgIface = RelCfgMgr().getIfaceByInterfaceID(msg->getDestIface());
     if (!cfgIface) {
 	Log(Error) << "Unable to relay message: Invalid interfaceID value:" << msg->getDestIface() << LogEnd;
 	return;
     }
 
-    SmartPtr<TIfaceIface> iface = this->Ctx->IfaceMgr->getIfaceByID(cfgIface->getID());
-    SmartPtr<TIPv6Addr> addr = msg->getDestAddr();
+    SPtr<TIfaceIface> iface = RelIfaceMgr().getIfaceByID(cfgIface->getID());
+    SPtr<TIPv6Addr> addr = msg->getDestAddr();
     static char buf[MAX_PACKET_LEN];
     int bufLen;
 
-    if (!iface) { 
+    if (!iface) {
 	Log(Warning) << "Unable to find interface with interfaceID=" << msg->getDestIface()
 		     << LogEnd;
 	return;
@@ -260,10 +261,10 @@ void TRelTransMgr::relayMsgRepl(SmartPtr<TRelMsg> msg) {
     Log(Notice) << "Relaying decapsulated " << msg->getName() << " message on the " << iface->getFullName()
 		<< " interface to the " << addr->getPlain() << ", port " << port << "." << LogEnd;
 
-    if (!this->Ctx->IfaceMgr->send(iface->getID(), buf, bufLen, addr, port)) {
+    if (!RelIfaceMgr().send(iface->getID(), buf, bufLen, addr, port)) {
 	Log(Error) << "Failed to decapsulated data." << LogEnd;
     }
-    
+
 }
 
 void TRelTransMgr::shutdown() {
@@ -297,6 +298,21 @@ TRelTransMgr::~TRelTransMgr() {
     Log(Debug) << "RelTransMgr cleanup." << LogEnd;
 }
 
+void TRelTransMgr::instanceCreate( const std::string xmlFile )
+{
+  if (Instance)
+      Log(Crit) << "RelTransMgr instance already created. Application error!" << LogEnd;
+  Instance = new TRelTransMgr(xmlFile);
+
+}
+
+TRelTransMgr& TRelTransMgr::instance()
+{
+    if (!Instance)
+	Log(Crit) << "RelTransMgr istance not created yet. Application error. Crashing in 3... 2... 1..." << LogEnd;
+    return *Instance;
+}
+
 
 ostream & operator<<(ostream &s, TRelTransMgr &x)
 {
