@@ -16,6 +16,7 @@
 #include "SrvCfgAddrClass.h"
 #include "SrvCfgPD.h"
 #include "Logger.h"
+#include "Opt.h"
 
 #ifndef MOD_SRV_DISABLE_DNSUPDATE
 #include "DNSUpdate.h"
@@ -35,23 +36,26 @@ bool TSrvCfgIface::leaseQuerySupport()
 }
 
 
-SPtr<TSrvCfgOptions> TSrvCfgIface::getClientException(SPtr<TDUID> duid, SPtr<TSrvOptRemoteID> remoteID, bool quiet)
+SPtr<TSrvCfgOptions> TSrvCfgIface::getClientException(SPtr<TDUID> duid, SPtr<TOptVendorData> remoteID, bool quiet)
 {
     SPtr<TSrvCfgOptions> x;
     ExceptionsLst.first();
     while (x=ExceptionsLst.get()) {
 	if ( duid && x->getDuid() && (*(x->getDuid()) == *duid) ) {
 	    if (!quiet)
-		Log(Debug) << "Found per-client configuration (exception) for client with DUID=" << x->getDuid()->getPlain() << LogEnd;
+		Log(Debug) << "Found per-client configuration (exception) for client with DUID=" 
+                           << x->getDuid()->getPlain() << LogEnd;
 	    return x;
 	}
-	SPtr<TSrvOptRemoteID> id;
-	id = x->getRemoteID();
+	SPtr<TOptVendorData> remoteid;
+	remoteid = x->getRemoteID();
 
-	if ( remoteID && id && (remoteID->getVendor() == id->getVendor()) && (id->getVendorDataLen() == remoteID->getVendorDataLen())
-	     && !memcmp(id->getVendorData(), remoteID->getVendorData(), id->getVendorDataLen()) ) {
-		Log(Debug) << "Found per-client configuration (exception) for client with RemoteID: vendor=" << id->getVendor()
-			   << ", data=" << id->getVendorDataPlain() << "." << LogEnd;
+	if ( remoteID && remoteid && (remoteID->getVendor() == remoteid->getVendor()) 
+             && (remoteid->getVendorDataLen() == remoteID->getVendorDataLen())
+	     && !memcmp(remoteid->getVendorData(), remoteID->getVendorData(), remoteid->getVendorDataLen()) ) {
+		Log(Debug) << "Found per-client configuration (exception) for client with RemoteID: vendor=" 
+                           << remoteid->getVendor() << ", data=" 
+                           << remoteid->getVendorDataPlain() << "." << LogEnd;
 	    return x;
 	}
     }
@@ -65,8 +69,8 @@ void TSrvCfgIface::firstAddrClass() {
 /*
  * tries to find if there is a class, where client is on white-list
  */
-bool TSrvCfgIface::getPreferedAddrClassID(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, unsigned long &classid) {
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+bool TSrvCfgIface::getPreferedAddrClassID(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, unsigned long &classid) {
+    SPtr<TSrvCfgAddrClass> ptrClass;
     this->SrvCfgAddrClassLst.first();
     while(ptrClass=SrvCfgAddrClassLst.get()) {
         if (ptrClass->clntPrefered(duid, clntAddr)) {
@@ -80,14 +84,14 @@ bool TSrvCfgIface::getPreferedAddrClassID(SmartPtr<TDUID> duid, SmartPtr<TIPv6Ad
 /*
  * tries to find a class, which client is allowed to use
  */
-bool TSrvCfgIface::getAllowedAddrClassID(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, unsigned long &classid) {
+bool TSrvCfgIface::getAllowedAddrClassID(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, unsigned long &classid) {
     unsigned int clsid[100];
     unsigned int share[100];
     unsigned int cnt = 0;
     unsigned int sum = 0;
     unsigned int rnd;
 
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TSrvCfgAddrClass> ptrClass;
     this->SrvCfgAddrClassLst.first();
     while( (ptrClass=SrvCfgAddrClassLst.get()) && (cnt<100) ) {
         if (ptrClass->clntSupported(duid, clntAddr)) {
@@ -125,24 +129,24 @@ bool TSrvCfgIface::supportPrefixDelegation() {
     return this->PrefixDelegationSupport;
 }
 
-void TSrvCfgIface::addTA(SmartPtr<TSrvCfgTA> ta) {
+void TSrvCfgIface::addTA(SPtr<TSrvCfgTA> ta) {
     this->SrvCfgTALst.append(ta);
 }
 
 void TSrvCfgIface::firstTA() {
     this->SrvCfgTALst.first();
 }
-SmartPtr<TSrvCfgTA> TSrvCfgIface::getTA() {
+SPtr<TSrvCfgTA> TSrvCfgIface::getTA() {
     return this->SrvCfgTALst.get();
 }
 
-void TSrvCfgIface::addPD(SmartPtr<TSrvCfgPD> pd) {
+void TSrvCfgIface::addPD(SPtr<TSrvCfgPD> pd) {
     this->PrefixDelegationSupport = true;
     this->SrvCfgPDLst.append(pd);
 }
 
-SmartPtr<TSrvCfgTA> TSrvCfgIface::getTA(SmartPtr<TDUID> clntDuid, SmartPtr<TIPv6Addr> clntAddr) {
-    SmartPtr<TSrvCfgTA> ta;
+SPtr<TSrvCfgTA> TSrvCfgIface::getTA(SPtr<TDUID> clntDuid, SPtr<TIPv6Addr> clntAddr) {
+    SPtr<TSrvCfgTA> ta;
 
     // try to find preferred TA for this client
     this->SrvCfgTALst.first();
@@ -161,13 +165,13 @@ SmartPtr<TSrvCfgTA> TSrvCfgIface::getTA(SmartPtr<TDUID> clntDuid, SmartPtr<TIPv6
     return 0;
 }
 
-SmartPtr<TSrvCfgAddrClass> TSrvCfgIface::getAddrClass() {
+SPtr<TSrvCfgAddrClass> TSrvCfgIface::getAddrClass() {
     return SrvCfgAddrClassLst.get();
 }
 
-SmartPtr<TSrvCfgAddrClass> TSrvCfgIface::getClassByID(unsigned long id) {
+SPtr<TSrvCfgAddrClass> TSrvCfgIface::getClassByID(unsigned long id) {
     this->firstAddrClass();
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TSrvCfgAddrClass> ptrClass;
     while (ptrClass = this->getAddrClass()) {
 	if (ptrClass->getID() == id)
 	    return ptrClass;
@@ -175,14 +179,16 @@ SmartPtr<TSrvCfgAddrClass> TSrvCfgIface::getClassByID(unsigned long id) {
     return 0;
 }
 
-void TSrvCfgIface::addClntAddr(SmartPtr<TIPv6Addr> ptrAddr) {
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+void TSrvCfgIface::addClntAddr(SPtr<TIPv6Addr> ptrAddr, bool quiet /* =false*/) {
+    SPtr<TSrvCfgAddrClass> ptrClass;
     this->firstAddrClass();
     while (ptrClass = this->getAddrClass() ) {
 	if (ptrClass->addrInPool(ptrAddr)) {
+	    unsigned int count = ptrClass->incrAssigned();
+	    if (quiet)
+		return;
 	    Log(Debug) << "Address usage for class " << ptrClass->getID()
-		       << " increased by 1." << LogEnd;
-	    ptrClass->incrAssigned();
+		       << " increased to " << count << "." << LogEnd;
 	    return;
 	}
     }
@@ -190,14 +196,16 @@ void TSrvCfgIface::addClntAddr(SmartPtr<TIPv6Addr> ptrAddr) {
 		 << *ptrAddr << LogEnd;
 }
 
-void TSrvCfgIface::delClntAddr(SmartPtr<TIPv6Addr> ptrAddr) {
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+void TSrvCfgIface::delClntAddr(SPtr<TIPv6Addr> ptrAddr, bool quiet /* =false*/) {
+    SPtr<TSrvCfgAddrClass> ptrClass;
     this->firstAddrClass();
     while (ptrClass = this->getAddrClass() ) {
 	if (ptrClass->addrInPool(ptrAddr)) {
-	    ptrClass->decrAssigned();
+	    unsigned long count = ptrClass->decrAssigned();
+	    if (quiet)
+		return;
 	    Log(Debug) << "Address usage for class " << ptrClass->getID()
-		       << " decreased by 1." << LogEnd;
+		       << " decreased to " << count << "." << LogEnd;
 	    return;
 	}
     }
@@ -205,8 +213,8 @@ void TSrvCfgIface::delClntAddr(SmartPtr<TIPv6Addr> ptrAddr) {
 		 << *ptrAddr << LogEnd;
 }
 
-SmartPtr<TSrvCfgAddrClass> TSrvCfgIface::getRandomClass(SmartPtr<TDUID> clntDuid,
-							SmartPtr<TIPv6Addr> clntAddr) {
+SPtr<TSrvCfgAddrClass> TSrvCfgIface::getRandomClass(SPtr<TDUID> clntDuid,
+							SPtr<TIPv6Addr> clntAddr) {
 
     unsigned long classid;
 
@@ -242,13 +250,13 @@ long TSrvCfgIface::countAddrClass() {
 
 */
 
-SmartPtr<TSrvCfgPD> TSrvCfgIface::getPD() {
+SPtr<TSrvCfgPD> TSrvCfgIface::getPD() {
     return SrvCfgPDLst.get();
 }
 
-SmartPtr<TSrvCfgPD> TSrvCfgIface::getPDByID(unsigned long id) {
+SPtr<TSrvCfgPD> TSrvCfgIface::getPDByID(unsigned long id) {
     this->firstPD();
-    SmartPtr<TSrvCfgPD> ptrPD;
+    SPtr<TSrvCfgPD> ptrPD;
     while (ptrPD = this->getPD()) {
 	if (ptrPD->getID() == id)
 	    return ptrPD;
@@ -256,14 +264,16 @@ SmartPtr<TSrvCfgPD> TSrvCfgIface::getPDByID(unsigned long id) {
     return 0;
 }
 
-bool TSrvCfgIface::addClntPrefix(SmartPtr<TIPv6Addr> ptrAddr) {
-    SmartPtr<TSrvCfgPD> ptrPD;
+bool TSrvCfgIface::addClntPrefix(SPtr<TIPv6Addr> ptrAddr, bool quiet /* =false */) {
+    SPtr<TSrvCfgPD> ptrPD;
     this->firstPD();
     while (ptrPD = this->getPD() ) {
 	if (ptrPD->prefixInPool(ptrAddr)) {
+	    unsigned long count = ptrPD->incrAssigned();
+            if (quiet)
+                return true;
 	    Log(Debug) << "PD: Prefix usage for class " << ptrPD->getID()
-		       << " increased by 1." << LogEnd;
-	    ptrPD->incrAssigned();
+		       << " increased to " << count << "." << LogEnd;
 	    return true;
 	}
     }
@@ -272,14 +282,16 @@ bool TSrvCfgIface::addClntPrefix(SmartPtr<TIPv6Addr> ptrAddr) {
     return false;
 }
 
-bool TSrvCfgIface::delClntPrefix(SmartPtr<TIPv6Addr> ptrAddr) {
-    SmartPtr<TSrvCfgPD> ptrPD;
+bool TSrvCfgIface::delClntPrefix(SPtr<TIPv6Addr> ptrAddr, bool quiet /* =false */) {
+    SPtr<TSrvCfgPD> ptrPD;
     this->firstPD();
     while (ptrPD = this->getPD() ) {
 	if (ptrPD->prefixInPool(ptrAddr)) {
-	    ptrPD->decrAssigned();
+	    unsigned long count = ptrPD->decrAssigned();
+            if (quiet)
+                return true;
 	    Log(Debug) << "PD: Prefix usage for class " << ptrPD->getID()
-		       << " decreased by 1." << LogEnd;
+		       << " decreased to " << count << "." << LogEnd;
 	    return true;
 	}
     }
@@ -309,7 +321,7 @@ string TSrvCfgIface::getFullName() {
 	+oss.str();
 }
 
-SmartPtr<TIPv6Addr> TSrvCfgIface::getUnicast() {
+SPtr<TIPv6Addr> TSrvCfgIface::getUnicast() {
 	return this->Unicast;
 }
 
@@ -317,7 +329,7 @@ SmartPtr<TIPv6Addr> TSrvCfgIface::getUnicast() {
 TSrvCfgIface::~TSrvCfgIface() {
 }
 
-void TSrvCfgIface::setOptions(SmartPtr<TSrvParsGlobalOpt> opt) {
+void TSrvCfgIface::setOptions(SPtr<TSrvParsGlobalOpt> opt) {
     // default options
     this->preference    = opt->getPreference();
     this->IfaceMaxLease = opt->getIfaceMaxLease();
@@ -327,10 +339,13 @@ void TSrvCfgIface::setOptions(SmartPtr<TSrvParsGlobalOpt> opt) {
     this->LeaseQuery    = opt->getLeaseQuerySupport();
 
     if (opt->supportFQDN()){
-	AcceptUnknownFQDN = opt->acceptUnknownFQDN();
+	UnknownFQDN = opt->getUnknownFQDN();
+	FQDNDomain  = opt->getFQDNDomain();
+
 #ifndef MOD_SRV_DISABLE_DNSUPDATE
 	this->setFQDNLst(opt->getFQDNLst());
-	this->setFQDNMode(opt->getFQDNMode());
+	FQDNMode = opt->getFQDNMode();
+	
 	this->setRevDNSZoneRootLength(opt->getRevDNSZoneRootLength());
 	Log(Debug) <<"FQDN: Support is enabled on the " << this->getName()  << " interface." << LogEnd;
 	Log(Debug) <<"FQDN: Mode set to " << this->getFQDNMode() << ": ";
@@ -390,8 +405,7 @@ void TSrvCfgIface::setDefaults() {
     this->NoConfig = false;
     this->preference = 0;
 
-    this->FQDNSupport             = false;
-    this->AcceptUnknownFQDN       = false;
+    this->UnknownFQDN = SERVER_DEFAULT_UNKNOWN_FQDN;
     this->PrefixDelegationSupport = false;
 }
 
@@ -416,7 +430,7 @@ bool TSrvCfgIface::getRapidCommit() {
 }
 
 
-void TSrvCfgIface::addAddrClass(SmartPtr<TSrvCfgAddrClass> addrClass) {
+void TSrvCfgIface::addAddrClass(SPtr<TSrvCfgAddrClass> addrClass) {
     this->SrvCfgAddrClassLst.append(addrClass);
 }
 
@@ -455,7 +469,6 @@ void TSrvCfgIface::setRelayID(int id) {
 // --- option: FQDN ---
 void TSrvCfgIface::setFQDNLst(List(TFQDN) *fqdn) {
     this->FQDNLst = *fqdn;
-    this->FQDNSupport = true;
 }
 
 /**
@@ -468,21 +481,29 @@ void TSrvCfgIface::setFQDNLst(List(TFQDN) *fqdn) {
  *
  * @return
  */
-SPtr<TFQDN> TSrvCfgIface::getFQDNName(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> addr, string hint) {
-    FQDNLst.first();
-
-    SPtr<TFQDN> bestFound=0; // best FQDN found for that client
+SPtr<TFQDN> TSrvCfgIface::getFQDNName(SPtr<TDUID> duid, SPtr<TIPv6Addr> addr, string hint) {
 
+    SPtr<TFQDN> alternative = 0; // best FQDN found for that client
     SPtr<TFQDN> foo;
 
-    bool duplicate = false ; // whether the hint exists in the FQDN list
+    bool knownName = false ; // whether the hint exists in the FQDN list
 
+    FQDNLst.first();
     while (foo=this->FQDNLst.get()) {
 
 	if (foo->isUsed())
 	{ // client sent a hint, but it is used currently
-	    if (foo->Name == hint)
-	     	   duplicate = true;
+	  if ( (foo->getDuid()) && (*foo->getDuid() == *duid) && (*foo->getAddr() == *addr)) {
+                Log(Debug) << "FQDN: This client (DUID=" << duid->getPlain() 
+                           << ") has already assigned name " << foo->Name
+                           <<" to its address " << foo->getAddr()->getPlain() << "." << LogEnd;
+                return foo;
+            }
+
+	    if (foo->Name == hint) {
+                Log(Debug) << "FQDN: Client requested " << hint << ", but it is currently used." << LogEnd;
+	     	   knownName = true;
+            }
             continue;
 	}
 
@@ -497,57 +518,91 @@ SPtr<TFQDN> TSrvCfgIface::getFQDNName(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr>
 
 	if (foo->Name == hint){
 	    // client asked for this name. Let's check if client is allowed to get this name.
-	   duplicate = true;
+	   knownName = true;
 	   if ( (!foo->Duid) && (!foo->Addr) ) {
 		Log(Debug) << "Client's hint: " << hint << " found in fqdn list, setting fqdn to "<< foo->Name << LogEnd;
 		return foo;
 	    }
 	}
 	if (!foo->Addr && !foo->Duid) {
-	    if (!bestFound)
-		bestFound = foo;
-	 //   return foo;
+	    if (!alternative)
+		alternative = foo;
 	}
     }
 
-    if (!hint.empty() &&  !duplicate )
+    switch (UnknownFQDN)
     {
-	if (acceptUnknownFQDN()) // should the server be accepting unknown names?
-	{
-	    Log(Debug) << "Client's hint: " << hint <<" but not found in FQDN list, creating an entry  " <<LogEnd;
-	    SPtr<TFQDN> newEntry = new TFQDN(hint,false);
-	    FQDNLst.append(newEntry);
-	    Log(Debug) << "Retured FQDN  " << newEntry->Name <<LogEnd;
-	    return newEntry;
-	} else
-	{
-	    Log(Info) << "FQDN: Client sent valid hint that is not mentioned in server configuration."
-		      << " Currently server is configured to drop such hints. To accept them, please "
-		      << "add accept-unknown-fqdn in the server.conf." << LogEnd;
-	}
+    default:
+    {
+	Log(Error) << "FQDN: Invalid unknown-fqdn mode specified (" << UnknownFQDN << ")." << LogEnd;
+	return 0;
+    }
+    case UNKNOWN_FQDN_REJECT:
+    {
+	Log(Info) << "FQDN: Client sent valid hint (" << hint << ") that is not "
+		  << "mentioned in server configuration. Server is configured to "
+		  << "drop such hints. To accept them, please "
+		  << "'add accept-unknown-fqdn X' in the server.conf (with X>0)." << LogEnd;
+	return 0;
+    }
+    case UNKKOWN_FQDN_ACCEPT_POOL:
+    {
+	if (alternative)
+	    Log(Info) << "FQDN: Client requested " << hint << ", but assigning other name (" 
+		      << alternative->Name << ") from available pool instead." << LogEnd;
+	return alternative;
+    }
+    case UNKNOWN_FQDN_ACCEPT:
+    {
+	Log(Info) << "FQDN: Accepting unknown (" << hint <<") FQDN requested by client." <<LogEnd;
+	SPtr<TFQDN> newEntry = new TFQDN(hint,false);
+	FQDNLst.append(newEntry);
+	Log(Debug) << "Retured FQDN  " << newEntry->Name <<LogEnd;
+	return newEntry;
+    }
+    case UKNNOWN_FQDN_APPEND:
+    {
+	string assignedDomain = hint;
+        std::string::size_type j = assignedDomain.find(".");
+        assignedDomain = assignedDomain.substr(0, j); // chop off anything after first dot
+
+        // sanity check
+        for (int k=assignedDomain.length(); k>=0; k--){
+            char x = assignedDomain[k];
+            if (!isalpha(x) && !isdigit(x) && (x!='-') ) {
+                assignedDomain.replace(k,1,""); // remove all inappropriate chars
+            }
+        }
+
+        assignedDomain += "." + FQDNDomain;
+	SPtr<TFQDN> newEntry = new TFQDN(assignedDomain, false);
+	FQDNLst.append(newEntry);
+	Log(Info) << "FQDN: Client requested (" << hint <<"), assigning (" << assignedDomain << ")." <<LogEnd;
+	return newEntry;
+    }
+    case UKNNOWN_FQDN_PROCEDURAL:
+    {
+	string tmp = addr->getPlain();
+	std::string::size_type j = 0;
+	while ( (j=tmp.find("::"))!=std::string::npos)
+	    tmp.replace(j,1,"-");
+	while ( (j=tmp.find(':'))!=std::string::npos)
+	    tmp.replace(j,1,"-");
+	tmp = tmp + "." + FQDNDomain;
+	SPtr<TFQDN> newEntry = new TFQDN(tmp, false);
+	FQDNLst.append(newEntry);
+	Log(Info) << "FQDN: Client requested (" << hint <<"), assiging (" << tmp << ")." <<LogEnd;
+	return newEntry;
     }
 
-    if (bestFound) {
-	Log(Debug) << "Not reserved FQDN found: " << bestFound->Name << LogEnd;
-	return bestFound;
     }
 
     // not found
     return 0;
 }
 
-/**
- * returns if server should accept FQDN hints that are not configured in the server.conf
- *
- *
- * @return true, if unknown names should be accepted
- */
-bool TSrvCfgIface::acceptUnknownFQDN() {
-    return AcceptUnknownFQDN;
-}
-
-SmartPtr<TDUID> TSrvCfgIface::getFQDNDuid(string name) {
-    SmartPtr<TDUID> res = new TDUID();
+SPtr<TDUID> TSrvCfgIface::getFQDNDuid(string name) {
+    SPtr<TDUID> res = new TDUID();
     return res;
 }
 
@@ -556,20 +611,19 @@ List(TFQDN) *TSrvCfgIface::getFQDNLst() {
 }
 
 bool TSrvCfgIface::supportFQDN() {
-    return this->FQDNSupport;
+    return FQDNLst.count() || UnknownFQDN>=UNKNOWN_FQDN_ACCEPT;
 }
 
-void TSrvCfgIface::setFQDNMode(int FQDNMode) {
-    this->FQDNMode = FQDNMode;
-}
 int TSrvCfgIface::getFQDNMode(){
-    return this->FQDNMode;
+    return FQDNMode;
 }
+
 int TSrvCfgIface::getRevDNSZoneRootLength(){
-	return this->revDNSZoneRootLength;
+    return this->revDNSZoneRootLength;
 }
+
 void TSrvCfgIface::setRevDNSZoneRootLength(int revDNSZoneRootLength){
-	this->revDNSZoneRootLength=revDNSZoneRootLength;
+    this->revDNSZoneRootLength=revDNSZoneRootLength;
 }
 
 string TSrvCfgIface::getFQDNModeString() {
@@ -583,7 +637,7 @@ string TSrvCfgIface::getFQDNModeString() {
 
 
 void TSrvCfgIface::addTAAddr() {
-    SmartPtr<TSrvCfgTA> ta;
+    SPtr<TSrvCfgTA> ta;
     this->firstTA();
     ta=this->getTA();
     if (!ta) {
@@ -595,7 +649,7 @@ void TSrvCfgIface::addTAAddr() {
 }
 
 void TSrvCfgIface::delTAAddr() {
-    SmartPtr<TSrvCfgTA> ta;
+    SPtr<TSrvCfgTA> ta;
     this->firstTA();
     ta = this->getTA();
     if (!ta) {
@@ -612,16 +666,21 @@ void TSrvCfgIface::delTAAddr() {
 // --------------------------------------------------------------------
 
 ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
-    SmartPtr<TStationID> Station;
-    SmartPtr<TIPv6Addr> addr;
-    SmartPtr<string> str;
+    SPtr<TStationID> Station;
+    SPtr<TIPv6Addr> addr;
+    SPtr<string> str;
 
     out << dec;
     out << "  <SrvCfgIface name=\""<<iface.Name << "\" ifindex=\""<<iface.ID << "\">" << endl;
 
     if (iface.Relay) {
-	out << "    <relay name=\"" << iface.RelayName << "\" ifindex=\"" << iface.RelayID << "\" interfaceid=\""
-	    << iface.RelayInterfaceID->getPlain() << "\"/>" << std::endl;
+        out << "    <relay name=\"" << iface.RelayName << "\" ifindex=\"" << iface.RelayID;
+	if (iface.RelayInterfaceID) {
+	  out << "\" interfaceid=\"" << iface.RelayInterfaceID->getPlain() << "\"";
+	} else {
+	  out << "\" interfaceid=null";
+	}
+	out << "/>" << std::endl;
     } else {
 	out << "    <!-- <relay/> -->" << std::endl;
     }
@@ -645,7 +704,7 @@ ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
 
     out << endl;
     // print IA objects
-    SmartPtr<TSrvCfgAddrClass>	ia;
+    SPtr<TSrvCfgAddrClass>	ia;
     iface.SrvCfgAddrClassLst.first();
     out << "    <!-- IA: non-temporary addr class count: " << iface.SrvCfgAddrClassLst.count() << "-->" << endl;
     while( ia=iface.SrvCfgAddrClassLst.get() ) {
@@ -654,7 +713,7 @@ ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
 
     out << endl;
     // print PD objects
-    SmartPtr<TSrvCfgPD>	pd;
+    SPtr<TSrvCfgPD>	pd;
     iface.SrvCfgPDLst.first();
     out << "    <!-- PD: prefix delegation class count: " << iface.SrvCfgPDLst.count() << "-->" << endl;
     while( pd=iface.SrvCfgPDLst.get() ) {
@@ -663,7 +722,7 @@ ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
 
     out << endl;
     // print TA objects
-    SmartPtr<TSrvCfgTA> ta;
+    SPtr<TSrvCfgTA> ta;
     iface.firstTA();
     out << "    <!-- TA: temporary IPv6 addr class count: " << iface.SrvCfgTALst.count() << "-->" << endl;
     while( ta=iface.getTA() )
@@ -751,35 +810,44 @@ ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
     }
 
     // option: VENDOR-SPEC
-    if (iface.supportVendorSpec()) {
+/*    if (iface.supportVendorSpec()) {
 	out << "    <vendorSpecList count=\"" << iface.VendorSpec.count() << "\">" << endl;
 	iface.VendorSpec.first();
         SPtr<TSrvOptVendorSpec> v;
 	while (v = iface.VendorSpec.get()) {
-	    out << "      <vendorSpec vendor=\"" << v->getVendor() << "\" length=\"" << v->getVendorDataLen()
-	    << "\">" << v->getVendorDataPlain() << "</vendorSpec>" << endl;
+	    out << "      <vendorSpec vendor=\"" << v->getVendor() << "\">" << endl;
+            SPtr<TOpt> sub;
+            v->firstOption();
+            while (sub = v->getOption()) {
+                out << "        <option code=\"" << sub->getOptType() 
+                    << "\" length=\"" << sub->getSize() << "\">"
+                    << sub->getPlain() << "</option>" << endl;
+            }
+	    out << "      </vendorSpec>" << endl;
 	}
 	out << "    </vendorSpecList>" << endl;
     } else {
 	out << "    <!-- <vendorSpec/> -->" << endl;
-    }
+        }*/
 
-    out << "    <!-- " << iface.getExtraOptions().count() << " extra option(s) -->" << endl;
+    out << "    <!-- " << iface.getExtraOptions().size() << " extra option(s) -->" << endl;
 
-    List(TSrvOptGeneric) extraOpts;
-    SPtr<TSrvOptGeneric> gen;
-    extraOpts = iface.getExtraOptions();
-    extraOpts.first();
-    while (gen = extraOpts.get())
+    TOptList extraLst =  iface.getExtraOptions();
+    for (TOptList::iterator extra = extraLst.begin(); extra!=extraLst.end(); ++extra)
     {
-	out << "      <extraOption length=\"" << gen->getSize()-4 << "\"/>" << endl;
-    }
+	out << "      <extraOption type=\"" << (*extra)->getOptType() 
+            << "\" length=\"" << (*extra)->getSize() << "\"/>" << endl;
+    } 
 
     // option: FQDN
     if (iface.supportFQDN()) {
       SPtr<TFQDN> f;
       List(TFQDN) * lst = iface.getFQDNLst();
-      out << "    <fqdnOptions count=\"" << lst->count() << "\" prefix=\"" << iface.getRevDNSZoneRootLength() << "\">" << endl;
+      out << "    <fqdnOptions count=\"" << lst->count() << "\" prefix=\"" 
+	  << iface.getRevDNSZoneRootLength() << "\""
+	  << " domain=\"" << iface.FQDNDomain << "\""
+	  << " unknownFqdnMode=\"" << iface.UnknownFQDN << "\""
+	  << ">" << endl;
       lst->first();
       while (f=lst->get()) {
 	    out << "       " << *f;
@@ -803,25 +871,23 @@ ostream& operator<<(ostream& out,TSrvCfgIface& iface) {
 
 void TSrvCfgIface::mapAllowDenyList( List(TSrvCfgClientClass) clientClassLst)
 {
+    //  Log(Info)<<"Mapping allow, deny list inside interface "<<Name<<LogEnd;
+    SPtr<TSrvCfgAddrClass> ptrClass;
+    this->SrvCfgAddrClassLst.first();
+    while(ptrClass=SrvCfgAddrClassLst.get()){
+	ptrClass->mapAllowDenyList(clientClassLst);
+    }
 
-	//  Log(Info)<<"Mapping allow, deny list inside interface "<<Name<<LogEnd;
-	  SmartPtr<TSrvCfgAddrClass> ptrClass;
-	  this->SrvCfgAddrClassLst.first();
-	  while(ptrClass=SrvCfgAddrClassLst.get()){
-		  ptrClass->mapAllowDenyList(clientClassLst);
-	  }
-
-
-   // Map the Allow and Deny list to TA c
-	  SmartPtr<TSrvCfgTA> ptrTA;
-	  this->SrvCfgTALst.first();
-	  while(ptrTA = SrvCfgTALst.get()){
-		  ptrTA->mapAllowDenyList(clientClassLst);
-	  }
-	  // Map the Allow and Deny list to prefix
-	  SmartPtr<TSrvCfgPD> ptrPD;
-	  this->SrvCfgPDLst.first();
-	  while(ptrPD = SrvCfgPDLst.get()){
-		  ptrPD->mapAllowDenyList(clientClassLst);
-	  }
+    // Map the Allow and Deny list to TA c
+    SPtr<TSrvCfgTA> ptrTA;
+    this->SrvCfgTALst.first();
+    while(ptrTA = SrvCfgTALst.get()){
+	ptrTA->mapAllowDenyList(clientClassLst);
+    }
+    // Map the Allow and Deny list to prefix
+    SPtr<TSrvCfgPD> ptrPD;
+    this->SrvCfgPDLst.first();
+    while(ptrPD = SrvCfgPDLst.get()){
+	ptrPD->mapAllowDenyList(clientClassLst);
+    }
 }
