@@ -6,11 +6,10 @@
  * changes: Petr Pisar <petr.pisar(at)atlas(dot)cz>
  *          Michal Kowalczuk <michal@kowalczuk.eu>
  *          Nguyen Vinh Nghiem
+ *          Grzegorz Pluto <g.pluto(at)u-r-b-a-n(dot)pl>
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: SrvCfgMgr.cpp,v 1.58 2008-10-12 20:07:31 thomson Exp $
- *
  */
 
 #include <iostream>
@@ -18,38 +17,34 @@
 #include <string>
 #include "SmartPtr.h"
 #include "Portable.h"
+#include "FlexLexer.h"
+#include "SrvParser.h"
 #include "SrvCfgMgr.h"
 #include "SrvCfgIface.h"
 #include "Logger.h"
-
-using namespace std;
-
 #include "IfaceMgr.h"
 #include "SrvIfaceMgr.h"
-
-#include "AddrClient.h"
+#include "AddrMgr.h"
 #include "TimeZone.h"
-
-#include "FlexLexer.h"
 #include "SrvParser.h"
 
+TSrvCfgMgr * TSrvCfgMgr::Instance = 0;
 int TSrvCfgMgr::NextRelayID = RELAY_MIN_IFINDEX;
 
-TSrvCfgMgr::TSrvCfgMgr(SmartPtr<TSrvIfaceMgr> ifaceMgr, string cfgFile, string xmlFile)
-    :TCfgMgr((Ptr*)ifaceMgr)
+TSrvCfgMgr::TSrvCfgMgr(const std::string cfgFile, const std::string xmlFile)
+    :TCfgMgr(), XmlFile(xmlFile), reconfigure(true)
 {
-    this->IfaceMgr = ifaceMgr;
-    this->XmlFile = xmlFile;
-
+    setDefaults();
+ 
     // load config file
     if (!this->parseConfigFile(cfgFile)) {
-	this->IsDone = true;
-	return;
+  	    IsDone = true;
+	      return;
     }
 
     // load or create DUID
     string duidFile = (string)SRVDUID_FILE;
-    if (!this->setDUID(duidFile)) {
+    if (!setDUID(duidFile, SrvIfaceMgr())) {
 		this->IsDone=true;
 		return;
     }
@@ -63,6 +58,14 @@ TSrvCfgMgr::TSrvCfgMgr(SmartPtr<TSrvIfaceMgr> ifaceMgr, string cfgFile, string x
     IsDone = false;
 }
 
+void TSrvCfgMgr::setDefaults()
+{
+    BulkLQAccept = BULKLQ_ACCEPT;
+    BulkLQTcpPort = BULKLQ_TCP_PORT;
+    BulkLQMaxConns = BULKLQ_MAX_CONNS;
+    BulkLQTimeout = BULKLQ_TIMEOUT;
+}
+
 bool TSrvCfgMgr::parseConfigFile(string cfgFile) {
     int result;
     ifstream f;
@@ -77,6 +80,7 @@ bool TSrvCfgMgr::parseConfigFile(string cfgFile) {
     }
     yyFlexLexer lexer(&f,&clog);
     SrvParser parser(&lexer);
+    parser.CfgMgr = this; // just a workaround (parser is called, while SrvCfgMgr is still in constructor, so instance() singleton method can't be called
     result = parser.yyparse();
     Log(Debug) << "Parsing " << cfgFile << " done." << LogEnd;
     f.close();
@@ -116,6 +120,12 @@ bool TSrvCfgMgr::parseConfigFile(string cfgFile) {
 	Log(Notice) << "Running in stateful mode." << LogEnd;
     }
 
+    // @todo: remove this info later
+    Log(Debug) << "Bulk-leasequery: enabled=" << (BulkLQAccept?"yes":"no")
+	       << ", TCP port=" << BulkLQTcpPort
+	       << ", max conns=" << BulkLQMaxConns
+	       << ", timeout=" << BulkLQTimeout << LogEnd;
+
     return true;
 }
 
@@ -126,7 +136,7 @@ void TSrvCfgMgr::dump() {
     xmlDump.close();
 }
 
-bool TSrvCfgMgr::setGlobalOptions(SmartPtr<TSrvParsGlobalOpt> opt) {
+bool TSrvCfgMgr::setGlobalOptions(SPtr<TSrvParsGlobalOpt> opt) {
     this->Workdir          = opt->getWorkDir();
     this->Stateless        = opt->getStateless();
     this->CacheSize        = opt->getCacheSize();
@@ -152,8 +162,8 @@ bool TSrvCfgMgr::matchParsedSystemInterfaces(SrvParser *parser) {
     cfgIfaceCnt = parser->SrvCfgIfaceLst.count();
     Log(Debug) << cfgIfaceCnt << " interface(s) specified in " << SRVCONF_FILE << LogEnd;
 
-    SmartPtr<TSrvCfgIface> cfgIface;
-    SmartPtr<TIfaceIface>  ifaceIface;
+    SPtr<TSrvCfgIface> cfgIface;
+    SPtr<TIfaceIface>  ifaceIface;
 
     parser->SrvCfgIfaceLst.first();
     while(cfgIface=parser->SrvCfgIfaceLst.get()) {
@@ -176,9 +186,9 @@ bool TSrvCfgMgr::matchParsedSystemInterfaces(SrvParser *parser) {
 	// physical interface
 	if (cfgIface->getID()==-1) {
 	    // ID==-1 means that user referenced to interface by name
-	    ifaceIface = IfaceMgr->getIfaceByName(cfgIface->getName());
+	    ifaceIface = SrvIfaceMgr().getIfaceByName(cfgIface->getName());
 	} else {
-	    ifaceIface = IfaceMgr->getIfaceByID(cfgIface->getID());
+	    ifaceIface = SrvIfaceMgr().getIfaceByID(cfgIface->getID());
 	}
 	if (!ifaceIface) {
 	    Log(Crit) << "Interface " << cfgIface->getFullName()
@@ -189,7 +199,7 @@ bool TSrvCfgMgr::matchParsedSystemInterfaces(SrvParser *parser) {
 
 	// Complete name and ID (one of them usually misses depending on
 	// identifier used in config file.
-	// FIXME: Client's class uses setIface{Name,ID}(). We should unite the
+	/// @todo: Client's class uses setIface{Name,ID}(). We should unite the
 	// method names.
 	cfgIface->setName(ifaceIface->getName());
 	cfgIface->setID(ifaceIface->getID());
@@ -239,11 +249,11 @@ bool TSrvCfgMgr::matchParsedSystemInterfaces(SrvParser *parser) {
     return true;
 }
 
-SmartPtr<TSrvCfgIface> TSrvCfgMgr::getIface() {
+SPtr<TSrvCfgIface> TSrvCfgMgr::getIface() {
 	return this->SrvCfgIfaceLst.get();
 }
 
-void TSrvCfgMgr::addIface(SmartPtr<TSrvCfgIface> ptr) {
+void TSrvCfgMgr::addIface(SPtr<TSrvCfgIface> ptr) {
     SrvCfgIfaceLst.append(ptr);
 }
 
@@ -254,7 +264,7 @@ void TSrvCfgMgr::addIface(SmartPtr<TSrvCfgIface> ptr) {
  * @param inactive true for makeing inactive, false for makeing active
  */
 void TSrvCfgMgr::makeInactiveIface(int ifindex, bool inactive) {
-    SmartPtr<TSrvCfgIface> x;
+    SPtr<TSrvCfgIface> x;
 
     if (inactive)
     {
@@ -316,12 +326,12 @@ SPtr<TSrvCfgIface> TSrvCfgMgr::checkInactiveIfaces() {
     if (!InactiveLst.count())
 	return 0;
 
-    IfaceMgr->redetectIfaces();
+    SrvIfaceMgr().redetectIfaces();
     SPtr<TSrvCfgIface> x;
     SPtr<TIfaceIface> iface;
     InactiveLst.first();
     while (x = InactiveLst.get()) {
-	iface = IfaceMgr->getIfaceByID(x->getID());
+	iface = SrvIfaceMgr().getIfaceByID(x->getID());
 	if (!iface) {
 	    Log(Error) << "TSrvCfgMgr::checkInactiveIfaces(): " <<
 		"Unable to find interface with ifindex=" << x->getID() << LogEnd;
@@ -362,12 +372,12 @@ TSrvCfgMgr::~TSrvCfgMgr() {
  * 
  * @return 
  */
-bool TSrvCfgMgr::isTAAddrSupported(int iface, SmartPtr<TIPv6Addr> addr) {
-    SmartPtr<TSrvCfgIface> ptrIface = this->getIfaceByID(iface);
+bool TSrvCfgMgr::isTAAddrSupported(int iface, SPtr<TIPv6Addr> addr) {
+    SPtr<TSrvCfgIface> ptrIface = this->getIfaceByID(iface);
     if (!ptrIface)
 	return false;
     ptrIface->firstTA();
-    SmartPtr<TSrvCfgTA> ta = ptrIface->getTA();
+    SPtr<TSrvCfgTA> ta = ptrIface->getTA();
     if (!ta)
 	return false;
     return ta->addrInPool(addr);
@@ -382,12 +392,12 @@ bool TSrvCfgMgr::isTAAddrSupported(int iface, SmartPtr<TIPv6Addr> addr) {
  * 
  * @return true, if address is supported
  */
-bool TSrvCfgMgr::isIAAddrSupported(int iface, SmartPtr<TIPv6Addr> addr) {
-    SmartPtr<TSrvCfgIface> ptrIface = this->getIfaceByID(iface);
+bool TSrvCfgMgr::isIAAddrSupported(int iface, SPtr<TIPv6Addr> addr) {
+    SPtr<TSrvCfgIface> ptrIface = this->getIfaceByID(iface);
     if (!ptrIface)
 	return false;
     ptrIface->firstAddrClass();
-    SmartPtr<TSrvCfgAddrClass> addrClass;
+    SPtr<TSrvCfgAddrClass> addrClass;
     while (addrClass = ptrIface->getAddrClass()) {
 	if (addrClass->addrInPool(addr))
 	    return true;
@@ -409,13 +419,13 @@ bool TSrvCfgMgr::isIAAddrSupported(int iface, SmartPtr<TIPv6Addr> addr) {
  * 
  * @return return value <= clnt-max-lease <= iface-max-lease
  */
-long TSrvCfgMgr::countAvailAddrs(SmartPtr<TDUID> clntDuid,
-				 SmartPtr<TIPv6Addr> clntAddr,  int iface)
+long TSrvCfgMgr::countAvailAddrs(SPtr<TDUID> clntDuid,
+				 SPtr<TIPv6Addr> clntAddr,  int iface)
 {
-    // FIXME: long long long int (128bit) could come in handy
+    /// @todo: long long long int (128bit) could come in handy
     double avail         = 0; // how many are available?
     double ifaceAssigned = 0; // how many are assigned on this iface?
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Error) << "Interface " << iface << " does not exist in SrvCfgMgr." << LogEnd;
@@ -424,7 +434,7 @@ long TSrvCfgMgr::countAvailAddrs(SmartPtr<TDUID> clntDuid,
 
     unsigned long ifaceMaxLease = ptrIface->getIfaceMaxLease();
 
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TSrvCfgAddrClass> ptrClass;
     ptrIface->firstAddrClass();
     while (ptrClass = ptrIface->getAddrClass()) {
 	if (!ptrClass->clntSupported(clntDuid,clntAddr))
@@ -453,10 +463,10 @@ long TSrvCfgMgr::countAvailAddrs(SmartPtr<TDUID> clntDuid,
  * 
  * @return pointer to the class (or 0, if no suitable class found)
  */
-SmartPtr<TSrvCfgAddrClass> TSrvCfgMgr::getClassByAddr(int iface, SmartPtr<TIPv6Addr> addr)
+SPtr<TSrvCfgAddrClass> TSrvCfgMgr::getClassByAddr(int iface, SPtr<TIPv6Addr> addr)
 {
     this->firstIface();
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
 
     if (!ptrIface) {
@@ -464,7 +474,7 @@ SmartPtr<TSrvCfgAddrClass> TSrvCfgMgr::getClassByAddr(int iface, SmartPtr<TIPv6A
 	return 0; // NULL
     }
 
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TSrvCfgAddrClass> ptrClass;
     ptrIface->firstAddrClass();
     while (ptrClass = ptrIface->getAddrClass()) {
 	if (ptrClass->addrInPool(addr))
@@ -482,10 +492,10 @@ SmartPtr<TSrvCfgAddrClass> TSrvCfgMgr::getClassByAddr(int iface, SmartPtr<TIPv6A
  *
  * @return class (or 0 if no class is found)
  */
-SmartPtr<TSrvCfgPD> TSrvCfgMgr::getClassByPrefix(int iface, SmartPtr<TIPv6Addr> addr)
+SPtr<TSrvCfgPD> TSrvCfgMgr::getClassByPrefix(int iface, SPtr<TIPv6Addr> addr)
 {
     this->firstIface();
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
 
     if (!ptrIface) {
@@ -493,7 +503,7 @@ SmartPtr<TSrvCfgPD> TSrvCfgMgr::getClassByPrefix(int iface, SmartPtr<TIPv6Addr>
 	return 0;
     }
 
-    SmartPtr<TSrvCfgPD> ptrClass;
+    SPtr<TSrvCfgPD> ptrClass;
     ptrIface->firstPD();
     while (ptrClass = ptrIface->getPD()) {
 	if (ptrClass->prefixInPool(addr))
@@ -505,12 +515,12 @@ SmartPtr<TSrvCfgPD> TSrvCfgMgr::getClassByPrefix(int iface, SmartPtr<TIPv6Addr>
 
 
 //on basis of duid/address/iface assign addresss to client
-SmartPtr<TIPv6Addr> TSrvCfgMgr::getRandomAddr(SmartPtr<TDUID> clntDuid,
-					      SmartPtr<TIPv6Addr> clntAddr,
+SPtr<TIPv6Addr> TSrvCfgMgr::getRandomAddr(SPtr<TDUID> clntDuid,
+					      SPtr<TIPv6Addr> clntAddr,
 					      int iface) {
-    SmartPtr<TSrvCfgIface> ptrIface;
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
-    SmartPtr<TIPv6Addr>    any;
+    SPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TIPv6Addr>    any;
 
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
@@ -522,33 +532,41 @@ SmartPtr<TIPv6Addr> TSrvCfgMgr::getRandomAddr(SmartPtr<TDUID> clntDuid,
     ptrClass = ptrIface->getAddrClass();
     return ptrClass->getRandomAddr();
 
-    //FIXME: get addrs from first address only
+    /// @todo: get addrs from first address only
 }
 
 
 /*
  * Method checks whether client is supported and assigned addresses from any class
  */
-bool TSrvCfgMgr::isClntSupported(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, int iface)
+bool TSrvCfgMgr::isClntSupported(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, int iface)
 {
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     firstIface();
     while((ptrIface=getIface())&&(ptrIface->getID()!=iface)) ;
 
-    /* FIXME: reject-client and accept-only does not work in stateless mode */
+    /** @todo: reject-client and accept-only does not work in stateless mode */
     if (this->stateless())
 	return true;
 
     int classCnt = 0;
     if (ptrIface)
     {
-        SmartPtr<TSrvCfgAddrClass> ptrClass;
+        SPtr<TSrvCfgAddrClass> ptrClass;
         ptrIface->firstAddrClass();
         while(ptrClass=ptrIface->getAddrClass()) {
             if (ptrClass->clntSupported(duid,clntAddr))
                 return true;
 	    classCnt++;
 	}
+
+        SPtr<TSrvCfgPD> pd;
+        ptrIface->firstPD();
+        while ( pd=ptrIface->getPD() ) {
+            if (pd->clntSupported(duid, clntAddr))
+                return true;
+            classCnt++;
+        }
     }
     if (!classCnt) {
 	Log(Warning) << "There are no address class defined on the " << ptrIface->getFullName()
@@ -562,20 +580,20 @@ bool TSrvCfgMgr::isClntSupported(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntA
 /*
 * Method checks whether client is supported and assigned addresses from any class
 */
-bool TSrvCfgMgr::isClntSupported(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, int iface, SmartPtr<TSrvMsg> msg)
+bool TSrvCfgMgr::isClntSupported(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, int iface, SPtr<TSrvMsg> msg)
 {
-   SmartPtr<TSrvCfgIface> ptrIface;
+   SPtr<TSrvCfgIface> ptrIface;
    firstIface();
    while((ptrIface=getIface())&&(ptrIface->getID()!=iface)) ;
 
-   /* FIXME: reject-client and accept-only does not work in stateless mode */
+   /** @todo: reject-client and accept-only does not work in stateless mode */
    if (this->stateless())
 	return true;
 
    int classCnt = 0;
    if (ptrIface)
    {
-       SmartPtr<TSrvCfgAddrClass> ptrClass;
+       SPtr<TSrvCfgAddrClass> ptrClass;
        ptrIface->firstAddrClass();
        while(ptrClass=ptrIface->getAddrClass()) {
            if (ptrClass->clntSupported(duid,clntAddr,msg))
@@ -596,7 +614,7 @@ bool TSrvCfgMgr::isDone() {
 }
 
 bool TSrvCfgMgr::validateConfig() {
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
 
     if (0 == (this->countIface() + this->inactiveIfacesCnt())) {
 	Log(Crit) << "Config problem: No interface defined." << LogEnd;
@@ -611,22 +629,23 @@ bool TSrvCfgMgr::validateConfig() {
     return true;
 }
 
-bool TSrvCfgMgr::validateIface(SmartPtr<TSrvCfgIface> ptrIface)
+bool TSrvCfgMgr::validateIface(SPtr<TSrvCfgIface> ptrIface)
 {
     bool dummyRelay = false;
-    SmartPtr<TSrvIfaceIface> iface = (Ptr*)this->IfaceMgr->getIfaceByID(ptrIface->getID());
+    SPtr<TSrvIfaceIface> iface = (Ptr*)SrvIfaceMgr().getIfaceByID(ptrIface->getID());
     if (iface && ptrIface->isRelay() && iface->getRelayCnt())
 	dummyRelay = true;
 
-    if (ptrIface->countAddrClass() && this->stateless()) {
+    if (ptrIface->countAddrClass() && stateless()) {
 	Log(Crit) << "Config problem: Interface " << ptrIface->getFullName()
 		  << ": Class definitions present, but stateless mode set." << LogEnd;
 	return false;
     }
-    if (!ptrIface->countAddrClass() && !this->stateless()) {
+    if (!ptrIface->countAddrClass() && !ptrIface->countPD() 
+	&& !ptrIface->getTA() && !stateless()) {
 	if (!dummyRelay) {
 	    Log(Crit) << "Config problem: Interface " << ptrIface->getName() << "/" << ptrIface->getID()
-		      << ": No class definitions present, but stateless mode not set." << LogEnd;
+		      << ": No class definitions (IA,TA or PD) present, but stateless mode not set." << LogEnd;
 	    return false;
 	} else {
 	    Log(Warning) << "Interface " << ptrIface->getFullName() << " has no addrs defined, working as cascade relay interface."
@@ -640,7 +659,7 @@ bool TSrvCfgMgr::validateIface(SmartPtr<TSrvCfgIface> ptrIface)
 	return false;
     }
 
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TSrvCfgAddrClass> ptrClass;
     ptrIface->firstAddrClass();
     while(ptrClass=ptrIface->getAddrClass()) {
 	if (!this->validateClass(ptrIface, ptrClass)) {
@@ -652,7 +671,7 @@ bool TSrvCfgMgr::validateIface(SmartPtr<TSrvCfgIface> ptrIface)
     return true;
 }
 
-bool TSrvCfgMgr::validateClass(SmartPtr<TSrvCfgIface> ptrIface, SmartPtr<TSrvCfgAddrClass> ptrClass)
+bool TSrvCfgMgr::validateClass(SPtr<TSrvCfgIface> ptrIface, SPtr<TSrvCfgAddrClass> ptrClass)
 {
     if (ptrClass->isLinkLocal()) {
 	Log(Crit) << "One of the classes defined on the " << ptrIface->getName() << "/" << ptrIface->getID()
@@ -679,8 +698,8 @@ bool TSrvCfgMgr::validateClass(SmartPtr<TSrvCfgIface> ptrIface, SmartPtr<TSrvCfg
     return true;
 }
 
-SmartPtr<TSrvCfgIface> TSrvCfgMgr::getIfaceByID(int iface) {
-    SmartPtr<TSrvCfgIface> ptrIface;
+SPtr<TSrvCfgIface> TSrvCfgMgr::getIfaceByID(int iface) {
+    SPtr<TSrvCfgIface> ptrIface;
     this->firstIface();
     while ( ptrIface = this->getIface() ) {
 	if ( ptrIface->getID()==iface )
@@ -692,8 +711,8 @@ SmartPtr<TSrvCfgIface> TSrvCfgMgr::getIfaceByID(int iface) {
 }
 
 
-void TSrvCfgMgr::delClntAddr(int iface, SmartPtr<TIPv6Addr> addr) {
-    SmartPtr<TSrvCfgIface> ptrIface;
+void TSrvCfgMgr::delClntAddr(int iface, SPtr<TIPv6Addr> addr) {
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Warning) << "Unable to decrease address usage: unknown interface (id="
@@ -703,8 +722,8 @@ void TSrvCfgMgr::delClntAddr(int iface, SmartPtr<TIPv6Addr> addr) {
     ptrIface->delClntAddr(addr);
 }
 
-void TSrvCfgMgr::addClntAddr(int iface, SmartPtr<TIPv6Addr> addr) {
-    SmartPtr<TSrvCfgIface> ptrIface;
+void TSrvCfgMgr::addClntAddr(int iface, SPtr<TIPv6Addr> addr) {
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Warning) << "Unable to increase address usage: unknown interface (id="
@@ -715,7 +734,7 @@ void TSrvCfgMgr::addClntAddr(int iface, SmartPtr<TIPv6Addr> addr) {
 }
 
 void TSrvCfgMgr::addTAAddr(int iface) {
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Error) << "Unable to increase address usage: interface (id="
@@ -726,7 +745,7 @@ void TSrvCfgMgr::addTAAddr(int iface) {
 }
 
 void TSrvCfgMgr::delTAAddr(int iface) {
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
 	Log(Error) << "Unable to decrease address usage: interface (id="
@@ -750,11 +769,11 @@ bool TSrvCfgMgr::guessMode()
     return GuessMode;
 }
 
-bool TSrvCfgMgr::setupRelay(SmartPtr<TSrvCfgIface> cfgIface) {
-    SmartPtr<TIfaceIface> iface;
+bool TSrvCfgMgr::setupRelay(SPtr<TSrvCfgIface> cfgIface) {
+    SPtr<TIfaceIface> iface;
     string name = cfgIface->getRelayName();
 
-    iface = IfaceMgr->getIfaceByName(name);
+    iface = SrvIfaceMgr().getIfaceByName(name);
     if (!iface) {
 	Log(Crit) << "Underlaying interface for " << cfgIface->getName() << "/" << cfgIface->getID()
 		  << " with name " << name << " is missing." << LogEnd;
@@ -762,7 +781,7 @@ bool TSrvCfgMgr::setupRelay(SmartPtr<TSrvCfgIface> cfgIface) {
     }
     cfgIface->setRelayID(iface->getID());
 
-    if (!IfaceMgr->setupRelay(cfgIface->getName(), cfgIface->getID(), iface->getID(), cfgIface->getRelayInterfaceID())) {
+    if (!SrvIfaceMgr().setupRelay(cfgIface->getName(), cfgIface->getID(), iface->getID(), cfgIface->getRelayInterfaceID())) {
 	Log(Crit) << "Relay setup for " << cfgIface->getName() << "/" << cfgIface->getID() << " interface failed." << LogEnd;
 	return false;
     }
@@ -786,27 +805,27 @@ ESrvIfaceIdOrder TSrvCfgMgr::getInterfaceIDOrder()
 
 /**
  * decreases prefix usage count (i.e. decreases prefix-pool usage by one)
- * actual prefix is deleted in AddrMgr
+ * Actual prefix is also deleted in AddrMgr.
  *
- * @param iface
- * @param prefix
+ * @param ifindex interface index
+ * @param prefix  prefix to be deleted
  *
- * @return
+ * @return 
  */
 bool TSrvCfgMgr::decrPrefixCount(int ifindex, SPtr<TIPv6Addr> prefix)
 {
-    SmartPtr<TSrvCfgIface> iface;
+    SPtr<TSrvCfgIface> iface;
     iface = getIfaceByID(ifindex);
     if (!iface) {
-	Log(Error) << "Unable to find interface with ifindex=" << ifindex << ", prefix deletion aborted." << LogEnd;
-	return false;
+	      Log(Error) << "Unable to find interface with ifindex=" << ifindex << ", prefix deletion aborted." << LogEnd;
+	      return false;
     }
     return iface->delClntPrefix(prefix);
 }
 
 bool TSrvCfgMgr::incrPrefixCount(int ifindex, SPtr<TIPv6Addr> prefix)
 {
-    SmartPtr<TSrvCfgIface> iface;
+    SPtr<TSrvCfgIface> iface;
     iface = getIfaceByID(ifindex);
     if (!iface) {
 	Log(Error) << "Unable to find interface with ifindex=" << ifindex << ", prefix increase count aborted." << LogEnd;
@@ -821,7 +840,7 @@ List(DigestTypes) TSrvCfgMgr::getDigestLst() {
 }
 
 enum DigestTypes TSrvCfgMgr::getDigest() {
-    SmartPtr<DigestTypes> dt;
+    SPtr<DigestTypes> dt;
 
     if (0 == DigestLst.count())
         return DIGEST_NONE;
@@ -903,7 +922,7 @@ ostream & operator<<(ostream &out, TSrvCfgMgr &x) {
     else
 	out << "  <!-- <stateless/> -->" << std::endl;
 
-    SmartPtr<TSrvCfgIface> ptrIface;
+    SPtr<TSrvCfgIface> ptrIface;
     x.firstIface();
     while (ptrIface = x.getIface()) {
 	out << *ptrIface;
@@ -912,12 +931,12 @@ ostream & operator<<(ostream &out, TSrvCfgMgr &x) {
     return out;
 }
 
-
-void TSrvCfgMgr::InClientClass(SmartPtr<TSrvMsg> msg)
+/// @todo: Fix this! We check if message is from accepted client, but don't do anything with that info
+void TSrvCfgMgr::InClientClass(SPtr<TSrvMsg> msg)
 {
 	// For each client class, check whether the message belong to ClientClass
 	ClientClassLst.first();
-	SmartPtr<TSrvCfgClientClass> clntClass;
+	SPtr<TSrvCfgClientClass> clntClass;
 
 	while( clntClass= ClientClassLst.get() )
 	{
@@ -930,3 +949,129 @@ void TSrvCfgMgr::InClientClass(SmartPtr<TSrvMsg> msg)
 }
 
 
+bool TSrvCfgMgr::reconfigureSupport()
+{
+    return reconfigure;
+}
+
+
+/** 
+ * sets pool usage counters (used during bringup, after AddrDB is loaded from file)
+ * 
+ */
+void TSrvCfgMgr::setCounters()
+{
+    int iaCnt = 0, pdCnt = 0;
+    SrvAddrMgr().firstClient();
+    SPtr<TAddrClient> client;
+    SPtr<TSrvCfgIface> iface;
+    while (client = SrvAddrMgr().getClient()) {
+	
+        // addresses
+	SPtr<TAddrIA> ia;
+	client->firstIA();
+	while ( ia=client->getIA() ) {
+	    iface = getIfaceByID(ia->getIface());
+            if (!iface)
+                continue;
+	    
+	    SPtr<TAddrAddr> addr;
+	    ia->firstAddr();
+	    while ( addr=ia->getAddr() ) {
+		iface->addClntAddr(addr->get(), true/*quiet*/);
+		iaCnt++;
+	    }
+	}
+
+        // prefixes
+        client->firstPD();
+        while (ia = client->getPD() ) {
+            iface = getIfaceByID(ia->getIface());
+            if (!iface)
+                continue;
+            SPtr<TAddrPrefix> prefix;
+            ia->firstPrefix();
+            while ( prefix=ia->getPrefix() ) {
+                iface->addClntPrefix(prefix->get(), true);
+                pdCnt++;
+            }
+        }
+    }
+    Log(Debug) << "Increased pools usage: currently " << iaCnt << " address(es) and " << pdCnt << " prefix(es) are leased." << LogEnd;
+}
+
+
+void TSrvCfgMgr::instanceCreate( const std::string cfgFile, const std::string xmlDumpFile )
+{
+    if (Instance)
+      Log(Crit) << "SrvCfgMgr already created. Application error!" << LogEnd;
+    Instance = new TSrvCfgMgr(cfgFile, xmlDumpFile);
+
+}
+
+TSrvCfgMgr & TSrvCfgMgr::instance()
+{
+    if (!Instance)
+        Log(Crit) << "SrvCfgMgr not initalized yet. Application error. Crashing in 3... 2... 1..." << LogEnd;
+    return *Instance;
+}
+
+    // Bulk-LeaseQuery
+void TSrvCfgMgr::bulkLQAccept(bool enabled)
+{
+    BulkLQAccept = enabled;
+}
+
+void TSrvCfgMgr::bulkLQTcpPort(unsigned short portNumber)
+{
+    BulkLQTcpPort = portNumber;
+}
+
+void TSrvCfgMgr::bulkLQMaxConns(unsigned int maxConnections)
+{
+    BulkLQMaxConns = maxConnections;
+}
+
+void TSrvCfgMgr::bulkLQTimeout(unsigned int timeout)
+{
+    BulkLQTimeout = timeout;
+}
+
+/// Sets DNS server address suitable for DNS Update
+///
+/// @param ddnsAddress DNS server address
+void TSrvCfgMgr::setDDNSAddress(SPtr<TIPv6Addr> ddnsAddress)
+{
+    FqdnDdnsAddress = ddnsAddress;
+}
+
+/// Returns DNS server address suitable for DNS Update
+///
+/// @param iface interface index
+///
+/// @return DNS address (or NULL)
+SPtr<TIPv6Addr> TSrvCfgMgr::getDDNSAddress(int iface)
+{
+    if (FqdnDdnsAddress)
+        return FqdnDdnsAddress;
+
+    SPtr<TSrvCfgIface> ptrIface = this->getIfaceByID(iface);
+    if (!ptrIface) {
+        Log(Warning) << "No global DNS Update address specified and can't find dns-addres on "
+                     << "interface " << iface << LogEnd;
+        return 0;
+    }
+
+    SPtr<TIPv6Addr> DNSAddr;
+
+    List(TIPv6Addr) DNSSrvLst = *ptrIface->getDNSServerLst();
+    DNSSrvLst.first();
+    if (DNSSrvLst.count())
+        DNSAddr = DNSSrvLst.get();
+
+    if (!DNSAddr) {
+        Log(Error) << "DDNS: DNS Update aborted. DNS server address is not specified." << LogEnd;
+        return 0;
+    }
+    return DNSAddr;
+}
