@@ -8,11 +8,10 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: SrvCfgMgr.h,v 1.24 2008-10-12 20:07:31 thomson Exp $
- *
  */
 
 class TSrvCfgMgr;
+
 #ifndef SRVCONFMGR_H
 #define SRVCONFMGR_H
 #include "SmartPtr.h"
@@ -23,58 +22,63 @@ class TSrvCfgMgr;
 #include "Container.h"
 #include "DUID.h"
 #include "KeyList.h"
-
-#include "FlexLexer.h"
-#include "SrvParser.h"
 #include "SrvCfgClientClass.h"
 
+
+#define SrvCfgMgr() (TSrvCfgMgr::instance())
+
+class SrvParser;
+
 class TSrvCfgMgr : public TCfgMgr
 {
 public:
     friend ostream & operator<<(ostream &strum, TSrvCfgMgr &x);
-    TSrvCfgMgr(SmartPtr<TSrvIfaceMgr> ifaceMgr, string cfgFile, string xmlFile);
+
+    static void instanceCreate(const std::string cfgFile, const std::string xmlDumpFile);
+    static TSrvCfgMgr &instance();
 
     bool parseConfigFile(string cfgFile);
 
     //Interfaces acccess methods
     void firstIface();
-    SmartPtr<TSrvCfgIface> getIface();
-    SmartPtr<TSrvCfgIface> getIfaceByID(int iface);
+    SPtr<TSrvCfgIface> getIface();
+    SPtr<TSrvCfgIface> getIfaceByID(int iface);
     long countIface();
-    void addIface(SmartPtr<TSrvCfgIface> iface);
+    void addIface(SPtr<TSrvCfgIface> iface);
     void makeInactiveIface(int ifindex, bool inactive);
     int inactiveIfacesCnt();
     SPtr<TSrvCfgIface> checkInactiveIfaces();
 
     void dump();
 
-    bool setupRelay(SmartPtr<TSrvCfgIface> cfgIface);
+    bool setupRelay(SPtr<TSrvCfgIface> cfgIface);
 
     //Address assignment connected methods
-    long countAvailAddrs(SmartPtr<TDUID> clntDuid, SmartPtr<TIPv6Addr> clntAddr, int iface);
-    SmartPtr<TSrvCfgAddrClass> getClassByAddr(int iface, SmartPtr<TIPv6Addr> addr);
-    SmartPtr<TSrvCfgPD> getClassByPrefix(int iface, SmartPtr<TIPv6Addr> prefix);
-    SmartPtr<TIPv6Addr> getRandomAddr(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, int iface);
-    bool isClntSupported(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, int iface);
-    bool isClntSupported(SmartPtr<TDUID> duid, SmartPtr<TIPv6Addr> clntAddr, int iface, SmartPtr<TSrvMsg> msg);
+    void setCounters();
+    long countAvailAddrs(SPtr<TDUID> clntDuid, SPtr<TIPv6Addr> clntAddr, int iface);
+    SPtr<TSrvCfgAddrClass> getClassByAddr(int iface, SPtr<TIPv6Addr> addr);
+    SPtr<TSrvCfgPD> getClassByPrefix(int iface, SPtr<TIPv6Addr> prefix);
+    SPtr<TIPv6Addr> getRandomAddr(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, int iface);
+    bool isClntSupported(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, int iface);
+    bool isClntSupported(SPtr<TDUID> duid, SPtr<TIPv6Addr> clntAddr, int iface, SPtr<TSrvMsg> msg);
 
     // prefix-related
     bool incrPrefixCount(int iface, SPtr<TIPv6Addr> prefix);
     bool decrPrefixCount(int iface, SPtr<TIPv6Addr> prefix);
 
     // class' usage management
-    void delClntAddr(int iface, SmartPtr<TIPv6Addr> addr);
-    void addClntAddr(int iface, SmartPtr<TIPv6Addr> addr);
+    void delClntAddr(int iface, SPtr<TIPv6Addr> addr);
+    void addClntAddr(int iface, SPtr<TIPv6Addr> addr);
 
-    bool isIAAddrSupported(int iface, SmartPtr<TIPv6Addr> addr);
-    bool isTAAddrSupported(int iface, SmartPtr<TIPv6Addr> addr);
+    bool isIAAddrSupported(int iface, SPtr<TIPv6Addr> addr);
+    bool isTAAddrSupported(int iface, SPtr<TIPv6Addr> addr);
 
     void addTAAddr(int iface);
     void delTAAddr(int iface);
 
     bool isDone();
     virtual ~TSrvCfgMgr();
-    bool setGlobalOptions(SmartPtr<TSrvParsGlobalOpt> opt);
+    bool setGlobalOptions(SPtr<TSrvParsGlobalOpt> opt);
 
     // configuration parameters
     string getWorkdir();
@@ -83,30 +87,46 @@ public:
     bool guessMode();
     ESrvIfaceIdOrder getInterfaceIDOrder();
     int getCacheSize();
+    bool reconfigureSupport();
+
+    void setDDNSAddress(SPtr<TIPv6Addr> ddnsAddress);
+    SPtr<TIPv6Addr> getDDNSAddress(int iface);
+
+    // Bulk-LeaseQuery
+    void bulkLQAccept(bool enabled);
+    void bulkLQTcpPort(unsigned short portNumber);
+    void bulkLQMaxConns(unsigned int maxConnections);
+    void bulkLQTimeout(unsigned int timeout);
 
     //Authentication
 #ifndef MOD_DISABLE_AUTH
-    SmartPtr<KeyList> AuthKeys;
+    SPtr<KeyList> AuthKeys;
     unsigned int getAuthLifetime();
     unsigned int getAuthKeyGenNonceLen();
     List(DigestTypes) getDigestLst();
     enum DigestTypes getDigest();
 #endif
 
+    void setDefaults();
+    std::string getScriptName() { return ScriptName; }
+    void setScriptName(std::string scriptFile) { ScriptName = scriptFile; }
+
     // Client List check
-    void InClientClass(SmartPtr<TSrvMsg> msg);
+    void InClientClass(SPtr<TSrvMsg> msg);
 private:
+    TSrvCfgMgr(string cfgFile, string xmlFile);
+    static TSrvCfgMgr * Instance;
     static int NextRelayID;
     string XmlFile;
+    bool reconfigure;
 
     bool IsDone;
     bool validateConfig();
-    bool validateIface(SmartPtr<TSrvCfgIface> ptrIface);
-    bool validateClass(SmartPtr<TSrvCfgIface> ptrIface, SmartPtr<TSrvCfgAddrClass> ptrClass);
+    bool validateIface(SPtr<TSrvCfgIface> ptrIface);
+    bool validateClass(SPtr<TSrvCfgIface> ptrIface, SPtr<TSrvCfgAddrClass> ptrClass);
     List(TSrvCfgIface) SrvCfgIfaceLst;
     List(TSrvCfgIface) InactiveLst;
     List(TSrvCfgClientClass) ClientClassLst;
-    SmartPtr<TSrvIfaceMgr> IfaceMgr;
     bool matchParsedSystemInterfaces(SrvParser *parser);
 
     // global options
@@ -115,12 +135,22 @@ private:
     bool GuessMode;
     int  CacheSize;
     ESrvIfaceIdOrder InterfaceIDOrder;
+    std::string ScriptName;
 
 #ifndef MOD_DISABLE_AUTH
     unsigned int AuthLifetime;
     unsigned int AuthKeyGenNonceLen;
     List(DigestTypes) DigestLst;
 #endif
+
+    // DDNS address
+    SPtr<TIPv6Addr> FqdnDdnsAddress;
+
+    // lease-query parameters
+    bool BulkLQAccept;
+    unsigned short BulkLQTcpPort;
+    unsigned int BulkLQMaxConns;
+    unsigned int BulkLQTimeout;
 };
 
 #endif /* SRVCONFMGR_H */
