@@ -12,70 +12,80 @@
 
 #include <climits>
 #include "SrvParsIfaceOpt.h"
-#include "DHCPConst.h"
+#include "OptAddr.h"
+#include "OptString.h"
+#include "DHCPDefaults.h"
 #include "Logger.h"
 
 TSrvParsIfaceOpt::TSrvParsIfaceOpt(void)
 {
-    this->Unicast       = 0;
-    this->Preference    = SERVER_DEFAULT_PREFERENCE;
-    this->RapidCommit   = SERVER_DEFAULT_RAPIDCOMMIT;
-    this->ClntMaxLease  = SERVER_DEFAULT_CLNTMAXLEASE;
-    this->IfaceMaxLease = SERVER_DEFAULT_IFACEMAXLEASE;
-    this->LeaseQuery    = false; // don't support leasequery unless explicitly configured to do so
+    Unicast       = 0;
+    Preference    = SERVER_DEFAULT_PREFERENCE;
+    RapidCommit   = SERVER_DEFAULT_RAPIDCOMMIT;
+    ClntMaxLease  = SERVER_DEFAULT_CLNTMAXLEASE;
+    IfaceMaxLease = SERVER_DEFAULT_IFACEMAXLEASE;
+    LeaseQuery    = false; // don't support leasequery unless explicitly configured to do so
 
     // options
-    this->DNSServerSupport  = false;
-    this->DomainSupport     = false;
-    this->NTPServerSupport  = false;
-    this->TimezoneSupport   = false;
-    this->SIPServerSupport  = false;
-    this->SIPDomainSupport  = false;
-    this->FQDNSupport       = false;
-    this->AcceptUnknownFQDN = false;
-    this->NISServerSupport  = false;
-    this->NISDomainSupport  = false;
-    this->NISPServerSupport = false;
-    this->NISPDomainSupport = false;
-    this->LifetimeSupport   = false;
-    this->VendorSpecSupport = false;
+    DNSServerSupport  = false;
+    DomainSupport     = false;
+    NTPServerSupport  = false;
+    TimezoneSupport   = false;
+    SIPServerSupport  = false;
+    SIPDomainSupport  = false;
+    FQDNSupport       = false;
+    NISServerSupport  = false;
+    NISDomainSupport  = false;
+    NISPServerSupport = false;
+    NISPDomainSupport = false;
+    LifetimeSupport   = false;
+    VendorSpecSupport = false;
 
-    this->TunnelMode = 0;
-    this->TunnelVendorSpec = 0;
+    UnknownFQDN = SERVER_DEFAULT_UNKNOWN_FQDN;
+    FQDNDomain = "";
 
-    this->Relay = false;
-    this->RelayName = "[unknown]";
-    this->RelayID = -1;
-    this->RelayInterfaceID = -1;
+    Relay = false;
+    RelayName = "[unknown]";
+    RelayID = -1;
+    RelayInterfaceID = -1;
 }
 
 TSrvParsIfaceOpt::~TSrvParsIfaceOpt(void) {
 }
 
-void TSrvParsIfaceOpt::acceptUnknownFQDN(bool accept) {
-    AcceptUnknownFQDN = accept;
+void TSrvParsIfaceOpt::setUnknownFQDN(EUnknownFQDNMode mode, const std::string domain) {
+    UnknownFQDN = mode;
+    FQDNDomain = domain;
 }
 
-bool TSrvParsIfaceOpt::acceptUnknownFQDN() {
-    return AcceptUnknownFQDN;
+/** 
+ * returns enum that specifies, how to handle unknown FQDNs
+ * 
+ * 
+ * @return 
+ */
+EUnknownFQDNMode TSrvParsIfaceOpt::getUnknownFQDN() {
+    return UnknownFQDN;
 }
 
-void TSrvParsIfaceOpt::setLeaseQuerySupport(bool support)
-{
+std::string TSrvParsIfaceOpt::getFQDNDomain() {
+    return FQDNDomain;
+}
+
+void TSrvParsIfaceOpt::setLeaseQuerySupport(bool support) {
     this->LeaseQuery = support;
 }
 
-bool TSrvParsIfaceOpt::getLeaseQuerySupport()
-{
+bool TSrvParsIfaceOpt::getLeaseQuerySupport() {
     return LeaseQuery;
 }
 
 // --- unicast ---
-void TSrvParsIfaceOpt::setUnicast(SmartPtr<TIPv6Addr> addr) {
+void TSrvParsIfaceOpt::setUnicast(SPtr<TIPv6Addr> addr) {
     this->Unicast = addr;
 }
 
-SmartPtr<TIPv6Addr> TSrvParsIfaceOpt::getUnicast() {
+SPtr<TIPv6Addr> TSrvParsIfaceOpt::getUnicast() {
     return this->Unicast;
 }
 
@@ -93,8 +103,7 @@ void TSrvParsIfaceOpt::setClntMaxLease(long clntMaxLease) {
     this->ClntMaxLease = clntMaxLease;
 }
 
-long TSrvParsIfaceOpt::getClntMaxLease()
-{
+long TSrvParsIfaceOpt::getClntMaxLease() {
     return this->ClntMaxLease;
 }
 
@@ -154,6 +163,7 @@ void TSrvParsIfaceOpt::setDNSServerLst(List(TIPv6Addr) *lst) {
     this->DNSServerLst = *lst;
     this->DNSServerSupport = true;
 }
+
 List(TIPv6Addr) * TSrvParsIfaceOpt::getDNSServerLst() {
     return &this->DNSServerLst;
 }
@@ -166,6 +176,7 @@ void TSrvParsIfaceOpt::setDomainLst(List(string) * lst) {
     this->DomainLst = *lst;
     this->DomainSupport = true;
 }
+
 List(string) * TSrvParsIfaceOpt::getDomainLst() {
     return &this->DomainLst;
 }
@@ -173,8 +184,9 @@ bool TSrvParsIfaceOpt::supportDomain(){
     return this->DomainSupport;
 }
 
+#if 0
 // --- option: VENDOR-SPEC INFO ---
-void TSrvParsIfaceOpt::setVendorSpec(List(TSrvOptVendorSpec) vendor)
+void TSrvParsIfaceOpt::setVendorSpec(List(TOptVendorSpecInfo) vendor)
 {
     VendorSpec = vendor;
     VendorSpecSupport = true;
@@ -184,10 +196,11 @@ bool TSrvParsIfaceOpt::supportVendorSpec()
     return VendorSpecSupport;
 }
 
-List(TSrvOptVendorSpec) TSrvParsIfaceOpt::getVendorSpec()
+List(TOptVendorSpecInfo) TSrvParsIfaceOpt::getVendorSpec()
 {
     return VendorSpec;
 }
+#endif
 
 // --- option: NTP-SERVERS ---
 void TSrvParsIfaceOpt::setNTPServerLst(List(TIPv6Addr) * lst) {
@@ -214,7 +227,7 @@ bool TSrvParsIfaceOpt::supportTimezone(){
 }
 
 // --- option: SIP server ---
-void TSrvParsIfaceOpt::setSIPServerLst(TContainer<SmartPtr<TIPv6Addr> > *lst) {
+void TSrvParsIfaceOpt::setSIPServerLst(TContainer<SPtr<TIPv6Addr> > *lst) {
     this->SIPServerLst = *lst;
     this->SIPServerSupport = true;
 }
@@ -237,17 +250,6 @@ bool TSrvParsIfaceOpt::supportSIPDomain() {
     return this->SIPDomainSupport;
 }
 
-// --- option: extra ---
-List(TSrvOptGeneric) TSrvParsIfaceOpt::getExtraOptions()
-{
-    return ExtraOpts;
-}
-
-void TSrvParsIfaceOpt::setExtraOptions(List(TSrvOptGeneric) extraOpts)
-{
-    ExtraOpts = extraOpts;
-}
-
 
 // --- option: FQDN ---
 
@@ -256,10 +258,10 @@ void TSrvParsIfaceOpt::setFQDNLst(List(TFQDN) *fqdn) {
     this->FQDNSupport = true;
 }
 
-string TSrvParsIfaceOpt::getFQDNName(SmartPtr<TDUID> duid) {
+string TSrvParsIfaceOpt::getFQDNName(SPtr<TDUID> duid) {
     int cpt = 1;
     string res = "";
-    SmartPtr<TFQDN> foo = FQDNLst.getFirst();
+    SPtr<TFQDN> foo = FQDNLst.getFirst();
     FQDNLst.first();
     foo = FQDNLst.get();
     while(!(*(*foo).Duid == *duid) && cpt<FQDNLst.count()){
@@ -276,10 +278,10 @@ string TSrvParsIfaceOpt::getFQDNName(SmartPtr<TDUID> duid) {
     return res;
 }
 
-string TSrvParsIfaceOpt::getFQDNName(SmartPtr<TIPv6Addr> addr) {
+string TSrvParsIfaceOpt::getFQDNName(SPtr<TIPv6Addr> addr) {
     int cpt = 1;
     string res = "";
-    SmartPtr<TFQDN> foo = FQDNLst.getFirst();
+    SPtr<TFQDN> foo = FQDNLst.getFirst();
     FQDNLst.first();
     foo = FQDNLst.get();
     while(!(*(*foo).Addr == *addr) && cpt<FQDNLst.count()){
@@ -299,7 +301,7 @@ string TSrvParsIfaceOpt::getFQDNName(SmartPtr<TIPv6Addr> addr) {
 string TSrvParsIfaceOpt::getFQDNName() {
     int cpt = 1;
     string res = "";
-    SmartPtr<TFQDN> foo = FQDNLst.getFirst();
+    SPtr<TFQDN> foo = FQDNLst.getFirst();
     FQDNLst.first();
     foo = FQDNLst.get();
     Log(Debug)<<"FQDN used ? : "<<(*foo).used<<LogEnd;
@@ -327,8 +329,8 @@ string TSrvParsIfaceOpt::getFQDNName() {
     return res;
 }
 
-SmartPtr<TDUID> TSrvParsIfaceOpt::getFQDNDuid(string name) {
-    SmartPtr<TDUID> res = new TDUID();
+SPtr<TDUID> TSrvParsIfaceOpt::getFQDNDuid(string name) {
+    SPtr<TDUID> res = new TDUID();
     return res;
 }
 
@@ -349,13 +351,12 @@ void TSrvParsIfaceOpt::setRevDNSZoneRootLength(int revDNSZoneRootLength){
 	this->revDNSZoneRootLength = revDNSZoneRootLength;
 }
 
-
 bool TSrvParsIfaceOpt::supportFQDN() {
     return this->FQDNSupport;
 }
 
 // --- option: NIS server ---
-void TSrvParsIfaceOpt::setNISServerLst(TContainer<SmartPtr<TIPv6Addr> > *lst) {
+void TSrvParsIfaceOpt::setNISServerLst(TContainer<SPtr<TIPv6Addr> > *lst) {
     this->NISServerLst     = *lst;
     this->NISServerSupport = true;
 }
@@ -379,7 +380,7 @@ bool TSrvParsIfaceOpt::supportNISDomain() {
 }
 
 // --- option: NIS+ server ---
-void TSrvParsIfaceOpt::setNISPServerLst(TContainer<SmartPtr<TIPv6Addr> > *lst) {
+void TSrvParsIfaceOpt::setNISPServerLst(TContainer<SPtr<TIPv6Addr> > *lst) {
     this->NISPServerLst = *lst;
     this->NISPServerSupport = true;
 }
@@ -415,36 +416,3 @@ bool TSrvParsIfaceOpt::supportLifetime() {
     return this->LifetimeSupport;
 }
 
-void TSrvParsIfaceOpt::setTunnelMode(int vendor, int mode, SPtr<TIPv6Addr> addr)
-{
-    TunnelMode = mode;
-    char tmpbuf[32];
-    int len;
-    
-    tmpbuf[0] = 0x0;
-    tmpbuf[1] = OPTION_VENDORSPEC_TUNNEL_TYPE;
-    tmpbuf[2] = 0x0;
-    tmpbuf[3] = 0x1;  // 0x0001 - option-len
-    tmpbuf[4] = mode;
-
-    tmpbuf[5] = 0x0;
-    tmpbuf[6] = OPTION_VENDORSPEC_ENDPOINT;
-    tmpbuf[7] = 0x0;
-    tmpbuf[8] = 0x10; // 0x0010 - option-code
-    memmove(tmpbuf+9,addr->getAddr(), 16);
-    len = 9+16; // actual length
-
-    SPtr<TSrvOptVendorSpec> v = new TSrvOptVendorSpec(vendor, tmpbuf, len, 0);
-
-    TunnelVendorSpec = v;
-}
-
-int TSrvParsIfaceOpt::getTunnelMode()
-{
-    return TunnelMode;
-}
-
-SPtr<TSrvOptVendorSpec> TSrvParsIfaceOpt::getTunnelVendorSpec()
-{
-    return TunnelVendorSpec;
-}
