@@ -13,8 +13,7 @@
 #ifndef TSRCPARSIFACEOPT_H_
 #define TSRCPARSIFACEOPT_H_
 
-#include "SrvOptVendorSpec.h"
-#include "SrvOptGeneric.h"
+#include "OptVendorSpecInfo.h"
 #include "SrvOptInterfaceID.h"
 #include "SrvParsClassOpt.h"
 #include "FQDN.h"
@@ -38,8 +37,8 @@ public:
     void setRapidCommit(bool rapidComm);
     bool getRapidCommit();
 
-    void setUnicast(SmartPtr<TIPv6Addr> addr);
-    SmartPtr<TIPv6Addr> getUnicast();
+    void setUnicast(SPtr<TIPv6Addr> addr);
+    SPtr<TIPv6Addr> getUnicast();
 
     void setRelayName(string name);
     void setRelayID(int ifindex);
@@ -86,15 +85,16 @@ public:
 
     // option: FQDN
     List(TFQDN) *getFQDNLst();
-    string getFQDNName(SmartPtr<TDUID> duid);
-    string getFQDNName(SmartPtr<TIPv6Addr> addr);
+    string getFQDNName(SPtr<TDUID> duid);
+    string getFQDNName(SPtr<TIPv6Addr> addr);
     string getFQDNName();
     int getRevDNSZoneRootLength();
     void setRevDNSZoneRootLength(int revDNSZoneRootLength);
-    void acceptUnknownFQDN(bool accept);
-    bool acceptUnknownFQDN();
+    void setUnknownFQDN(EUnknownFQDNMode mode, const std::string domain);
+    EUnknownFQDNMode getUnknownFQDN();
+    std::string getFQDNDomain();
 
-    SmartPtr<TDUID> getFQDNDuid(string name);
+    SPtr<TDUID> getFQDNDuid(string name);
     void setFQDNLst(List(TFQDN) *fqdn);
     bool supportFQDN();
 
@@ -126,26 +126,20 @@ public:
     unsigned int getLifetime();
     bool supportLifetime();
 
+
+#if 0
     // option: VENDOR-SPEC INFO
-    void setVendorSpec(List(TSrvOptVendorSpec) vendor);
+    void setVendorSpec(List(TOptVendorSpecInfo) vendor);
     bool supportVendorSpec();
-    List(TSrvOptVendorSpec) getVendorSpec();
-
-    // option: extra
-    void setExtraOptions(List(TSrvOptGeneric) extraOpts);
-    List(TSrvOptGeneric) getExtraOptions();
-
-    // experimental tunnel-mode
-    void setTunnelMode(int vendor, int mode, SPtr<TIPv6Addr> addr);
-    int getTunnelMode();
-    SPtr<TSrvOptVendorSpec> getTunnelVendorSpec();
+    List(TOptVendorSpecInfo) getVendorSpec();
+#endif
 
 private:
     char Preference;
     bool RapidCommit;
     long IfaceMaxLease;
     long ClntMaxLease;
-    SmartPtr<TIPv6Addr> Unicast;
+    SPtr<TIPv6Addr> Unicast;
     bool LeaseQuery; // support for leasequery
 
     // relay
@@ -180,17 +174,15 @@ private:
     List(TIPv6Addr) NISPServerLst;
     string NISDomain;
     string NISPDomain;
-    int FQDNMode;
-    bool AcceptUnknownFQDN;
-    int revDNSZoneRootLength;
     unsigned int Lifetime;
 
-    // tunnel-mode
-    int TunnelMode;
-    SPtr<TSrvOptVendorSpec> TunnelVendorSpec;
+    List(TOptVendorSpecInfo) VendorSpec;
 
-    List(TSrvOptVendorSpec) VendorSpec;
-    List(TSrvOptGeneric) ExtraOpts;
+    // FQDN
+    int FQDNMode;
+    EUnknownFQDNMode UnknownFQDN; // accept, reject, append domain, generate procedurally
+    std::string FQDNDomain;
+    int revDNSZoneRootLength;
 };
 
 #endif
