@@ -24,6 +24,10 @@
 #include "SrvParsGlobalOpt.h"
 #include "SrvParsClassOpt.h"
 #include "SrvParsIfaceOpt.h"
+#include "OptAddr.h"
+#include "OptAddrLst.h"
+#include "OptString.h"
+#include "SrvCfgMgr.h"
 #include "SrvCfgTA.h"
 #include "SrvCfgPD.h"
 #include "SrvCfgAddrClass.h"
@@ -32,7 +36,8 @@
 #include "DUID.h"
 #include "Logger.h"
 #include "FQDN.h"
-#include "SrvOptVendorSpec.h"
+#include "OptVendorSpecInfo.h"
+#include "OptRtPrefix.h"
 #include "SrvOptAddrParams.h"
 #include "Portable.h"
 #include "SrvCfgClientClass.h"
@@ -40,6 +45,7 @@
 #include "NodeConstant.h"
 #include "NodeClientSpecific.h"
 #include "NodeOperator.h"
+#include "CfgMgr.h"
 #include <sstream>
 
 #define YY_USE_CLASS
@@ -49,50 +55,48 @@ List(TSrvCfgIface) SrvCfgIfaceLst;         /* list of SrvCfg interfaces */
 List(TSrvCfgAddrClass) SrvCfgAddrClassLst; /* list of SrvCfg address classes */      \
 List(TSrvCfgTA) SrvCfgTALst;               /* list of SrvCfg TA objects */           \
 List(TSrvCfgPD) SrvCfgPDLst;		   /* list of SrvCfg PD objects */           \
-List(TSrvCfgClientClass) SrvCfgClientClassLst;		   /* list of SrvCfgClientClass objects */      \
+List(TSrvCfgClientClass) SrvCfgClientClassLst; /* list of SrvCfgClientClass objs */  \
 List(TIPv6Addr) PresentAddrLst;            /* address list (used for DNS,NTP,etc.)*/ \
 List(string) PresentStringLst;             /* string list */                         \
-List(Node) NodeClientClassLst;             /* Node list */                         \
+List(Node) NodeClientClassLst;             /* Node list */                           \
 List(TFQDN) PresentFQDNLst;                                                          \
-SmartPtr<TDUID> duidNew;                                                             \
-SmartPtr<TIPv6Addr> addr;                                                            \
+SPtr<TIPv6Addr> addr;                                                                \
 List(TStationRange) PresentRangeLst;                                                 \
 List(TStationRange) PDLst;                                                           \
-int VendorEnterpriseNumber;                                                          \
-List(TSrvOptGeneric) ExtraOpts;                                                      \
-List(TSrvOptVendorSpec) VendorSpec;			                             \
 List(TSrvCfgOptions) ClientLst;                                                      \
 int PDPrefix;                                                                        \
-/*method check whether interface with id=ifaceNr has been already declared */        \
-bool CheckIsIface(int ifaceNr);                                                      \
-/*method check whether interface with id=ifaceName has been already declared*/       \
-bool CheckIsIface(string ifaceName);                                                 \
-void StartIfaceDeclaration();                                                        \
+bool IfaceDefined(int ifaceNr);                                                      \
+bool IfaceDefined(string ifaceName);                                                 \
+bool StartIfaceDeclaration(string iface);                                            \
+bool StartIfaceDeclaration(int ifindex);                                             \
 bool EndIfaceDeclaration();                                                          \
 void StartClassDeclaration();                                                        \
 bool EndClassDeclaration();                                                          \
-SmartPtr<TIPv6Addr> getRangeMin(char * addrPacked, int prefix);                      \
-SmartPtr<TIPv6Addr> getRangeMax(char * addrPacked, int prefix);                      \
+SPtr<TIPv6Addr> getRangeMin(char * addrPacked, int prefix);                          \
+SPtr<TIPv6Addr> getRangeMax(char * addrPacked, int prefix);                          \
 void StartTAClassDeclaration();                                                      \
 bool EndTAClassDeclaration();                                                        \
 void StartPDDeclaration();                                                           \
 bool EndPDDeclaration();                                                             \
+TSrvCfgMgr * CfgMgr;                                                                 \
+SPtr<TOpt> nextHop;                                                                  \
 virtual ~SrvParser();
 #define YY_SrvParser_CONSTRUCTOR_PARAM  yyFlexLexer * lex
 #define YY_SrvParser_CONSTRUCTOR_CODE                                                           \
     ParserOptStack.append(new TSrvParsGlobalOpt());                               \
-    ParserOptStack.getLast()->setUnicast(false);                                  \
-    this->lex = lex;
+    this->lex = lex;                                                              \
+    CfgMgr = 0;                                                                   \
+    nextHop = 0;
 
-#line 83 "SrvParser.y"
-typedef union    
+#line 87 "SrvParser.y"
+typedef union
 {
     unsigned int ival;
     char *strval;
     struct SDuid
     {
-        int length;
-        char* duid;
+	int length;
+	char* duid;
     } duidval;
     char addrval[16];
 } yy_SrvParser_stype;
@@ -275,81 +279,95 @@ typedef
 #define	LOGNAME_	264
 #define	LOGLEVEL_	265
 #define	LOGMODE_	266
-#define	WORKDIR_	267
-#define	OPTION_	268
-#define	DNS_SERVER_	269
-#define	DOMAIN_	270
-#define	NTP_SERVER_	271
-#define	TIME_ZONE_	272
-#define	SIP_SERVER_	273
-#define	SIP_DOMAIN_	274
-#define	NIS_SERVER_	275
-#define	NIS_DOMAIN_	276
-#define	NISP_SERVER_	277
-#define	NISP_DOMAIN_	278
-#define	FQDN_	279
-#define	ACCEPT_UNKNOWN_FQDN_	280
-#define	LIFETIME_	281
-#define	ACCEPT_ONLY_	282
-#define	REJECT_CLIENTS_	283
-#define	POOL_	284
-#define	SHARE_	285
-#define	T1_	286
-#define	T2_	287
-#define	PREF_TIME_	288
-#define	VALID_TIME_	289
-#define	UNICAST_	290
-#define	PREFERENCE_	291
-#define	RAPID_COMMIT_	292
-#define	IFACE_MAX_LEASE_	293
-#define	CLASS_MAX_LEASE_	294
-#define	CLNT_MAX_LEASE_	295
-#define	STATELESS_	296
-#define	CACHE_SIZE_	297
-#define	PDCLASS_	298
-#define	PD_LENGTH_	299
-#define	PD_POOL_	300
-#define	VENDOR_SPEC_	301
-#define	CLIENT_	302
-#define	DUID_KEYWORD_	303
-#define	REMOTE_ID_	304
-#define	ADDRESS_	305
-#define	GUESS_MODE_	306
-#define	INACTIVE_MODE_	307
-#define	EXPERIMENTAL_	308
-#define	ADDR_PARAMS_	309
-#define	TUNNEL_MODE_	310
-#define	EXTRA_	311
-#define	AUTH_METHOD_	312
-#define	AUTH_LIFETIME_	313
-#define	AUTH_KEY_LEN_	314
-#define	DIGEST_NONE_	315
-#define	DIGEST_PLAIN_	316
-#define	DIGEST_HMAC_MD5_	317
-#define	DIGEST_HMAC_SHA1_	318
-#define	DIGEST_HMAC_SHA224_	319
-#define	DIGEST_HMAC_SHA256_	320
-#define	DIGEST_HMAC_SHA384_	321
-#define	DIGEST_HMAC_SHA512_	322
-#define	ACCEPT_LEASEQUERY_	323
-#define	CLIENT_CLASS_	324
-#define	MATCH_IF_	325
-#define	EQ_	326
-#define	AND_	327
-#define	OR_	328
-#define	CLIENT_VENDOR_SPEC_ENTERPRISE_NUM_	329
-#define	CLIENT_VENDOR_SPEC_DATA_	330
-#define	CLIENT_VENDOR_CLASS_EN_	331
-#define	CLIENT_VENDOR_CLASS_DATA_	332
-#define	ALLOW_	333
-#define	DENY_	334
-#define	SUBSTRING_	335
-#define	CONTAIN_	336
-#define	STRING_	337
-#define	HEXNUMBER_	338
-#define	INTNUMBER_	339
-#define	IPV6ADDR_	340
-#define	DUID_	341
+#define	LOGCOLORS_	267
+#define	WORKDIR_	268
+#define	OPTION_	269
+#define	DNS_SERVER_	270
+#define	DOMAIN_	271
+#define	NTP_SERVER_	272
+#define	TIME_ZONE_	273
+#define	SIP_SERVER_	274
+#define	SIP_DOMAIN_	275
+#define	NIS_SERVER_	276
+#define	NIS_DOMAIN_	277
+#define	NISP_SERVER_	278
+#define	NISP_DOMAIN_	279
+#define	LIFETIME_	280
+#define	FQDN_	281
+#define	ACCEPT_UNKNOWN_FQDN_	282
+#define	FQDN_DDNS_ADDRESS_	283
+#define	DDNS_PROTOCOL_	284
+#define	DDNS_TIMEOUT_	285
+#define	ACCEPT_ONLY_	286
+#define	REJECT_CLIENTS_	287
+#define	POOL_	288
+#define	SHARE_	289
+#define	T1_	290
+#define	T2_	291
+#define	PREF_TIME_	292
+#define	VALID_TIME_	293
+#define	UNICAST_	294
+#define	PREFERENCE_	295
+#define	RAPID_COMMIT_	296
+#define	IFACE_MAX_LEASE_	297
+#define	CLASS_MAX_LEASE_	298
+#define	CLNT_MAX_LEASE_	299
+#define	STATELESS_	300
+#define	CACHE_SIZE_	301
+#define	PDCLASS_	302
+#define	PD_LENGTH_	303
+#define	PD_POOL_	304
+#define	SCRIPT_	305
+#define	VENDOR_SPEC_	306
+#define	CLIENT_	307
+#define	DUID_KEYWORD_	308
+#define	REMOTE_ID_	309
+#define	ADDRESS_	310
+#define	GUESS_MODE_	311
+#define	INACTIVE_MODE_	312
+#define	EXPERIMENTAL_	313
+#define	ADDR_PARAMS_	314
+#define	REMOTE_AUTOCONF_NEIGHBORS_	315
+#define	AFTR_	316
+#define	AUTH_METHOD_	317
+#define	AUTH_LIFETIME_	318
+#define	AUTH_KEY_LEN_	319
+#define	DIGEST_NONE_	320
+#define	DIGEST_PLAIN_	321
+#define	DIGEST_HMAC_MD5_	322
+#define	DIGEST_HMAC_SHA1_	323
+#define	DIGEST_HMAC_SHA224_	324
+#define	DIGEST_HMAC_SHA256_	325
+#define	DIGEST_HMAC_SHA384_	326
+#define	DIGEST_HMAC_SHA512_	327
+#define	ACCEPT_LEASEQUERY_	328
+#define	BULKLQ_ACCEPT_	329
+#define	BULKLQ_TCPPORT_	330
+#define	BULKLQ_MAX_CONNS_	331
+#define	BULKLQ_TIMEOUT_	332
+#define	CLIENT_CLASS_	333
+#define	MATCH_IF_	334
+#define	EQ_	335
+#define	AND_	336
+#define	OR_	337
+#define	CLIENT_VENDOR_SPEC_ENTERPRISE_NUM_	338
+#define	CLIENT_VENDOR_SPEC_DATA_	339
+#define	CLIENT_VENDOR_CLASS_EN_	340
+#define	CLIENT_VENDOR_CLASS_DATA_	341
+#define	ALLOW_	342
+#define	DENY_	343
+#define	SUBSTRING_	344
+#define	STRING_KEYWORD_	345
+#define	ADDRESS_LIST_	346
+#define	CONTAIN_	347
+#define	NEXT_HOP_	348
+#define	ROUTE_	349
+#define	INFINITE_	350
+#define	STRING_	351
+#define	HEXNUMBER_	352
+#define	INTNUMBER_	353
+#define	IPV6ADDR_	354
+#define	DUID_	355
 
 
 #line 169 "../bison++/bison.h"
@@ -407,6 +425,7 @@ static const int TACLASS_;
 static const int LOGNAME_;
 static const int LOGLEVEL_;
 static const int LOGMODE_;
+static const int LOGCOLORS_;
 static const int WORKDIR_;
 static const int OPTION_;
 static const int DNS_SERVER_;
@@ -419,9 +438,12 @@ static const int NIS_SERVER_;
 static const int NIS_DOMAIN_;
 static const int NISP_SERVER_;
 static const int NISP_DOMAIN_;
+static const int LIFETIME_;
 static const int FQDN_;
 static const int ACCEPT_UNKNOWN_FQDN_;
-static const int LIFETIME_;
+static const int FQDN_DDNS_ADDRESS_;
+static const int DDNS_PROTOCOL_;
+static const int DDNS_TIMEOUT_;
 static const int ACCEPT_ONLY_;
 static const int REJECT_CLIENTS_;
 static const int POOL_;
@@ -441,6 +463,7 @@ static const int CACHE_SIZE_;
 static const int PDCLASS_;
 static const int PD_LENGTH_;
 static const int PD_POOL_;
+static const int SCRIPT_;
 static const int VENDOR_SPEC_;
 static const int CLIENT_;
 static const int DUID_KEYWORD_;
@@ -450,8 +473,8 @@ static const int GUESS_MODE_;
 static const int INACTIVE_MODE_;
 static const int EXPERIMENTAL_;
 static const int ADDR_PARAMS_;
-static const int TUNNEL_MODE_;
-static const int EXTRA_;
+static const int REMOTE_AUTOCONF_NEIGHBORS_;
+static const int AFTR_;
 static const int AUTH_METHOD_;
 static const int AUTH_LIFETIME_;
 static const int AUTH_KEY_LEN_;
@@ -464,6 +487,10 @@ static const int DIGEST_HMAC_SHA256_;
 static const int DIGEST_HMAC_SHA384_;
 static const int DIGEST_HMAC_SHA512_;
 static const int ACCEPT_LEASEQUERY_;
+static const int BULKLQ_ACCEPT_;
+static const int BULKLQ_TCPPORT_;
+static const int BULKLQ_MAX_CONNS_;
+static const int BULKLQ_TIMEOUT_;
 static const int CLIENT_CLASS_;
 static const int MATCH_IF_;
 static const int EQ_;
@@ -476,7 +503,12 @@ static const int CLIENT_VENDOR_CLASS_DATA_;
 static const int ALLOW_;
 static const int DENY_;
 static const int SUBSTRING_;
+static const int STRING_KEYWORD_;
+static const int ADDRESS_LIST_;
 static const int CONTAIN_;
+static const int NEXT_HOP_;
+static const int ROUTE_;
+static const int INFINITE_;
 static const int STRING_;
 static const int HEXNUMBER_;
 static const int INTNUMBER_;
@@ -499,81 +531,95 @@ static const int DUID_;
 	,LOGNAME_=264
 	,LOGLEVEL_=265
 	,LOGMODE_=266
-	,WORKDIR_=267
-	,OPTION_=268
-	,DNS_SERVER_=269
-	,DOMAIN_=270
-	,NTP_SERVER_=271
-	,TIME_ZONE_=272
-	,SIP_SERVER_=273
-	,SIP_DOMAIN_=274
-	,NIS_SERVER_=275
-	,NIS_DOMAIN_=276
-	,NISP_SERVER_=277
-	,NISP_DOMAIN_=278
-	,FQDN_=279
-	,ACCEPT_UNKNOWN_FQDN_=280
-	,LIFETIME_=281
-	,ACCEPT_ONLY_=282
-	,REJECT_CLIENTS_=283
-	,POOL_=284
-	,SHARE_=285
-	,T1_=286
-	,T2_=287
-	,PREF_TIME_=288
-	,VALID_TIME_=289
-	,UNICAST_=290
-	,PREFERENCE_=291
-	,RAPID_COMMIT_=292
-	,IFACE_MAX_LEASE_=293
-	,CLASS_MAX_LEASE_=294
-	,CLNT_MAX_LEASE_=295
-	,STATELESS_=296
-	,CACHE_SIZE_=297
-	,PDCLASS_=298
-	,PD_LENGTH_=299
-	,PD_POOL_=300
-	,VENDOR_SPEC_=301
-	,CLIENT_=302
-	,DUID_KEYWORD_=303
-	,REMOTE_ID_=304
-	,ADDRESS_=305
-	,GUESS_MODE_=306
-	,INACTIVE_MODE_=307
-	,EXPERIMENTAL_=308
-	,ADDR_PARAMS_=309
-	,TUNNEL_MODE_=310
-	,EXTRA_=311
-	,AUTH_METHOD_=312
-	,AUTH_LIFETIME_=313
-	,AUTH_KEY_LEN_=314
-	,DIGEST_NONE_=315
-	,DIGEST_PLAIN_=316
-	,DIGEST_HMAC_MD5_=317
-	,DIGEST_HMAC_SHA1_=318
-	,DIGEST_HMAC_SHA224_=319
-	,DIGEST_HMAC_SHA256_=320
-	,DIGEST_HMAC_SHA384_=321
-	,DIGEST_HMAC_SHA512_=322
-	,ACCEPT_LEASEQUERY_=323
-	,CLIENT_CLASS_=324
-	,MATCH_IF_=325
-	,EQ_=326
-	,AND_=327
-	,OR_=328
-	,CLIENT_VENDOR_SPEC_ENTERPRISE_NUM_=329
-	,CLIENT_VENDOR_SPEC_DATA_=330
-	,CLIENT_VENDOR_CLASS_EN_=331
-	,CLIENT_VENDOR_CLASS_DATA_=332
-	,ALLOW_=333
-	,DENY_=334
-	,SUBSTRING_=335
-	,CONTAIN_=336
-	,STRING_=337
-	,HEXNUMBER_=338
-	,INTNUMBER_=339
-	,IPV6ADDR_=340
-	,DUID_=341
+	,LOGCOLORS_=267
+	,WORKDIR_=268
+	,OPTION_=269
+	,DNS_SERVER_=270
+	,DOMAIN_=271
+	,NTP_SERVER_=272
+	,TIME_ZONE_=273
+	,SIP_SERVER_=274
+	,SIP_DOMAIN_=275
+	,NIS_SERVER_=276
+	,NIS_DOMAIN_=277
+	,NISP_SERVER_=278
+	,NISP_DOMAIN_=279
+	,LIFETIME_=280
+	,FQDN_=281
+	,ACCEPT_UNKNOWN_FQDN_=282
+	,FQDN_DDNS_ADDRESS_=283
+	,DDNS_PROTOCOL_=284
+	,DDNS_TIMEOUT_=285
+	,ACCEPT_ONLY_=286
+	,REJECT_CLIENTS_=287
+	,POOL_=288
+	,SHARE_=289
+	,T1_=290
+	,T2_=291
+	,PREF_TIME_=292
+	,VALID_TIME_=293
+	,UNICAST_=294
+	,PREFERENCE_=295
+	,RAPID_COMMIT_=296
+	,IFACE_MAX_LEASE_=297
+	,CLASS_MAX_LEASE_=298
+	,CLNT_MAX_LEASE_=299
+	,STATELESS_=300
+	,CACHE_SIZE_=301
+	,PDCLASS_=302
+	,PD_LENGTH_=303
+	,PD_POOL_=304
+	,SCRIPT_=305
+	,VENDOR_SPEC_=306
+	,CLIENT_=307
+	,DUID_KEYWORD_=308
+	,REMOTE_ID_=309
+	,ADDRESS_=310
+	,GUESS_MODE_=311
+	,INACTIVE_MODE_=312
+	,EXPERIMENTAL_=313
+	,ADDR_PARAMS_=314
+	,REMOTE_AUTOCONF_NEIGHBORS_=315
+	,AFTR_=316
+	,AUTH_METHOD_=317
+	,AUTH_LIFETIME_=318
+	,AUTH_KEY_LEN_=319
+	,DIGEST_NONE_=320
+	,DIGEST_PLAIN_=321
+	,DIGEST_HMAC_MD5_=322
+	,DIGEST_HMAC_SHA1_=323
+	,DIGEST_HMAC_SHA224_=324
+	,DIGEST_HMAC_SHA256_=325
+	,DIGEST_HMAC_SHA384_=326
+	,DIGEST_HMAC_SHA512_=327
+	,ACCEPT_LEASEQUERY_=328
+	,BULKLQ_ACCEPT_=329
+	,BULKLQ_TCPPORT_=330
+	,BULKLQ_MAX_CONNS_=331
+	,BULKLQ_TIMEOUT_=332
+	,CLIENT_CLASS_=333
+	,MATCH_IF_=334
+	,EQ_=335
+	,AND_=336
+	,OR_=337
+	,CLIENT_VENDOR_SPEC_ENTERPRISE_NUM_=338
+	,CLIENT_VENDOR_SPEC_DATA_=339
+	,CLIENT_VENDOR_CLASS_EN_=340
+	,CLIENT_VENDOR_CLASS_DATA_=341
+	,ALLOW_=342
+	,DENY_=343
+	,SUBSTRING_=344
+	,STRING_KEYWORD_=345
+	,ADDRESS_LIST_=346
+	,CONTAIN_=347
+	,NEXT_HOP_=348
+	,ROUTE_=349
+	,INFINITE_=350
+	,STRING_=351
+	,HEXNUMBER_=352
+	,INTNUMBER_=353
+	,IPV6ADDR_=354
+	,DUID_=355
 
 
 #line 215 "../bison++/bison.h"
