@@ -25,16 +25,16 @@ TSrvIfaceIface::TSrvIfaceIface(const char * name, int id, unsigned int flags, ch
     this->RelaysCnt = 0;
 }
 
-void TSrvIfaceIface::setUnderlaying(SmartPtr<TSrvIfaceIface> under) {
+void TSrvIfaceIface::setUnderlaying(SPtr<TSrvIfaceIface> under) {
     this->UnderRelay = under;
     this->Relay = true;
 }
 
-SmartPtr<TSrvIfaceIface> TSrvIfaceIface::getUnderlaying() {
+SPtr<TSrvIfaceIface> TSrvIfaceIface::getUnderlaying() {
     return this->UnderRelay;
 }
 
-bool TSrvIfaceIface::appendRelay(SmartPtr<TSrvIfaceIface> relay, SPtr<TSrvOptInterfaceID> interfaceID) {
+bool TSrvIfaceIface::appendRelay(SPtr<TSrvIfaceIface> relay, SPtr<TSrvOptInterfaceID> interfaceID) {
     if (this->RelaysCnt>=HOP_COUNT_LIMIT) 
 	return false;
     this->Relays[this->RelaysCnt].iface       = relay;
@@ -44,7 +44,7 @@ bool TSrvIfaceIface::appendRelay(SmartPtr<TSrvIfaceIface> relay, SPtr<TSrvOptInt
     return true;
 }
 
-SmartPtr<TSrvIfaceIface> TSrvIfaceIface::getRelayByInterfaceID(SPtr<TSrvOptInterfaceID> interfaceID) {
+SPtr<TSrvIfaceIface> TSrvIfaceIface::getRelayByInterfaceID(SPtr<TSrvOptInterfaceID> interfaceID) {
     int i=0;
     if (this->RelaysCnt==0) {
 	Log(Warning) << "No relay interface defined on the " << this->getFullName() << LogEnd;
@@ -57,18 +57,18 @@ SmartPtr<TSrvIfaceIface> TSrvIfaceIface::getRelayByInterfaceID(SPtr<TSrvOptInter
     return 0;
 }
 
-SmartPtr<TSrvIfaceIface> TSrvIfaceIface::getRelayByLinkAddr(SmartPtr<TIPv6Addr> addr) {
+SPtr<TSrvIfaceIface> TSrvIfaceIface::getRelayByLinkAddr(SPtr<TIPv6Addr> addr) {
     if (this->RelaysCnt==0) {
 	Log(Warning) << "No relay interface defined on the " << this->getFullName() << LogEnd;
 	return 0;
     }
-    /// FIXME: Implement finding RELAYs using link address
+    //// @todo: Implement finding RELAYs using link address
     Log(Error) << "Finding RELAYs using link address is not implemented yet. Using first relay:" 
 	      << this->Relays[0].iface->getFullName() << LogEnd;
     return this->Relays[0].iface;
 }
 
-SmartPtr<TSrvIfaceIface> TSrvIfaceIface::getAnyRelay() {
+SPtr<TSrvIfaceIface> TSrvIfaceIface::getAnyRelay() {
     if (this->RelaysCnt==0) {
 	Log(Warning) << "No relay interface defined on the " << this->getFullName() << LogEnd;
 	return 0;
@@ -106,8 +106,12 @@ ostream & operator <<(ostream & strum, TSrvIfaceIface &x) {
     if (x.RelaysCnt) {
 	for (i=0; i< x.RelaysCnt; i++) {
 	    strum << "    <OverlayingRelay name=\"" << x.Relays[i].iface->getName() 
-		  << "\" ifindex=\"" << x.Relays[i].ifindex 
-		  << "\" interfaceID=\"" << x.Relays[i].interfaceID->getPlain() << "\" />" << endl;
+		  << "\" ifindex=\"" << x.Relays[i].ifindex;
+	    if (x.Relays[i].interfaceID)
+	      strum << "\" interfaceID=\"" << x.Relays[i].interfaceID->getPlain();
+	    else
+	      strum << "\" interfaceID=null\"";
+	    strum << "\" />" << endl;
 	}
     }
 
@@ -115,7 +119,15 @@ ostream & operator <<(ostream & strum, TSrvIfaceIface &x) {
 
     for (int i=0; i<x.LLAddrCnt; i++) {
 	inet_ntop6(x.LLAddr+i*16,buf);
-	strum << "    <Addr>" << buf << "</Addr>" << endl;
+	strum << "    <Addr scope=\"local\">" << buf << "</Addr>" << endl;
+    }
+
+    strum << "    <!-- " << x.countGlobalAddr() << " non-local (global) addrs -->" << endl;
+
+    x.firstGlobalAddr();
+    SPtr<TIPv6Addr> addr;
+    while (addr = x.getGlobalAddr()) {
+      	strum << "    <Addr scope=\"global\">" << *addr << "</Addr>" << endl;
     }
 
     strum << "    <Mac length=\"" << x.Maclen << "\">";
@@ -128,7 +140,7 @@ ostream & operator <<(ostream & strum, TSrvIfaceIface &x) {
     strum << "</Mac>" << endl;
 
     strum << "    <!-- " << x.countSocket() << " sockets -->" << endl;
-    SmartPtr<TIfaceSocket> sock;
+    SPtr<TIfaceSocket> sock;
     x.firstSocket();
     while (sock = x.getSocket() ) {
 	strum << "    " << *sock;
