@@ -12,6 +12,7 @@
  *
  */
 
+#include <sstream>
 #include <stdio.h> // required for DEV-CPP compilation
 #include "Portable.h"
 #include "SmartPtr.h"
@@ -33,10 +34,16 @@
 #include "AddrClient.h"
 #include "SrvIfaceIface.h"
 #include "SrvOptEcho.h"
-#include "SrvOptGeneric.h"
+#include "OptGeneric.h"
+#include "OptVendorData.h"
+#include "OptIAAddress.h"
+#include "OptIAPrefix.h"
 
 using namespace std;
 
+TSrvIfaceMgr * TSrvIfaceMgr::Instance = 0;
+
+
 /*
  * constructor. 
  */
@@ -65,7 +72,7 @@ TSrvIfaceMgr::TSrvIfaceMgr(string xmlFile)
                  // << ", flags=" << ptr->flags 
                     << ", MAC=" << this->printMac(ptr->mac, ptr->maclen) << "." << LogEnd;
 	
-        SmartPtr<TIfaceIface> iface(new TSrvIfaceIface(ptr->name,ptr->id,
+        SPtr<TIfaceIface> iface(new TSrvIfaceIface(ptr->name,ptr->id,
 						       ptr->flags,
 						       ptr->mac,
 						       ptr->maclen,
@@ -96,16 +103,17 @@ void TSrvIfaceMgr::dump()
 
 /**
  * sends data to client. Uses multicast address as source
- * @param iface - interface ID
+ * @param iface interface index
  * @param msg - buffer containing message ready to send
  * @param size - size of message
- * @param addr - destination address
- * returns true if message was send successfully
+ * @param addr  destination IPv6 address
+ * @param port  destination UDP port
+ * @return true if message was send successfully
  */
 bool TSrvIfaceMgr::send(int iface, char *msg, int size, 
-			SmartPtr<TIPv6Addr> addr, int port) {
+			SPtr<TIPv6Addr> addr, int port) {
     // find this interface
-    SmartPtr<TIfaceIface> ptrIface;
+    SPtr<TIfaceIface> ptrIface;
     ptrIface = this->getIfaceByID(iface);
     if (!ptrIface) {
 	    Log(Error)  << "Send failed: No such interface id=" << iface << LogEnd;
@@ -113,51 +121,37 @@ bool TSrvIfaceMgr::send(int iface, char *msg, int size,
     }
 
     // find this socket
-    SmartPtr<TIfaceSocket> ptrSocket;
+    SPtr<TIfaceSocket> sock;
     ptrIface->firstSocket();
-    ptrSocket = ptrIface->getSocket();
-    if (!ptrSocket) {
-	     Log(Error) << "Send failed: interface " << ptrIface->getName() 
-		 << "/" << iface << " has no open sockets." << LogEnd;
-         return false;
+    while (sock = ptrIface->getSocket()) {
+        if (sock->multicast())
+            continue; // don't send anything via multicast sockets
+        break;
+    }
+    if (!sock) {
+        Log(Error) << "Send failed: interface " << ptrIface->getName() 
+                   << "/" << iface << " has no open sockets." << LogEnd;
+        return false;
     }
 
     // send it!
-    return (bool)(ptrSocket->send(msg,size,addr,port));
+    return (sock->send(msg,size,addr,port));
 }
 
 /**
  * reads messages from all interfaces
  * it's wrapper around IfaceMgr::select(...) method
  * @param timeout - how long can we wait for packets?
- * returns SmartPtr to message object
+ * returns SPtr to message object
  */
-SmartPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
+SPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
     
     // static buffer speeds things up
     const int maxBufsize = 4096;
     int bufsize=maxBufsize;
     static char buf[maxBufsize];
 
-#if 0
-    buf[0]=buf[1]=buf[2]=buf[3]=2;
-    buf[4]=buf[5]=buf[6]=buf[7]=2;
-
-    SPtr<TSrvOptInterfaceID> opt1 = new TSrvOptInterfaceID(3, 0);
-    SPtr<TSrvOptInterfaceID> opt2 = new TSrvOptInterfaceID(5, 0);
-
-    Log(Info) << "#### opt1->" << opt1->getPlain() << LogEnd;
-    Log(Info) << "#### opt2->" << opt2->getPlain() << LogEnd;
-
-    if (*opt1 == *opt2)
-	Log(Info) << "#### equal " << LogEnd;
-    else
-	Log(Info) << "#### NOT equal" << LogEnd;
-
-    exit(-1);
-#endif
-
-    SmartPtr<TIPv6Addr> peer (new TIPv6Addr());
+    SPtr<TIPv6Addr> peer (new TIPv6Addr());
     int sockid;
     int msgtype;
 
@@ -171,8 +165,8 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
 	
 	// check message type
 	msgtype = buf[0];
-	//SmartPtr<TMsg> ptr;
-	SmartPtr<TSrvIfaceIface> ptrIface;
+	//SPtr<TMsg> ptr;
+	SPtr<TSrvIfaceIface> ptrIface;
 
 	// get interface
 	ptrIface = (Ptr*)this->getIfaceBySocket(sockid);
@@ -182,7 +176,7 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
 		   << ")." << LogEnd;
 
 	// create specific message object
-    SmartPtr<TSrvMsg> ptr;
+	SPtr<TSrvMsg> ptr;
 	switch (msgtype) {
 	case SOLICIT_MSG:
 	case REQUEST_MSG:
@@ -193,22 +187,26 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
 	case DECLINE_MSG:
 	case INFORMATION_REQUEST_MSG:
 	case LEASEQUERY_MSG:
+	{
 	    ptr = this->decodeMsg(ptrIface, peer, buf, bufsize);
-        if (!ptr->validateReplayDetection() ||
-            !ptr->validateAuthInfo(buf, bufsize)) {
-            Log(Error) << "Auth: Authorization failed, message dropped." << LogEnd;
-            return 0;
-        }
-        return ptr;
+	    if (!ptr->validateReplayDetection() ||
+		!ptr->validateAuthInfo(buf, bufsize)) {
+		Log(Error) << "Auth: Authorization failed, message dropped." << LogEnd;
+		return 0;
+	    }
+	    return ptr;
+	}
 	case RELAY_FORW_MSG:
+	{
 	    ptr = this->decodeRelayForw(ptrIface, peer, buf, bufsize);
-        if (!ptr)
-            return 0;
-        if (!ptr->validateReplayDetection() ||
-            !ptr->validateAuthInfo(buf, bufsize)) {
-            Log(Error) << "Auth: validation failed, message dropped." << LogEnd;
-            return 0;
-        }
+	    if (!ptr)
+		return 0;
+	    if (!ptr->validateReplayDetection() ||
+		!ptr->validateAuthInfo(buf, bufsize)) {
+		Log(Error) << "Auth: validation failed, message dropped." << LogEnd;
+		return 0;
+	    }
+	}
         return ptr;
 	case ADVERTISE_MSG:
 	case REPLY_MSG:
@@ -227,7 +225,7 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::select(unsigned long timeout) {
 }
 
 bool TSrvIfaceMgr::setupRelay(string name, int ifindex, int underIfindex, SPtr<TSrvOptInterfaceID> interfaceID) {
-    SmartPtr<TSrvIfaceIface> under = (Ptr*)this->getIfaceByID(underIfindex);
+    SPtr<TSrvIfaceIface> under = (Ptr*)this->getIfaceByID(underIfindex);
     if (!under) {
 	Log(Crit) << "Unable to setup " << name << "/" << ifindex 
 		  << " relay: underlaying interface with id=" << underIfindex 
@@ -242,7 +240,7 @@ bool TSrvIfaceMgr::setupRelay(string name, int ifindex, int underIfindex, SPtr<T
 	return false;
     }
 
-    SmartPtr<TSrvIfaceIface> relay = new TSrvIfaceIface((const char*)name.c_str(), ifindex, 
+    SPtr<TSrvIfaceIface> relay = new TSrvIfaceIface((const char*)name.c_str(), ifindex, 
 							IF_UP | IF_RUNNING | IF_MULTICAST,   // flags
 							0,   // MAC
 							0,   // MAC length
@@ -265,20 +263,20 @@ bool TSrvIfaceMgr::setupRelay(string name, int ifindex, int underIfindex, SPtr<T
     return true;
 }
 
-SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIface, 
-						SmartPtr<TIPv6Addr> peer, 
+SPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SPtr<TSrvIfaceIface> ptrIface, 
+						SPtr<TIPv6Addr> peer, 
 						char * buf, int bufsize) {
 
-    SmartPtr<TIPv6Addr> linkAddrTbl[HOP_COUNT_LIMIT];
-    SmartPtr<TIPv6Addr> peerAddrTbl[HOP_COUNT_LIMIT];
-    SmartPtr<TSrvOptInterfaceID> interfaceIDTbl[HOP_COUNT_LIMIT];
+    SPtr<TIPv6Addr> linkAddrTbl[HOP_COUNT_LIMIT];
+    SPtr<TIPv6Addr> peerAddrTbl[HOP_COUNT_LIMIT];
+    SPtr<TSrvOptInterfaceID> interfaceIDTbl[HOP_COUNT_LIMIT];
     int hopTbl[HOP_COUNT_LIMIT];
-    List(TSrvOptGeneric) echoListTbl[HOP_COUNT_LIMIT];
-    SmartPtr<TSrvIfaceIface> relayIface;
+    List(TOptGeneric) echoListTbl[HOP_COUNT_LIMIT];
+    SPtr<TSrvIfaceIface> relayIface;
     int relays=0; // number of nested RELAY_FORW messages
-    SPtr<TSrvOptRemoteID> remoteID = 0;
+    SPtr<TOptVendorData> remoteID = 0;
     SPtr<TSrvOptEcho> echo = 0;
-    SPtr<TSrvOptGeneric> gen = 0;
+    SPtr<TOptGeneric> gen = 0;
 
     char * relay_buf = buf;
     int relay_bufsize = bufsize;
@@ -293,7 +291,7 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 	    return 0;
 	}
 
-	SmartPtr<TSrvOptInterfaceID> ptrIfaceID;
+	SPtr<TSrvOptInterfaceID> ptrIfaceID;
 	ptrIfaceID = 0;
 
 	char type = buf[0];
@@ -303,18 +301,18 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 	int optRelayCnt = 0;
 	int optIfaceIDCnt = 0;
 
-	SmartPtr<TIPv6Addr> linkAddr = new TIPv6Addr(buf+2,false);
-	SmartPtr<TIPv6Addr> peerAddr = new TIPv6Addr(buf+18, false);
+	SPtr<TIPv6Addr> linkAddr = new TIPv6Addr(buf+2,false);
+	SPtr<TIPv6Addr> peerAddr = new TIPv6Addr(buf+18, false);
 	buf+=34;
 	bufsize-=34;
 
 	// options: only INTERFACE-ID and RELAY_MSG are allowed
 	while (bufsize>=4) {
-	    unsigned short code = ntohs( *((unsigned short*)(buf)));
-	    unsigned short len  = ntohs( *((unsigned short*)(buf+2)));
-	    buf     += 4;
-	    bufsize -= 4;
-	    
+	    unsigned short code = readUint16(buf);
+	    buf += sizeof(uint16_t); bufsize -= sizeof(uint16_t);
+	    unsigned short len  = readUint16(buf);
+	    buf += sizeof(uint16_t); bufsize -= sizeof(uint16_t);
+
 	    if (len > bufsize) {
 		Log(Warning) << "Truncated option " << code << ": " << bufsize << " bytes remaining, but length is " << len 
 			     << "." << LogEnd;
@@ -337,14 +335,14 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 		optRelayCnt++;
 		break;
 	    case OPTION_REMOTE_ID:
-		remoteID = new TSrvOptRemoteID(buf, len, 0);
+		remoteID = new TOptVendorData(OPTION_REMOTE_ID, buf, len, 0);
 		break;
 	    case OPTION_ERO:
 		Log(Debug) << "Echo Request received in RELAY_FORW." << LogEnd;
 		echo = new TSrvOptEcho(buf, len, 0);
 		break;
 	    default:
-		gen = new TSrvOptGeneric(code, buf, len, 0);
+		gen = new TOptGeneric(code, buf, len, 0);
 		echoListTbl[relays].append(gen);
 
 	    }
@@ -394,7 +392,7 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 
 	Log(Info) << "RELAY_FORW was decapsulated: link=" << linkAddr->getPlain() << ", peer=" << peerAddr->getPlain();
 
-	bool guessMode = SrvCfgMgr->guessMode();
+	bool guessMode = SrvCfgMgr().guessMode();
 
 	if (ptrIfaceID) {
 	    // find relay interface based on the interface-id option
@@ -437,12 +435,13 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
 	bufsize = relay_bufsize;
     }
     
-    SmartPtr<TSrvMsg> msg = this->decodeMsg(ptrIface, peer, relay_buf, relay_bufsize);
+    SPtr<TSrvMsg> msg = this->decodeMsg(ptrIface, peer, relay_buf, relay_bufsize);
     for (int i=0; i<relays; i++) {
 	msg->addRelayInfo(linkAddrTbl[i], peerAddrTbl[i], hopTbl[i], interfaceIDTbl[i], echoListTbl[i]);
     }
     if (remoteID) {
-	Log(Debug) << "RemoteID received: vendor=" << remoteID->getVendor() << ", length=" << remoteID->getVendorDataLen() << "." << LogEnd;
+	Log(Debug) << "RemoteID received: vendor=" << remoteID->getVendor() 
+                   << ", length=" << remoteID->getVendorDataLen() << "." << LogEnd;
 	msg->setRemoteID(remoteID);
 	remoteID = 0;
 	remoteID = msg->getRemoteID();
@@ -452,67 +451,37 @@ SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeRelayForw(SmartPtr<TSrvIfaceIface> ptrIfac
     return (Ptr*)msg;
  }
 
-SmartPtr<TSrvMsg> TSrvIfaceMgr::decodeMsg(SmartPtr<TSrvIfaceIface> ptrIface, 
-					     SmartPtr<TIPv6Addr> peer, 
+SPtr<TSrvMsg> TSrvIfaceMgr::decodeMsg(SPtr<TSrvIfaceIface> ptrIface, 
+					     SPtr<TIPv6Addr> peer, 
 					     char * buf, int bufsize) {
     int ifaceid = ptrIface->getID();
     if (bufsize<4) 
 	return 0;
     switch (buf[0]) {
     case SOLICIT_MSG:
-	return new TSrvMsgSolicit(That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				  ifaceid, peer, buf, bufsize);
+	      return new TSrvMsgSolicit(ifaceid, peer, buf, bufsize);
     case REQUEST_MSG:
-	return new TSrvMsgRequest(That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				      ifaceid, peer, buf, bufsize);
+	      return new TSrvMsgRequest(ifaceid, peer, buf, bufsize);
     case CONFIRM_MSG:
-	return new TSrvMsgConfirm(That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				  ifaceid,  peer, buf, bufsize);
+	      return new TSrvMsgConfirm(ifaceid,  peer, buf, bufsize);
     case RENEW_MSG:
-	return new TSrvMsgRenew  (That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				  ifaceid,  peer, buf, bufsize);
+	      return new TSrvMsgRenew  (ifaceid,  peer, buf, bufsize);
     case REBIND_MSG:
-	return new TSrvMsgRebind (That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				  ifaceid, peer, buf, bufsize);
+	      return new TSrvMsgRebind (ifaceid, peer, buf, bufsize);
     case RELEASE_MSG:
-	return new TSrvMsgRelease(That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				  ifaceid, peer, buf, bufsize);
+	      return new TSrvMsgRelease(ifaceid, peer, buf, bufsize);
     case DECLINE_MSG:
-	return new TSrvMsgDecline(That, this->SrvTransMgr, 
-				  this->SrvCfgMgr, this->SrvAddrMgr,
-				  ifaceid, peer, buf, bufsize);
+	      return new TSrvMsgDecline(ifaceid, peer, buf, bufsize);
     case INFORMATION_REQUEST_MSG:
-	return new TSrvMsgInfRequest(That, this->SrvTransMgr, 
-				     this->SrvCfgMgr, this->SrvAddrMgr,
-				     ifaceid, peer, buf, bufsize);
+	      return new TSrvMsgInfRequest(ifaceid, peer, buf, bufsize);
     case LEASEQUERY_MSG:
-	return new TSrvMsgLeaseQuery(That, SrvCfgMgr, SrvAddrMgr, ifaceid, 
-				     peer, buf, bufsize);
+	      return new TSrvMsgLeaseQuery(ifaceid, peer, buf, bufsize);
     default:
-	Log(Warning) << "Illegal message type " << (int)(buf[0]) << " received." << LogEnd;
-	return 0; //NULL;;
+        Log(Warning) << "Illegal message type " << (int)(buf[0]) << " received." << LogEnd;
+        return 0; //NULL;;
     }
 }
 
-/*
- * remember SmartPtrs to all managers (including this one)
- */
-void TSrvIfaceMgr::setContext(SmartPtr<TSrvIfaceMgr> srvIfaceMgr,
-			      SmartPtr<TSrvTransMgr> srvTransMgr,
-			      SmartPtr<TSrvCfgMgr> srvCfgMgr,
-			      SmartPtr<TSrvAddrMgr> srvAddrMgr) {
-    SrvCfgMgr=srvCfgMgr;
-    SrvAddrMgr=srvAddrMgr;
-    SrvTransMgr=srvTransMgr;
-    That=srvIfaceMgr;
-}
-
 /**
  * Compares current flags of interfaces with old flags. If change is detected,
  * stored flags of the interface are updated
@@ -541,9 +510,25 @@ void TSrvIfaceMgr::redetectIfaces() {
     if_list_release(ifaceList); // allocated in pure C, and so release it there
 }
 
+void TSrvIfaceMgr::instanceCreate( const std::string xmlDumpFile )
+{
+    if (Instance) {
+      Log(Crit) << "SrvIfaceMgr instance already created! Application error." << LogEnd;
+      return; // don't create second instance
+    }
+    Instance = new TSrvIfaceMgr(xmlDumpFile);
+}
+
+TSrvIfaceMgr & TSrvIfaceMgr::instance()
+{
+  if (!Instance)
+      Log(Crit) << "SrvIfaceMgr not create yet. Application error. Crashing in 3... 2... 1..." << LogEnd;
+  return *Instance;
+}
+
 ostream & operator <<(ostream & strum, TSrvIfaceMgr &x) {
     strum << "<SrvIfaceMgr>" << std::endl;
-    SmartPtr<TSrvIfaceIface> ptr;
+    SPtr<TSrvIfaceIface> ptr;
     x.IfaceLst.first();
     while ( ptr= (Ptr*) x.IfaceLst.get() ) {
 	strum << *ptr;
