@@ -8,10 +8,7 @@
  *
  * $Id: SrvMsgAdvertise.h,v 1.5 2008-08-29 00:07:34 thomson Exp $
  *
- * $Log: SrvMsgAdvertise.h,v $
- * Revision 1.5  2008-08-29 00:07:34  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.4  2005-01-08 16:52:04  thomson
  * Relay support implemented.
  *
@@ -33,27 +30,13 @@ class TSrvMsgAdvertise : public TSrvMsg
 {
   public:
     // creates object based on a buffer
-    TSrvMsgAdvertise(SmartPtr<TSrvIfaceMgr> IfaceMgr,
-		     SmartPtr<TSrvTransMgr> TransMgr,
-		     SmartPtr<TSrvCfgMgr> CfgMgr,
-		     SmartPtr<TSrvAddrMgr> AddrMgr,
-		     int iface, SmartPtr<TIPv6Addr> addr);
-    
-    TSrvMsgAdvertise(SmartPtr<TSrvIfaceMgr> IfaceMgr,
-		     SmartPtr<TSrvTransMgr> TransMgr,
-		     SmartPtr<TSrvCfgMgr> CfgMgr,
-		     SmartPtr<TSrvAddrMgr> AddrMgr,
-		     SmartPtr<TSrvMsgSolicit> question);
-    
-	TSrvMsgAdvertise(SmartPtr<TSrvIfaceMgr> IfaceMgr,
-		SmartPtr<TSrvTransMgr> TransMgr,
-		SmartPtr<TSrvCfgMgr> CfgMgr,
-		SmartPtr<TSrvAddrMgr> AddrMgr,
-		unsigned int iface, SmartPtr<TIPv6Addr> addr,
-		unsigned char* buf, unsigned int bufSize);
+    TSrvMsgAdvertise(int iface, SPtr<TIPv6Addr> addr);
+    TSrvMsgAdvertise(SPtr<TSrvMsgSolicit> question);
+    TSrvMsgAdvertise(unsigned int iface, SPtr<TIPv6Addr> addr,unsigned char* buf, unsigned int bufSize);
+    /// @todo: get rid of 2 of those constructors
 
     bool check();
-    bool answer(SmartPtr<TSrvMsgSolicit> solicit);
+    bool handleSolicitOptions(SPtr<TSrvMsgSolicit> solicit);
     void doDuties();
     unsigned long getTimeout();
     string getName();
