@@ -25,15 +25,10 @@
 class TSrvMsgConfirm : public TSrvMsg
 {
  public:
-    TSrvMsgConfirm(SmartPtr<TSrvIfaceMgr> IfaceMgr, 
-		   SmartPtr<TSrvTransMgr> TransMgr, 
-		   SmartPtr<TSrvCfgMgr> CfgMgr, 
-		   SmartPtr<TSrvAddrMgr> AddrMgr,
-		   int iface, SmartPtr<TIPv6Addr> addr,
-		   char* buf, int bufSize);
-    bool check();
+    TSrvMsgConfirm(int iface, SPtr<TIPv6Addr> addr, char* buf, int bufSize);
     void doDuties();
-    unsigned long getTimeout();
+    bool check();
+    unsigned long getTimeout(); /// @todo this is obsolete
     ~TSrvMsgConfirm();
     string getName();
 
