@@ -6,8 +6,6 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: SrvMsgInfRequest.h,v 1.5 2008-08-29 00:07:35 thomson Exp $
- *
  */
 
 #ifndef SRVINFREQUEST_H
@@ -15,27 +13,19 @@
 
 #include "SmartPtr.h"
 #include "SrvMsg.h"
-#include "SrvAddrMgr.h"
-#include "SrvCfgMgr.h"
-#include "SrvIfaceMgr.h"
 #include "IPv6Addr.h"
 
 class TSrvMsgInfRequest : public TSrvMsg
 {
   public:
-    TSrvMsgInfRequest(SmartPtr<TSrvIfaceMgr> IfMgr, 
-		      SmartPtr<TSrvTransMgr> TransMgr,
-		      SmartPtr<TSrvCfgMgr>   ConfMgr, 
-		      SmartPtr<TSrvAddrMgr>  AddrMgr, 
-		      int iface, SmartPtr<TIPv6Addr> addr, 
-		      char* buf, int bufSize);
+    TSrvMsgInfRequest(int iface, SPtr<TIPv6Addr> addr, char* buf, int bufSize);
     void doDuties();
     bool check();
     unsigned long getTimeout();
     string getName();
     ~TSrvMsgInfRequest();
   private:
-    SmartPtr<TSrvAddrMgr> AddrMgr;
+    SPtr<TSrvAddrMgr> AddrMgr;
     List(TMsg) BackupSrvLst;
 };
 
