@@ -17,23 +17,19 @@
 #include "SrvOptServerIdentifier.h"
 #include "SrvOptIA_NA.h"
 #include "AddrClient.h"
+#include "Logger.h"
 
-TSrvMsgLeaseQuery::TSrvMsgLeaseQuery(SmartPtr<TSrvIfaceMgr> IfaceMgr, 
-                               //SmartPtr<TSrvTransMgr> TransMgr,
-                               SmartPtr<TSrvCfgMgr>   ConfMgr, 
-                               SmartPtr<TSrvAddrMgr>  AddrMgr, 
-                               int iface,  SmartPtr<TIPv6Addr> addr,
-                               char* buf,
-                               int bufSize)
-    :TSrvMsg(IfaceMgr,0,ConfMgr,AddrMgr,iface,addr,buf,bufSize) {
+TSrvMsgLeaseQuery::TSrvMsgLeaseQuery(int iface,  SPtr<TIPv6Addr> addr, char* buf, int bufSize)
+    :TSrvMsg(iface,addr,buf,bufSize) {
 }
 
+
 void TSrvMsgLeaseQuery::doDuties() {
     return;
 }
 
 bool TSrvMsgLeaseQuery::check() {
-    // TODO: validation
+    /// @todo: validation
     if (!getOption(OPTION_CLIENTID)) {
 	Log(Warning) << "LQ: Lease Query message does not contain required CLIENT-ID option." << LogEnd;
 	return false;
