@@ -19,15 +19,11 @@
 #include "SrvOptIAPrefix.h"
 #include "SrvOptClientIdentifier.h"
 #include "AddrClient.h"
+#include "SrvCfgMgr.h"
 
 
-TSrvMsgLeaseQueryReply::TSrvMsgLeaseQueryReply(SmartPtr<TSrvIfaceMgr> IfaceMgr,
-				   SmartPtr<TSrvTransMgr> TransMgr,
-				   SmartPtr<TSrvCfgMgr> CfgMgr,
-				   SmartPtr<TSrvAddrMgr> AddrMgr,
-				   SmartPtr<TSrvMsgLeaseQuery> query)
-    :TSrvMsg(IfaceMgr,TransMgr,CfgMgr,AddrMgr,
-	     query->getIface(), query->getAddr(), LEASEQUERY_REPLY_MSG,
+TSrvMsgLeaseQueryReply::TSrvMsgLeaseQueryReply(SPtr<TSrvMsgLeaseQuery> query)
+    :TSrvMsg(query->getIface(), query->getAddr(), LEASEQUERY_REPLY_MSG,
 	     query->getTransID())
 {
   if (!answer(query)) {
@@ -70,7 +66,7 @@ bool TSrvMsgLeaseQueryReply::answer(SPtr<TSrvMsgLeaseQuery> queryMsg) {
 		ok = queryByClientID(q, queryMsg);
 		break;
 	    default:
-		Options.append( new TSrvOptStatusCode(STATUSCODE_UNKNOWNQUERYTYPE, "Invalid Query type.", this) );
+		Options.push_back( new TSrvOptStatusCode(STATUSCODE_UNKNOWNQUERYTYPE, "Invalid Query type.", this) );
 		Log(Warning) << "LQ: Invalid query type (" << q->getQueryType() << " received." << LogEnd;
 		return true;
 	    }
@@ -82,20 +78,20 @@ bool TSrvMsgLeaseQueryReply::answer(SPtr<TSrvMsgLeaseQuery> queryMsg) {
 	}
 	case OPTION_CLIENTID:
 	    // copy the client-id option
-	    Options.append(opt);
+	    Options.push_back(opt);
 	    break;
 	}
 
     }
     if (!count) {
-	Options.append(new TSrvOptStatusCode(STATUSCODE_MALFORMEDQUERY, "Required LQ_QUERY option missing.", this));
+	Options.push_back(new TSrvOptStatusCode(STATUSCODE_MALFORMEDQUERY, "Required LQ_QUERY option missing.", this));
 	return true;
     }
 
     // append SERVERID
-    SmartPtr<TSrvOptServerIdentifier> ptrSrvID;
-    ptrSrvID = new TSrvOptServerIdentifier(SrvCfgMgr->getDUID(),this);
-    Options.append((Ptr*)ptrSrvID);
+    SPtr<TSrvOptServerIdentifier> ptrSrvID;
+    ptrSrvID = new TSrvOptServerIdentifier(SrvCfgMgr().getDUID(), this);
+    Options.push_back((Ptr*)ptrSrvID);
 
     // allocate buffer
     pkt = new char[getSize()];
@@ -115,16 +111,16 @@ bool TSrvMsgLeaseQueryReply::queryByAddress(SPtr<TSrvOptLQ> q, SPtr<TSrvMsgLease
 	    addr = (Ptr*) opt;
     }
     if (!addr) {
-	Options.append(new TSrvOptStatusCode(STATUSCODE_MALFORMEDQUERY, "Required IAADDR suboption missing.", this));
+	Options.push_back(new TSrvOptStatusCode(STATUSCODE_MALFORMEDQUERY, "Required IAADDR suboption missing.", this));
 	return true;
     }
 
     // search for client
-    SPtr<TAddrClient> cli = SrvAddrMgr->getClient( addr->getAddr() );
+    SPtr<TAddrClient> cli = SrvAddrMgr().getClient( addr->getAddr() );
     
     if (!cli) {
 	Log(Warning) << "LQ: Assignement for client addr=" << addr->getAddr()->getPlain() << " not found." << LogEnd;
-	Options.append( new TSrvOptStatusCode(STATUSCODE_NOTCONFIGURED, "No binding for this address found.", this) );
+	Options.push_back( new TSrvOptStatusCode(STATUSCODE_NOTCONFIGURED, "No binding for this address found.", this) );
 	return true;
     }
     
@@ -146,16 +142,16 @@ bool TSrvMsgLeaseQueryReply::queryByClientID(SPtr<TSrvOptLQ> q, SPtr<TSrvMsgLeas
 	}
     }
     if (!duid) {
-	Options.append( new TSrvOptStatusCode(STATUSCODE_UNSPECFAIL, "You didn't send your ClientID.", this) );
+	Options.push_back( new TSrvOptStatusCode(STATUSCODE_UNSPECFAIL, "You didn't send your ClientID.", this) );
 	return true;
     }
 
     // search for client
-    SPtr<TAddrClient> cli = SrvAddrMgr->getClient( duid );
+    SPtr<TAddrClient> cli = SrvAddrMgr().getClient( duid );
     
     if (!cli) {
 	Log(Warning) << "LQ: Assignement for client duid=" << duid->getPlain() << " not found." << LogEnd;
-	Options.append( new TSrvOptStatusCode(STATUSCODE_NOTCONFIGURED, "No binding for this DUID found.", this) );
+	Options.push_back( new TSrvOptStatusCode(STATUSCODE_NOTCONFIGURED, "No binding for this DUID found.", this) );
 	return true;
     }
     
@@ -209,7 +205,7 @@ void TSrvMsgLeaseQueryReply::appendClientData(SPtr<TAddrClient> cli) {
 
     cliData->addOption( new TSrvOptLQClientTime(diff, this));
 
-    Options.append((Ptr*)cliData);
+    Options.push_back((Ptr*)cliData);
 }
 
 bool TSrvMsgLeaseQueryReply::check() {
