@@ -14,16 +14,8 @@
 #include "SrvOptServerIdentifier.h"
 #include "AddrClient.h"
 
-TSrvMsgRelease::TSrvMsgRelease(
-	SmartPtr<TSrvIfaceMgr> IfMgr, 
-	SmartPtr<TSrvTransMgr> TransMgr,
-	SmartPtr<TSrvCfgMgr>   ConfMgr, 
-	SmartPtr<TSrvAddrMgr>  AddrMgr, 
-	int iface, 
-	SmartPtr<TIPv6Addr> addr,
-	char* buf,
-	int bufSize)
-    :TSrvMsg(IfMgr, TransMgr, ConfMgr, AddrMgr, iface, addr,buf,bufSize)
+TSrvMsgRelease::TSrvMsgRelease(int iface, SPtr<TIPv6Addr> addr, char* buf, int bufSize)
+    :TSrvMsg(iface, addr, buf, bufSize)
 {
 }
 
