@@ -16,13 +16,8 @@
 #include "SrvCfgMgr.h"
 #include "DHCPConst.h"
 
-TSrvMsgRenew::TSrvMsgRenew(SmartPtr<TSrvIfaceMgr> IfaceMgr,
-			   SmartPtr<TSrvTransMgr> TransMgr,
-			   SmartPtr<TSrvCfgMgr> CfgMgr,
-			   SmartPtr<TSrvAddrMgr> AddrMgr,
-			   int iface,  SmartPtr<TIPv6Addr> addr,
-			   char* buf, int bufSize)
-    :TSrvMsg(IfaceMgr,TransMgr,CfgMgr,AddrMgr,iface,addr,buf,bufSize) {
+TSrvMsgRenew::TSrvMsgRenew(int iface,  SPtr<TIPv6Addr> addr, char* buf, int bufSize)
+    :TSrvMsg(iface,addr,buf,bufSize) {
 
 }
 
