@@ -7,7 +7,7 @@
  *
  * released under GNU GPL v2 only licence
  *
- * $Id: SrvOptIA_NA.cpp,v 1.30 2008-10-12 20:16:14 thomson Exp $
+ * $Id: SrvOptIA_NA.cpp,v 1.31 2009-03-24 01:14:55 thomson Exp $
  */
 
 #ifdef WIN32
@@ -20,12 +20,15 @@
 #include "SrvOptIA_NA.h"
 #include "SrvOptIAAddress.h"
 #include "SrvOptStatusCode.h"
-#include "SrvOptRapidCommit.h"
-#include "SrvOptRemoteID.h"
+#include "OptVendorData.h"
 #include "SrvCfgOptions.h"
 #include "Logger.h"
 #include "AddrClient.h"
 #include "DHCPConst.h"
+#include "Msg.h"
+#include "SrvAddrMgr.h"
+#include "SrvCfgMgr.h"
+#include "SrvTransMgr.h"
 
 TSrvOptIA_NA::TSrvOptIA_NA( long IAID, long T1, long T2, TMsg* parent)
     :TOptIA_NA(IAID,T1,T2, parent) {
@@ -52,16 +55,16 @@ TSrvOptIA_NA::TSrvOptIA_NA( char * buf, int bufsize, TMsg* parent)
         if ((code>0)&&(code<=24))
         {
             if(allowOptInOpt(parent->getType(),OPTION_IA_NA,code)) {
-                SmartPtr<TOpt> opt;
-		opt = SmartPtr<TOpt>(); /* NULL */
+                SPtr<TOpt> opt;
+		opt = SPtr<TOpt>(); /* NULL */
                 switch (code)
                 {
                 case OPTION_IAADDR:
-                    opt = (Ptr*)SmartPtr<TSrvOptIAAddress>
+                    opt = (Ptr*)SPtr<TSrvOptIAAddress>
 			(new TSrvOptIAAddress(buf+pos,length,this->Parent));
                     break;
                 case OPTION_STATUS_CODE:
-                    opt = (Ptr*)SmartPtr<TSrvOptStatusCode>
+                    opt = (Ptr*)SPtr<TSrvOptStatusCode>
 			(new TSrvOptStatusCode(buf+pos,length,this->Parent));
                     break;
                 default:
@@ -98,19 +101,16 @@ TSrvOptIA_NA::TSrvOptIA_NA( char * buf, int bufsize, TMsg* parent)
  * @param msgType
  * @param parent
  */
-TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr> cfgMgr,
-			   SmartPtr<TSrvOptIA_NA> queryOpt,
-			   SmartPtr<TDUID> clntDuid, SmartPtr<TIPv6Addr> clntAddr,
+TSrvOptIA_NA::TSrvOptIA_NA(SPtr<TSrvOptIA_NA> queryOpt,
+			   SPtr<TDUID> clntDuid, SPtr<TIPv6Addr> clntAddr,
 			   int iface, int msgType, TMsg* parent)
     :TOptIA_NA(queryOpt->getIAID(), DHCPV6_INFINITY, DHCPV6_INFINITY, parent) {
 
-    this->AddrMgr   = addrMgr;
-    this->CfgMgr    = cfgMgr;
     this->ClntDuid  = clntDuid;
     this->ClntAddr  = clntAddr;
     this->Iface     = iface;
 
-    // FIXME: SOLICIT without RAPID COMMIT should set this to true
+    /// @todo: SOLICIT without RAPID COMMIT should set this to true
     bool quiet = false;
 
     // --- check if client already has binding
@@ -134,7 +134,7 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
       } else {
 	  Log(Notice) << "Reserved address " << hint->getPlain() << " for this client found, trying to assign." << LogEnd;
       }
-      SmartPtr<TSrvOptStatusCode> ptrStatus;
+      SPtr<TSrvOptStatusCode> ptrStatus;
       if (this->assignAddr(hint, DHCPV6_INFINITY, DHCPV6_INFINITY, quiet))
       {
 	  // include status code
@@ -158,10 +158,10 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
     unsigned long addrsMax       = 0; // clnt-max-lease
     unsigned long willAssign     = 0; // how many will be assigned?
 
-    addrsAssigned = addrMgr->getAddrCount(clntDuid);
+    addrsAssigned = SrvAddrMgr().getAddrCount(clntDuid);
     addrsRequested= queryOpt->countAddrs();
-    addrsAvail    = cfgMgr->countAvailAddrs(clntDuid, clntAddr, iface);
-    addrsMax      = cfgMgr->getIfaceByID(iface)->getClntMaxLease();
+    addrsAvail    = SrvCfgMgr().countAvailAddrs(clntDuid, clntAddr, iface);
+    addrsMax      = SrvCfgMgr().getIfaceByID(iface)->getClntMaxLease();
 
     willAssign = addrsRequested;
 
@@ -183,10 +183,10 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
               << addrsMax << ", " << willAssign << " will be assigned." << LogEnd;
 
     // --- ok, let's assign those damn addresses ---
-    SmartPtr<TOpt> opt;
-    SmartPtr<TIPv6Addr> hint;
-    SmartPtr<TOptIAAddress> optAddr;
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TOpt> opt;
+    SPtr<TIPv6Addr> hint;
+    SPtr<TOptIAAddress> optAddr;
+    SPtr<TSrvCfgAddrClass> ptrClass;
     bool ok=true;
 
     queryOpt->firstOption();
@@ -222,7 +222,7 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
 	}
 	case OPTION_STATUS_CODE:
 	{
-	    SmartPtr<TOptStatusCode> ptrStatus = (Ptr*) opt;
+	    SPtr<TOptStatusCode> ptrStatus = (Ptr*) opt;
 	    Log(Notice) << "Receviced STATUS_CODE code="
 			<<  ptrStatus->getCode() << ", message=(" << ptrStatus->getText()
 			<< ")" << LogEnd;
@@ -238,14 +238,14 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
     }
 
     // --- now include STATUS CODE ---
-    SmartPtr<TSrvOptStatusCode> ptrStatus;
+    SPtr<TSrvOptStatusCode> ptrStatus;
     if (ok) {
       ptrStatus = new TSrvOptStatusCode(STATUSCODE_SUCCESS,
                                         "All addresses were assigned.",this->Parent);
-      // FIXME: if this is solicit, place "all addrs would be assigned."
+      /// @todo: if this is solicit, place "all addrs would be assigned."
     } else {
 	char buf[60];
-	sprintf(buf, "%lu addr(s) requested, but assigned only %lu.",addrsRequested, addrsAssigned);
+	snprintf(buf, 60, "%lu addr(s) requested, but assigned only %lu.",addrsRequested, addrsAssigned);
 	if (addrsAssigned) {
 	    ptrStatus = new TSrvOptStatusCode(STATUSCODE_SUCCESS,buf, this->Parent);
 	} else {
@@ -259,28 +259,27 @@ TSrvOptIA_NA::TSrvOptIA_NA(SmartPtr<TSrvAddrMgr> addrMgr,  SmartPtr<TSrvCfgMgr>
 }
 
 void TSrvOptIA_NA::releaseAllAddrs(bool quiet) {
-    SmartPtr<TOpt> opt;
-    SmartPtr<TIPv6Addr> addr;
-    SmartPtr<TOptIAAddress> optAddr;
+    SPtr<TOpt> opt;
+    SPtr<TIPv6Addr> addr;
+    SPtr<TOptIAAddress> optAddr;
     this->firstOption();
     while ( opt = this->getOption() ) {
 	if (opt->getOptType() != OPTION_IAADDR)
 	    continue;
 	optAddr = (Ptr*) opt;
 	addr = optAddr->getAddr();
-	this->AddrMgr->delClntAddr(this->ClntDuid, this->IAID, addr, quiet);
-	this->CfgMgr->delClntAddr(this->Iface, addr);
+	SrvAddrMgr().delClntAddr(this->ClntDuid, this->IAID, addr, quiet);
+	SrvCfgMgr().delClntAddr(this->Iface, addr);
     }
 }
 
-SmartPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SmartPtr<TIPv6Addr> hint, unsigned long pref,
+SPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SPtr<TIPv6Addr> hint, unsigned long pref,
 						    unsigned long valid,
 						    bool quiet) {
-
     // Assign one address
-    SmartPtr<TIPv6Addr> addr;
-    SmartPtr<TSrvOptIAAddress> optAddr;
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TIPv6Addr> addr;
+    SPtr<TSrvOptIAAddress> optAddr;
+    SPtr<TSrvCfgAddrClass> ptrClass;
 
     // get address
     addr = this->getFreeAddr(hint);
@@ -288,7 +287,7 @@ SmartPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SmartPtr<TIPv6Addr> hint, un
 	Log(Warning) << "There are no more addresses available." << LogEnd;
 	return 0;
     }
-    ptrClass = this->CfgMgr->getClassByAddr(this->Iface, addr);
+    ptrClass = SrvCfgMgr().getClassByAddr(this->Iface, addr);
     pref = ptrClass->getPref(pref);
     valid= ptrClass->getValid(valid);
     optAddr = new TSrvOptIAAddress(addr, pref, valid, this->Parent);
@@ -306,9 +305,9 @@ SmartPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SmartPtr<TIPv6Addr> hint, un
     this->T2= ptrClass->getT2(this->T2);
 
     // register this address as used by this client
-    this->AddrMgr->addClntAddr(this->ClntDuid, this->ClntAddr, this->Iface, this->IAID,
+    SrvAddrMgr().addClntAddr(this->ClntDuid, this->ClntAddr, this->Iface, this->IAID,
 			       this->T1, this->T2, addr, pref, valid, quiet);
-    this->CfgMgr->addClntAddr(this->Iface, addr);
+    SrvCfgMgr().addClntAddr(this->Iface, addr);
 
     return optAddr;
 }
@@ -320,18 +319,16 @@ SmartPtr<TSrvOptIAAddress> TSrvOptIA_NA::assignAddr(SmartPtr<TIPv6Addr> hint, un
  */
 SPtr<TIPv6Addr> TSrvOptIA_NA::getExceptionAddr()
 {
-    SmartPtr<TSrvCfgIface> ptrIface=CfgMgr->getIfaceByID(Iface);
+    SPtr<TSrvCfgIface> ptrIface=SrvCfgMgr().getIfaceByID(Iface);
     if (!ptrIface) {
 	return 0;
     }
 
-    SPtr<TSrvOptRemoteID> remoteID;
-
+    SPtr<TOptVendorData> remoteID;
 
     TSrvMsg * par = dynamic_cast<TSrvMsg*>(Parent);
     if (par) {
 	remoteID = par->getRemoteID();
-    } else {
     }
 
     SPtr<TSrvCfgOptions> ex = ptrIface->getClientException(ClntDuid, remoteID, false/* false = verbose */);
@@ -342,16 +339,12 @@ SPtr<TIPv6Addr> TSrvOptIA_NA::getExceptionAddr()
     return 0;
 }
 
-// constructor used only in RENEW, REBIND, DECLINE and RELEASE
-TSrvOptIA_NA::TSrvOptIA_NA( SmartPtr<TSrvCfgMgr> cfgMgr,
-		 SmartPtr<TSrvAddrMgr> addrMgr,
-		 SmartPtr<TSrvOptIA_NA> queryOpt,
-		 SmartPtr<TIPv6Addr> clntAddr, SmartPtr<TDUID> clntDuid,
+// constructor used only in RENEW, REBIND, CONFIRM,DECLINE and RELEASE
+TSrvOptIA_NA::TSrvOptIA_NA(SPtr<TSrvOptIA_NA> queryOpt,
+		 SPtr<TIPv6Addr> clntAddr, SPtr<TDUID> clntDuid,
 		 int iface, unsigned long &addrCount, int msgType , TMsg* parent)
     :TOptIA_NA(queryOpt->getIAID(),0x7fffffff,0x7fffffff, parent)
 {
-    this->AddrMgr   = addrMgr;
-    this->CfgMgr    = cfgMgr;
     this->ClntDuid  = clntDuid;
     this->ClntAddr  = clntAddr;
     this->Iface     = iface;
@@ -391,18 +384,18 @@ TSrvOptIA_NA::TSrvOptIA_NA( SmartPtr<TSrvCfgMgr> cfgMgr,
 }
 
 /**
- * generate OPTION_IA_NA based on OPTION_IA_NA received in RENEW message
+ * generates OPTION_IA_NA based on OPTION_IA_NA received in RENEW message
  *
- * @param queryOpt - IA_NA option in the RENEW message
- * @param addrCount
+ * @param queryOpt IA_NA option received from client in the RENEW message
+ * @param complainIfMissing specifies if potential warnings should be printed or not
  *
  * @return true - if binding was renewed, false - if not found or invalid
  */
-bool TSrvOptIA_NA::renew(SmartPtr<TSrvOptIA_NA> queryOpt, bool complainIfMissing)
+bool TSrvOptIA_NA::renew(SPtr<TSrvOptIA_NA> queryOpt, bool complainIfMissing)
 {
     // find that client in addrdb
-    SmartPtr <TAddrClient> ptrClient;
-    ptrClient = this->AddrMgr->getClient(this->ClntDuid);
+    SPtr <TAddrClient> ptrClient;
+    ptrClient = SrvAddrMgr().getClient(this->ClntDuid);
     if (!ptrClient) {
       if (complainIfMissing) {
         SubOptions.append(new TSrvOptStatusCode(STATUSCODE_NOBINDING,"Who are you? Do I know you?",
@@ -414,7 +407,7 @@ bool TSrvOptIA_NA::renew(SmartPtr<TSrvOptIA_NA> queryOpt, bool complainIfMissing
     }
 
     // find that IA
-    SmartPtr <TAddrIA> ptrIA;
+    SPtr <TAddrIA> ptrIA;
     ptrIA = ptrClient->getIA(this->IAID);
     if (!ptrIA) {
       if (complainIfMissing) {
@@ -432,10 +425,10 @@ bool TSrvOptIA_NA::renew(SmartPtr<TSrvOptIA_NA> queryOpt, bool complainIfMissing
     this->T2 = ptrIA->getT2();
 
     // send addr info to client
-    SmartPtr<TAddrAddr> ptrAddr;
+    SPtr<TAddrAddr> ptrAddr;
     ptrIA->firstAddr();
     while ( ptrAddr = ptrIA->getAddr() ) {
-        SmartPtr<TOptIAAddress> optAddr;
+        SPtr<TOptIAAddress> optAddr;
         ptrAddr->setTimestamp();
         optAddr = new TSrvOptIAAddress(ptrAddr->get(), ptrAddr->getPref(),ptrAddr->getValid(),
 				       this->Parent);
@@ -443,19 +436,18 @@ bool TSrvOptIA_NA::renew(SmartPtr<TSrvOptIA_NA> queryOpt, bool complainIfMissing
     }
 
     // finally send greetings and happy OK status code
-    SmartPtr<TSrvOptStatusCode> ptrStatus;
+    SPtr<TSrvOptStatusCode> ptrStatus;
     ptrStatus = new TSrvOptStatusCode(STATUSCODE_SUCCESS,"Address(es) renewed. Greetings from planet Earth",this->Parent);
     SubOptions.append( (Ptr*)ptrStatus );
 
     return true;
 }
 
-void TSrvOptIA_NA::rebind(SmartPtr<TSrvOptIA_NA> queryOpt,
+void TSrvOptIA_NA::rebind(SPtr<TSrvOptIA_NA> queryOpt,
                           unsigned long &addrCount)
 {
     // find that client in addrdb
-    SmartPtr <TAddrClient> ptrClient;
-    ptrClient = this->AddrMgr->getClient(this->ClntDuid);
+    SPtr <TAddrClient> ptrClient = SrvAddrMgr().getClient(this->ClntDuid);
     if (!ptrClient) {
         // hmmm, that's not our client
         SubOptions.append(new TSrvOptStatusCode(STATUSCODE_NOBINDING,
@@ -464,7 +456,7 @@ void TSrvOptIA_NA::rebind(SmartPtr<TSrvOptIA_NA> queryOpt,
     }
 
     // find that IA
-    SmartPtr <TAddrIA> ptrIA;
+    SPtr <TAddrIA> ptrIA;
     ptrIA = ptrClient->getIA(this->IAID);
     if (!ptrIA) {
         SubOptions.append(new TSrvOptStatusCode(STATUSCODE_NOBINDING,
@@ -472,7 +464,7 @@ void TSrvOptIA_NA::rebind(SmartPtr<TSrvOptIA_NA> queryOpt,
         return;
     }
 
-    // FIXME: 18.2.4 par. 3 (check if addrs are appropriate for this link)
+    /// @todo: 18.2.4 par. 3 (check if addrs are appropriate for this link)
 
     // everything seems ok, update data in addrdb
     ptrIA->setTimestamp();
@@ -480,32 +472,34 @@ void TSrvOptIA_NA::rebind(SmartPtr<TSrvOptIA_NA> queryOpt,
     this->T2 = ptrIA->getT2();
 
     // send addr info to client
-    SmartPtr<TAddrAddr> ptrAddr;
+    SPtr<TAddrAddr> ptrAddr;
     ptrIA->firstAddr();
     while ( ptrAddr = ptrIA->getAddr() ) {
-        SmartPtr<TOptIAAddress> optAddr;
+        SPtr<TOptIAAddress> optAddr;
         optAddr = new TSrvOptIAAddress(ptrAddr->get(), ptrAddr->getPref(),
 				       ptrAddr->getValid(),this->Parent);
         SubOptions.append( (Ptr*)optAddr );
     }
 
     // finally send greetings and happy OK status code
-    SmartPtr<TSrvOptStatusCode> ptrStatus;
+    SPtr<TSrvOptStatusCode> ptrStatus;
     ptrStatus = new TSrvOptStatusCode(STATUSCODE_SUCCESS,"Greetings from planet Earth",
 				      this->Parent);
     SubOptions.append( (Ptr*)ptrStatus );
 }
 
-void TSrvOptIA_NA::release(SmartPtr<TSrvOptIA_NA> queryOpt,
+void TSrvOptIA_NA::release(SPtr<TSrvOptIA_NA> queryOpt,
                            unsigned long &addrCount)
 {
 }
 
-void TSrvOptIA_NA::confirm(SmartPtr<TSrvOptIA_NA> queryOpt,
+
+//CHANGED here: add code to support CONFRIM msgs
+void TSrvOptIA_NA::confirm(SPtr<TSrvOptIA_NA> queryOpt,
                            unsigned long &addrCount)
 {
-    SmartPtr<TSrvOptIA_NA> ia = queryOpt;
-    SmartPtr<TOpt> subOpt;
+    SPtr<TSrvOptIA_NA> ia = queryOpt;
+    SPtr<TOpt> subOpt;
     bool NotOnLink = false;
 
     ia->firstOption();
@@ -513,11 +507,11 @@ void TSrvOptIA_NA::confirm(SmartPtr<TSrvOptIA_NA> queryOpt,
 	if (subOpt->getOptType() != OPTION_IAADDR)
 	    continue;
 
-        SmartPtr<TSrvOptIAAddress> optAddr = (Ptr*)subOpt;
+        SPtr<TSrvOptIAAddress> optAddr = (Ptr*)subOpt;
 
-	//FIXME: proper check if the addresses are valid or not should be performed
-        SmartPtr<TSrvCfgAddrClass> ptrClass;
-        ptrClass = CfgMgr->getClassByAddr(this->Iface, optAddr->getAddr());
+	/// @todo: proper check if the addresses are valid or not should be performed
+        SPtr<TSrvCfgAddrClass> ptrClass;
+        ptrClass = SrvCfgMgr().getClassByAddr(this->Iface, optAddr->getAddr());
 	if (!ptrClass)
 	{
 	    NotOnLink = true;
@@ -531,7 +525,7 @@ void TSrvOptIA_NA::confirm(SmartPtr<TSrvOptIA_NA> queryOpt,
         this->setT1( ptrClass->getT1(DHCPV6_INFINITY) );
         this->setT2( ptrClass->getT2(DHCPV6_INFINITY) );
 
-        SmartPtr<TOptIAAddress> myOptAddr;
+        SPtr<TOptIAAddress> myOptAddr;
         myOptAddr = new TSrvOptIAAddress(optAddr->getAddr(), optAddr->getPref(),
                                        optAddr->getValid(),this->Parent);
         SubOptions.append( (Ptr*)myOptAddr );
@@ -544,7 +538,7 @@ void TSrvOptIA_NA::confirm(SmartPtr<TSrvOptIA_NA> queryOpt,
 
 }
 
-void TSrvOptIA_NA::decline(SmartPtr<TSrvOptIA_NA> queryOpt,
+void TSrvOptIA_NA::decline(SPtr<TSrvOptIA_NA> queryOpt,
                            unsigned long &addrCount)
 {
 }
@@ -557,31 +551,28 @@ bool TSrvOptIA_NA::doDuties()
 /*
  * gets free address for a client
  */
-SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
-
-    // Getting out the request Message
-    
-    SmartPtr<TSrvTransMgr> srvTrans =  ((TSrvMsg*)Parent)->SrvTransMgr;
-    SmartPtr<TSrvMsg> requestMsg =  (Ptr*)(srvTrans->requestMsg);
+SPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SPtr<TIPv6Addr> hint) {
 
     bool invalidAddr = false;
-    SmartPtr<TSrvCfgIface> ptrIface;
-    SmartPtr<TIPv6Addr>    addr;
-    ptrIface = this->CfgMgr->getIfaceByID(this->Iface);
+    SPtr<TSrvCfgIface> ptrIface;
+    SPtr<TIPv6Addr>    addr;
+    ptrIface = SrvCfgMgr().getIfaceByID(this->Iface);
     if (!ptrIface) {
-	Log(Error) << "Trying to find free address on non-existent interface (id=%d)\n"
-		   << this->Iface << LogEnd;
-	return 0; // NULL
+        Log(Error) << "Trying to find free address on non-existent interface (id=%d)\n"
+	           << this->Iface << LogEnd;
+        return 0; // NULL
     }
 
+    SPtr<TSrvMsg> requestMsg = SrvTransMgr().getCurrentRequest();
+
     // check if this address is ok
 
     // is it anyaddress (::)?
-    SmartPtr<TIPv6Addr> anyaddr = new TIPv6Addr();
+    SPtr<TIPv6Addr> anyaddr = new TIPv6Addr();
     if (*anyaddr==*hint) {
-	Log(Debug) << "Client requested unspecified (" << *hint
-		   << ") address. Hint ignored." << LogEnd;
-	invalidAddr = true;
+        Log(Debug) << "Client requested unspecified (" << *hint
+           << ") address. Hint ignored." << LogEnd;
+        invalidAddr = true;
     }
 
     // is it multicast address (ff...)?
@@ -601,8 +592,8 @@ SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
     if ( !invalidAddr ) {
 	// hint is valid, try to use it
 
-	SmartPtr<TSrvCfgAddrClass> ptrClass;
-	ptrClass = this->CfgMgr->getClassByAddr(this->Iface, hint);
+	SPtr<TSrvCfgAddrClass> ptrClass;
+	ptrClass = SrvCfgMgr().getClassByAddr(this->Iface, hint);
 
 	// For Supportting Client Classify
 	// Should get clientMessage, instead of Parent message
@@ -611,7 +602,7 @@ SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
 	if ( ptrClass && ptrClass->clntSupported(ClntDuid, ClntAddr, requestMsg ))
 	{
 		// best case: address belongs to supported class, and is free
-		if ( AddrMgr->addrIsFree(hint) ) {
+		if ( SrvAddrMgr().addrIsFree(hint) ) {
 		    Log(Debug) << "Requested address (" << *hint << ") is free, great!" << LogEnd;
 		    return hint;
 		}
@@ -629,29 +620,29 @@ SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
 			       << ") belongs to supported class, but is used." << LogEnd;
 		    do {
 			addr = ptrClass->getRandomAddr();
-		    } while (!AddrMgr->addrIsFree(addr));
+		    } while (!SrvAddrMgr().addrIsFree(addr));
 		    return addr;
 		}
 	}// If the Class are valid and support the Client (based on duid, addr, clientclass)
     } //  if ( !invalidAddr )
 
     // do we have a cached address for that client?
-    if (addr = AddrMgr->getCachedAddr(this->ClntDuid)) {
-	if (this->CfgMgr->getClassByAddr(this->Iface, addr)) {
+    if (addr = SrvAddrMgr().getCachedEntry(this->ClntDuid, TAddrIA::TYPE_IA)) {
+	if (SrvCfgMgr().getClassByAddr(this->Iface, addr)) {
 	    Log(Info) << "Cache: Cached address " << *addr << " found. Welcome back." << LogEnd;
-	    if (AddrMgr->addrIsFree(addr))
+	    if (SrvAddrMgr().addrIsFree(addr))
 		return addr;
 	    Log(Info) << "Unfortunately, " << addr->getPlain() << " is used." << LogEnd;
-	    AddrMgr->delCachedAddr(addr);
+	    SrvAddrMgr().delCachedEntry(addr, TAddrIA::TYPE_IA);
 	} else {
 	    Log(Warning) << "Cache: Cached address " << *addr << " found, but it is no longer valid." << LogEnd;
-	    AddrMgr->delCachedAddr(addr);
+	    SrvAddrMgr().delCachedEntry(addr, TAddrIA::TYPE_IA);
 	}// else
     }// if have cached address for that client
 
     // worst case: address does not belong to supported class
     // or specified hint is invalid
-    SmartPtr<TSrvCfgAddrClass> ptrClass;
+    SPtr<TSrvCfgAddrClass> ptrClass;
 
 
     ptrClass = ptrIface->getRandomClass(this->ClntDuid, this->ClntAddr);
@@ -678,6 +669,6 @@ SmartPtr<TIPv6Addr> TSrvOptIA_NA::getFreeAddr(SmartPtr<TIPv6Addr> hint) {
 
     do {
 	addr = ptrClass->getRandomAddr();
-    } while (!AddrMgr->addrIsFree(hint));
+    } while (!SrvAddrMgr().addrIsFree(hint));
     return addr;
 }
