@@ -17,13 +17,13 @@
 #include "SrvOptPreference.h"
 
 TSrvOptPreference::TSrvOptPreference( char * buf,  int n, TMsg* parent)
-	:TOptPreference(buf,n, parent)
+  :TOptInteger(OPTION_PREFERENCE, 1, buf,n, parent)
 {
 
 }
 
 TSrvOptPreference::TSrvOptPreference( char pref, TMsg* parent)
-	:TOptPreference(pref, parent)
+  :TOptInteger(OPTION_PREFERENCE, 1, pref, parent)
 {
 }
 
