@@ -16,7 +16,7 @@
 class TSrvOptServerIdentifier : public TOptDUID
 {
   public:
-    TSrvOptServerIdentifier( SmartPtr<TDUID> duid, TMsg* parent);
+    TSrvOptServerIdentifier( SPtr<TDUID> duid, TMsg* parent);
     TSrvOptServerIdentifier(char* buf, int bufsize, TMsg* parent);
     bool doDuties();
 };
