@@ -8,10 +8,7 @@
  *
  * $Id: SrvOptServerUnicast.cpp,v 1.4 2008-08-29 00:07:37 thomson Exp $
  *
- * $Log: SrvOptServerUnicast.cpp,v $
- * Revision 1.4  2008-08-29 00:07:37  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.3  2004-10-25 20:45:54  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
@@ -29,7 +26,7 @@ TSrvOptServerUnicast::TSrvOptServerUnicast( char * buf,  int n, TMsg* parent)
 
 }
 
-TSrvOptServerUnicast::TSrvOptServerUnicast(SmartPtr<TIPv6Addr> addr, TMsg* parent) 
+TSrvOptServerUnicast::TSrvOptServerUnicast(SPtr<TIPv6Addr> addr, TMsg* parent) 
     :TOptAddr(OPTION_UNICAST, addr, parent) {
 
 }
