@@ -8,10 +8,7 @@
  *
  * $Id: SrvOptServerUnicast.h,v 1.4 2008-08-29 00:07:37 thomson Exp $
  *
- * $Log: SrvOptServerUnicast.h,v $
- * Revision 1.4  2008-08-29 00:07:37  thomson
- * Temporary license change(GPLv2 or later -> GPLv2 only)
- *
+ * $Log: not supported by cvs2svn $
  * Revision 1.3  2004-10-25 20:45:54  thomson
  * Option support, parsers rewritten. ClntIfaceMgr now handles options.
  *
@@ -30,7 +27,7 @@
 class TSrvOptServerUnicast : public TOptAddr {
  public:
     TSrvOptServerUnicast( char * buf,  int n, TMsg* parent);
-    TSrvOptServerUnicast(SmartPtr<TIPv6Addr> addr, TMsg* parent);
+    TSrvOptServerUnicast(SPtr<TIPv6Addr> addr, TMsg* parent);
     bool doDuties();	
 };
 
