@@ -10,57 +10,63 @@
  *
  */
 
-class TSrvTransMgr;
 #ifndef SRVTRANSMGR_H
 #define SRVTRANSMGR_H
 
 #include <string>
+#include <vector>
 #include "SmartPtr.h"
 #include "Container.h"
 #include "Opt.h"
 #include "SrvMsg.h"
 #include "SrvIfaceMgr.h"
-#include "SrvCfgMgr.h"
+#include "SrvCfgIface.h"
 #include "SrvAddrMgr.h"
 
+#define SrvTransMgr() (TSrvTransMgr::instance())
+
 class TSrvTransMgr
 {
     friend ostream & operator<<(ostream &strum, TSrvTransMgr &x);
   public:
-    TSrvTransMgr(SmartPtr<TSrvIfaceMgr> ifaceMgr,
-		 SmartPtr<TSrvAddrMgr> addrMgr,
-		 SmartPtr<TSrvCfgMgr> cfgMgr,
-		 string xmlFile);
-    ~TSrvTransMgr();
+    static void instanceCreate(const std::string config);
+    static TSrvTransMgr &instance();
 
-    bool openSocket(SmartPtr<TSrvCfgIface> confIface);
+    bool openSocket(SPtr<TSrvCfgIface> confIface);
+    SPtr<TSrvMsg> getCurrentRequest();
 
     long getTimeout();
-    void relayMsg(SmartPtr<TSrvMsg> msg);
+    void relayMsg(SPtr<TSrvMsg> msg);
     void doDuties();
     void dump();
 
     bool isDone();
     void shutdown();
 
+    void removeExpired(std::vector<TSrvAddrMgr::TExpiredInfo>& addrLst,
+                       std::vector<TSrvAddrMgr::TExpiredInfo>& tempAddrLst,
+                       std::vector<TSrvAddrMgr::TExpiredInfo>& prefixLst);
+
+    void notifyExpireInfo(TNotifyScriptParams& params, const TSrvAddrMgr::TExpiredInfo& exp,
+                          TAddrIA::TIAType type);
+
     char * getCtrlAddr();
     int    getCtrlIface();
 
-    void setContext(SmartPtr<TSrvTransMgr> transMgr);
-
-    SmartPtr<TSrvMsg> requestMsg;
   private:
+    TSrvTransMgr(string xmlFile);
+    ~TSrvTransMgr();
+
     string XmlFile;
     List(TSrvMsg) MsgLst;
     bool IsDone;
 
-    SmartPtr<TSrvIfaceMgr> IfaceMgr;
-    SmartPtr<TSrvTransMgr> That;
-    SmartPtr<TSrvCfgMgr>  CfgMgr;
-    SmartPtr<TSrvAddrMgr>  AddrMgr;
-
     int ctrlIface;
     char ctrlAddr[48];
+
+    SPtr<TSrvMsg> requestMsg; /// @todo: Remove this field and do the REQUEST handling properly
+
+    static TSrvTransMgr * Instance;
 };
 
 
